@@ -28,17 +28,13 @@ import java.util.Set;
 
 import org.apache.maven.model.BuildBase;
 import org.apache.maven.model.CiManagement;
-import org.apache.maven.model.Contributor;
 import org.apache.maven.model.Dependency;
 import org.apache.maven.model.DeploymentRepository;
-import org.apache.maven.model.Developer;
 import org.apache.maven.model.DistributionManagement;
 import org.apache.maven.model.Exclusion;
 import org.apache.maven.model.Extension;
 import org.apache.maven.model.InputLocation;
 import org.apache.maven.model.IssueManagement;
-import org.apache.maven.model.License;
-import org.apache.maven.model.MailingList;
 import org.apache.maven.model.Model;
 import org.apache.maven.model.ModelBase;
 import org.apache.maven.model.Organization;
@@ -57,6 +53,7 @@ import org.apache.maven.model.Site;
  *
  * @author Benjamin Bentmann
  */
+@SuppressWarnings( { "checkstyle:methodname" } )
 public class MavenModelMerger
     extends ModelMerger
 {
@@ -69,7 +66,7 @@ public class MavenModelMerger
     /**
      * The context key for the artifact id of the target model.
      */
-    private static final String ARTIFACT_ID = "artifact-id";
+    public static final String ARTIFACT_ID = "artifact-id";
 
     @Override
     protected void mergeModel( Model target, Model source, boolean sourceDominant, Map<Object, Object> context )
@@ -106,14 +103,14 @@ public class MavenModelMerger
             }
             else if ( target.getUrl() == null )
             {
-                target.setUrl( appendPath( src, context ) );
+                target.setUrl( extrapolateChildUrl( src, context ) );
                 target.setLocation( "url", source.getLocation( "url" ) );
             }
         }
     }
 
     /*
-     * TODO: Whether the merge continues recursively into an existing node or not could be an option for the generated
+     * TODO Whether the merge continues recursively into an existing node or not could be an option for the generated
      * merger
      */
     @Override
@@ -204,7 +201,7 @@ public class MavenModelMerger
     {
         if ( target.getLicenses().isEmpty() )
         {
-            target.setLicenses( new ArrayList<License>( source.getLicenses() ) );
+            target.setLicenses( new ArrayList<>( source.getLicenses() ) );
         }
     }
 
@@ -214,7 +211,7 @@ public class MavenModelMerger
     {
         if ( target.getDevelopers().isEmpty() )
         {
-            target.setDevelopers( new ArrayList<Developer>( source.getDevelopers() ) );
+            target.setDevelopers( new ArrayList<>( source.getDevelopers() ) );
         }
     }
 
@@ -224,7 +221,7 @@ public class MavenModelMerger
     {
         if ( target.getContributors().isEmpty() )
         {
-            target.setContributors( new ArrayList<Contributor>( source.getContributors() ) );
+            target.setContributors( new ArrayList<>( source.getContributors() ) );
         }
     }
 
@@ -234,7 +231,7 @@ public class MavenModelMerger
     {
         if ( target.getMailingLists().isEmpty() )
         {
-            target.setMailingLists( new ArrayList<MailingList>( source.getMailingLists() ) );
+            target.setMailingLists( new ArrayList<>( source.getMailingLists() ) );
         }
     }
 
@@ -245,10 +242,10 @@ public class MavenModelMerger
         List<String> src = source.getModules();
         if ( !src.isEmpty() && sourceDominant )
         {
-            List<Integer> indices = new ArrayList<Integer>();
+            List<Integer> indices = new ArrayList<>();
             List<String> tgt = target.getModules();
-            Set<String> excludes = new LinkedHashSet<String>( tgt );
-            List<String> merged = new ArrayList<String>( tgt.size() + src.size() );
+            Set<String> excludes = new LinkedHashSet<>( tgt );
+            List<String> merged = new ArrayList<>( tgt.size() + src.size() );
             merged.addAll( tgt );
             for ( int i = 0, n = tgt.size(); i < n; i++ )
             {
@@ -270,7 +267,7 @@ public class MavenModelMerger
     }
 
     /*
-     * TODO: The order of the merged list could be controlled by an attribute in the model association: target-first,
+     * TODO The order of the merged list could be controlled by an attribute in the model association: target-first,
      * source-first, dominant-first, recessive-first
      */
     @Override
@@ -281,7 +278,7 @@ public class MavenModelMerger
         if ( !src.isEmpty() )
         {
             List<Repository> tgt = target.getRepositories();
-            Map<Object, Repository> merged = new LinkedHashMap<Object, Repository>( ( src.size() + tgt.size() ) * 2 );
+            Map<Object, Repository> merged = new LinkedHashMap<>( ( src.size() + tgt.size() ) * 2 );
 
             List<Repository> dominant, recessive;
             if ( sourceDominant )
@@ -310,10 +307,11 @@ public class MavenModelMerger
                 }
             }
 
-            target.setRepositories( new ArrayList<Repository>( merged.values() ) );
+            target.setRepositories( new ArrayList<>( merged.values() ) );
         }
     }
 
+    @Override
     protected void mergeModelBase_PluginRepositories( ModelBase target, ModelBase source, boolean sourceDominant,
                                                       Map<Object, Object> context )
     {
@@ -321,7 +319,7 @@ public class MavenModelMerger
         if ( !src.isEmpty() )
         {
             List<Repository> tgt = target.getPluginRepositories();
-            Map<Object, Repository> merged = new LinkedHashMap<Object, Repository>( ( src.size() + tgt.size() ) * 2 );
+            Map<Object, Repository> merged = new LinkedHashMap<>( ( src.size() + tgt.size() ) * 2 );
 
             List<Repository> dominant, recessive;
             if ( sourceDominant )
@@ -350,12 +348,12 @@ public class MavenModelMerger
                 }
             }
 
-            target.setPluginRepositories( new ArrayList<Repository>( merged.values() ) );
+            target.setPluginRepositories( new ArrayList<>( merged.values() ) );
         }
     }
 
     /*
-     * TODO: Whether duplicates should be removed looks like an option for the generated merger.
+     * TODO Whether duplicates should be removed looks like an option for the generated merger.
      */
     @Override
     protected void mergeBuildBase_Filters( BuildBase target, BuildBase source, boolean sourceDominant,
@@ -365,8 +363,8 @@ public class MavenModelMerger
         if ( !src.isEmpty() )
         {
             List<String> tgt = target.getFilters();
-            Set<String> excludes = new LinkedHashSet<String>( tgt );
-            List<String> merged = new ArrayList<String>( tgt.size() + src.size() );
+            Set<String> excludes = new LinkedHashSet<>( tgt );
+            List<String> merged = new ArrayList<>( tgt.size() + src.size() );
             merged.addAll( tgt );
             for ( String s : src )
             {
@@ -469,7 +467,7 @@ public class MavenModelMerger
             }
             else if ( target.getUrl() == null )
             {
-                target.setUrl( appendPath( src, context ) );
+                target.setUrl( extrapolateChildUrl( src, context ) );
                 target.setLocation( "url", source.getLocation( "url" ) );
             }
         }
@@ -488,7 +486,7 @@ public class MavenModelMerger
             }
             else if ( target.getUrl() == null )
             {
-                target.setUrl( appendPath( src, context ) );
+                target.setUrl( extrapolateChildUrl( src, context ) );
                 target.setLocation( "url", source.getLocation( "url" ) );
             }
         }
@@ -507,7 +505,7 @@ public class MavenModelMerger
             }
             else if ( target.getConnection() == null )
             {
-                target.setConnection( appendPath( src, context ) );
+                target.setConnection( extrapolateChildUrl( src, context ) );
                 target.setLocation( "connection", source.getLocation( "connection" ) );
             }
         }
@@ -527,7 +525,7 @@ public class MavenModelMerger
             }
             else if ( target.getDeveloperConnection() == null )
             {
-                target.setDeveloperConnection( appendPath( src, context ) );
+                target.setDeveloperConnection( extrapolateChildUrl( src, context ) );
                 target.setLocation( "developerConnection", source.getLocation( "developerConnection" ) );
             }
         }
@@ -542,7 +540,7 @@ public class MavenModelMerger
         {
             List<PluginExecution> tgt = target.getExecutions();
             Map<Object, PluginExecution> merged =
-                new LinkedHashMap<Object, PluginExecution>( ( src.size() + tgt.size() ) * 2 );
+                new LinkedHashMap<>( ( src.size() + tgt.size() ) * 2 );
 
             for ( PluginExecution element : src )
             {
@@ -565,7 +563,7 @@ public class MavenModelMerger
                 merged.put( key, element );
             }
 
-            target.setExecutions( new ArrayList<PluginExecution>( merged.values() ) );
+            target.setExecutions( new ArrayList<>( merged.values() ) );
         }
     }
 
@@ -577,8 +575,8 @@ public class MavenModelMerger
         if ( !src.isEmpty() )
         {
             List<String> tgt = target.getGoals();
-            Set<String> excludes = new LinkedHashSet<String>( tgt );
-            List<String> merged = new ArrayList<String>( tgt.size() + src.size() );
+            Set<String> excludes = new LinkedHashSet<>( tgt );
+            List<String> merged = new ArrayList<>( tgt.size() + src.size() );
             merged.addAll( tgt );
             for ( String s : src )
             {
@@ -599,14 +597,14 @@ public class MavenModelMerger
         if ( !src.isEmpty() )
         {
             List<ReportSet> tgt = target.getReportSets();
-            Map<Object, ReportSet> merged = new LinkedHashMap<Object, ReportSet>( ( src.size() + tgt.size() ) * 2 );
+            Map<Object, ReportSet> merged = new LinkedHashMap<>( ( src.size() + tgt.size() ) * 2 );
 
-            for ( ReportSet element : src )
+            for ( ReportSet rset : src )
             {
-                if ( sourceDominant || ( element.getInherited() != null ? element.isInherited() : source.isInherited() ) )
+                if ( sourceDominant || ( rset.getInherited() != null ? rset.isInherited() : source.isInherited() ) )
                 {
-                    Object key = getReportSetKey( element );
-                    merged.put( key, element );
+                    Object key = getReportSetKey( rset );
+                    merged.put( key, rset );
                 }
             }
 
@@ -621,7 +619,7 @@ public class MavenModelMerger
                 merged.put( key, element );
             }
 
-            target.setReportSets( new ArrayList<ReportSet>( merged.values() ) );
+            target.setReportSets( new ArrayList<>( merged.values() ) );
         }
     }
 
@@ -673,56 +671,9 @@ public class MavenModelMerger
         return exclusion.getGroupId() + ':' + exclusion.getArtifactId();
     }
 
-    private String appendPath( String parentPath, Map<Object, Object> context )
+    protected String extrapolateChildUrl( String parentUrl, Map<Object, Object> context )
     {
-        Object artifactId = context.get( ARTIFACT_ID );
-        Object childPathAdjustment = context.get( CHILD_PATH_ADJUSTMENT );
-
-        if ( artifactId != null && childPathAdjustment != null )
-        {
-            return appendPath( parentPath, artifactId.toString(), childPathAdjustment.toString() );
-        }
-        else
-        {
-            return parentPath;
-        }
-    }
-
-    private String appendPath( String parentPath, String childPath, String pathAdjustment )
-    {
-        String path = parentPath;
-        path = concatPath( path, pathAdjustment );
-        path = concatPath( path, childPath );
-        return path;
-    }
-
-    private String concatPath( String base, String path )
-    {
-        String result = base;
-
-        if ( path != null && path.length() > 0 )
-        {
-            if ( ( result.endsWith( "/" ) && !path.startsWith( "/" ) )
-                || ( !result.endsWith( "/" ) && path.startsWith( "/" ) ) )
-            {
-                result += path;
-            }
-            else if ( result.endsWith( "/" ) && path.startsWith( "/" ) )
-            {
-                result += path.substring( 1 );
-            }
-            else
-            {
-                result += '/';
-                result += path;
-            }
-            if ( base.endsWith( "/" ) && !result.endsWith( "/" ) )
-            {
-                result += '/';
-            }
-        }
-
-        return result;
+        return parentUrl;
     }
 
 }
