@@ -49,6 +49,7 @@ import org.apache.tools.ant.util.CollectionUtils;
 import org.apache.tools.ant.util.FileUtils;
 import org.apache.tools.ant.util.JavaEnvUtils;
 import org.apache.tools.ant.util.LoaderUtils;
+import org.apache.tools.ant.util.StringUtils;
 import org.apache.tools.ant.util.VectorSet;
 import org.apache.tools.zip.ZipLong;
 
@@ -355,11 +356,9 @@ public class AntClassLoader extends ClassLoader implements SubBuildListener, Clo
     public void setClassPath(final Path classpath) {
         pathComponents.removeAllElements();
         if (classpath != null) {
-            final Path actualClasspath = classpath.concatSystemClasspath("ignore");
-            final String[] pathElements = actualClasspath.list();
-            for (int i = 0; i < pathElements.length; ++i) {
+            for (String pathElement : classpath.concatSystemClasspath("ignore").list()) {
                 try {
-                    addPathElement(pathElements[i]);
+                    addPathElement(pathElement);
                 } catch (final BuildException e) {
                     // ignore path elements which are invalid
                     // relative to the project
@@ -401,6 +400,8 @@ public class AntClassLoader extends ClassLoader implements SubBuildListener, Clo
     protected void log(final String message, final int priority) {
         if (project != null) {
             project.log(message, priority);
+        } else if (priority < Project.MSG_INFO) {
+            System.err.println(message);
         }
     }
 
@@ -925,8 +926,8 @@ public class AntClassLoader extends ClassLoader implements SubBuildListener, Clo
      *
      * @param name name of the resource
      * @return possible URLs as enumeration
-     * @throws IOException
-     * @see {@link #findResources(String, boolean)}
+     * @throws IOException if something goes wrong
+     * @see #findResources(String, boolean)
      * @since Ant 1.8.0
      */
     public Enumeration<URL> getNamedResources(final String name)
@@ -1020,7 +1021,6 @@ public class AntClassLoader extends ClassLoader implements SubBuildListener, Clo
                             final String msg = "CLASSPATH element " + file
                                 + " is not a JAR.";
                             log(msg, Project.MSG_WARN);
-                            System.err.println(msg);
                             return null;
                         }
                         jarFile = new JarFile(file);
@@ -1043,8 +1043,7 @@ public class AntClassLoader extends ClassLoader implements SubBuildListener, Clo
         } catch (final Exception e) {
             final String msg = "Unable to obtain resource from " + file + ": ";
             log(msg + e, Project.MSG_WARN);
-            System.err.println(msg);
-            e.printStackTrace();
+            log(StringUtils.getStackTrace(e), Project.MSG_WARN);
         }
         return null;
     }
@@ -1210,11 +1209,8 @@ public class AntClassLoader extends ClassLoader implements SubBuildListener, Clo
      *
      * @return the entry's certificates or null is the container is
      *         not a jar or it has no certificates.
-     *
-     * @exception IOException if the manifest cannot be read.
      */
-    private Certificate[] getCertificates(final File container, final String entry)
-        throws IOException {
+    private Certificate[] getCertificates(final File container, final String entry) {
         if (container.isDirectory()) {
             return null;
         }
@@ -1563,6 +1559,12 @@ public class AntClassLoader extends ClassLoader implements SubBuildListener, Clo
 
     /**
      * Factory method
+     *
+     * @param parent ClassLoader
+     * @param project Project
+     * @param path Path
+     * @param parentFirst boolean
+     * @return AntClassLoader
      */
     public static AntClassLoader newAntClassLoader(final ClassLoader parent,
                                                    final Project project,
