@@ -33,6 +33,7 @@ import java.io.OutputStreamWriter;
 import java.net.MalformedURLException;
 import java.net.URL;
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.Enumeration;
 import java.util.HashSet;
 import java.util.Iterator;
@@ -64,9 +65,9 @@ import org.apache.tools.ant.util.StringUtils;
  * Generates Javadoc documentation for a collection
  * of source code.
  *
- * <p>Current known limitations are:
+ * <p>Current known limitations are:</p>
  *
- * <p><ul>
+ * <ul>
  *    <li>patterns must be of the form "xxx.*", every other pattern doesn't
  *        work.
  *    <li>there is no control on arguments sanity since they are left
@@ -74,10 +75,10 @@ import org.apache.tools.ant.util.StringUtils;
  * </ul>
  *
  * <p>If no <code>doclet</code> is set, then the <code>version</code> and
- * <code>author</code> are by default <code>"yes"</code>.
+ * <code>author</code> are by default <code>"yes"</code>.</p>
  *
  * <p>Note: This task is run on another VM because the Javadoc code calls
- * <code>System.exit()</code> which would break Ant functionality.
+ * <code>System.exit()</code> which would break Ant functionality.</p>
  *
  * @since Ant 1.1
  *
@@ -1313,7 +1314,7 @@ public class Javadoc extends Task {
      * cannot be static in inner classes.) The first letter
      * from each element is used to build up the scope string.
      */
-    static final String[] SCOPE_ELEMENTS = {
+    static final String[] SCOPE_ELEMENTS = { //NOSONAR
         "overview", "packages", "types", "constructors",
         "methods", "fields"
     };
@@ -1334,7 +1335,7 @@ public class Javadoc extends Task {
         private String scope = "a";
 
         /** Sole constructor. */
-        public TagArgument () {
+        public TagArgument() {
             //empty
         }
 
@@ -1344,7 +1345,7 @@ public class Javadoc extends Task {
          * @param name The name of the tag.
          *             Must not be <code>null</code> or empty.
          */
-        public void setName (final String name) {
+        public void setName(final String name) {
             this.name = name;
         }
 
@@ -1364,7 +1365,7 @@ public class Javadoc extends Task {
          * elements are specified, or if any unrecognised elements are
          * specified.
          */
-        public void setScope (String verboseScope) throws BuildException {
+        public void setScope(String verboseScope) throws BuildException {
             verboseScope = verboseScope.toLowerCase(Locale.ENGLISH);
 
             final boolean[] elements = new boolean[SCOPE_ELEMENTS.length];
@@ -1374,7 +1375,7 @@ public class Javadoc extends Task {
 
             // Go through the tokens one at a time, updating the
             // elements array and issuing warnings where appropriate.
-            final StringTokenizer tok = new StringTokenizer (verboseScope, ",");
+            final StringTokenizer tok = new StringTokenizer(verboseScope, ",");
             while (tok.hasMoreTokens()) {
                 final String next = tok.nextToken().trim();
                 if (next.equals("all")) {
@@ -1430,7 +1431,7 @@ public class Javadoc extends Task {
          *
          * @param enabled Whether or not this tag is enabled.
          */
-        public void setEnabled (final boolean enabled) {
+        public void setEnabled(final boolean enabled) {
             this.enabled = enabled;
         }
 
@@ -1673,6 +1674,7 @@ public class Javadoc extends Task {
     /**
      * Enables deep-copying of <code>doc-files</code> directories.
      *
+     * @param b boolean
      * @since Ant 1.8.0
      */
     public void setDocFilesSubDirs(final boolean b) {
@@ -1683,6 +1685,7 @@ public class Javadoc extends Task {
      * Colon-separated list of <code>doc-files</code> subdirectories
      * to skip if {@link #setDocFilesSubDirs docFilesSubDirs is true}.
      *
+     * @param s String
      * @since Ant 1.8.0
      */
     public void setExcludeDocFilesSubDir(final String s) {
@@ -1691,6 +1694,8 @@ public class Javadoc extends Task {
 
     /**
      * Whether to post-process the generated javadocs in order to mitigate CVE-2013-1571.
+     *
+     * @param b boolean
      * @since Ant 1.9.2
      */
     public void setPostProcessGeneratedJavadocs(final boolean b) {
@@ -1772,10 +1777,12 @@ public class Javadoc extends Task {
                 useExternalFile, tmpList, srcListWriter);
 
             if (useExternalFile) {
-                srcListWriter.flush();
+                srcListWriter.flush(); //NOSONAR
             }
         } catch (final IOException e) {
-            tmpList.delete();
+            if (tmpList != null) {
+                tmpList.delete();
+            }
             throw new BuildException("Error creating temporary file",
                                      e, getLocation());
         } finally {
@@ -1912,32 +1919,26 @@ public class Javadoc extends Task {
     private void doDoclet(final Commandline toExecute) {
         if (doclet != null) {
             if (doclet.getName() == null) {
-                throw new BuildException("The doclet name must be "
-                                         + "specified.", getLocation());
-            } else {
-                toExecute.createArgument().setValue("-doclet");
-                toExecute.createArgument().setValue(doclet.getName());
-                if (doclet.getPath() != null) {
-                    final Path docletPath
-                        = doclet.getPath().concatSystemClasspath("ignore");
-                    if (docletPath.size() != 0) {
-                        toExecute.createArgument().setValue("-docletpath");
-                        toExecute.createArgument().setPath(docletPath);
-                    }
+                throw new BuildException("The doclet name must be specified.",
+                    getLocation());
+            }
+            toExecute.createArgument().setValue("-doclet");
+            toExecute.createArgument().setValue(doclet.getName());
+            if (doclet.getPath() != null) {
+                final Path docletPath
+                    = doclet.getPath().concatSystemClasspath("ignore");
+                if (docletPath.size() != 0) {
+                    toExecute.createArgument().setValue("-docletpath");
+                    toExecute.createArgument().setPath(docletPath);
                 }
-                for (final Enumeration<DocletParam> e = doclet.getParams();
-                     e.hasMoreElements();) {
-                    final DocletParam param = e.nextElement();
-                    if (param.getName() == null) {
-                        throw new BuildException("Doclet parameters must "
-                                                 + "have a name");
-                    }
-
-                    toExecute.createArgument().setValue(param.getName());
-                    if (param.getValue() != null) {
-                        toExecute.createArgument()
-                            .setValue(param.getValue());
-                    }
+            }
+            for (final DocletParam param : Collections.list(doclet.getParams())) {
+                if (param.getName() == null) {
+                    throw new BuildException("Doclet parameters must have a name");
+                }
+                toExecute.createArgument().setValue(param.getName());
+                if (param.getValue() != null) {
+                    toExecute.createArgument().setValue(param.getValue());
                 }
             }
         }
@@ -2024,7 +2025,8 @@ public class Javadoc extends Task {
                     // is the href a valid URL
                     try {
                         final URL base = new URL("file://.");
-                        new URL(base, la.getHref());
+                        // created for the side effect of throwing a MalformedURLException
+                        new URL(base, la.getHref()); //NOSONAR
                         link = la.getHref();
                     } catch (final MalformedURLException mue) {
                         // ok - just skip
@@ -2145,27 +2147,20 @@ public class Javadoc extends Task {
                     // -tag arguments.
                     final DirectoryScanner tagDefScanner =
                         ta.getDirectoryScanner(getProject());
-                    final String[] files = tagDefScanner.getIncludedFiles();
-                    for (int i = 0; i < files.length; i++) {
-                        final File tagDefFile = new File(tagDir, files[i]);
+                    for (String file : tagDefScanner.getIncludedFiles()) {
+                        final File tagDefFile = new File(tagDir, file);
                         try {
-                            final BufferedReader in
-                                = new BufferedReader(
-                                    new FileReader(tagDefFile)
-                                                     );
+                            final BufferedReader in = new BufferedReader(
+                                    new FileReader(tagDefFile));
                             String line = null;
                             while ((line = in.readLine()) != null) {
-                                toExecute.createArgument()
-                                    .setValue("-tag");
-                                toExecute.createArgument()
-                                    .setValue(line);
+                                toExecute.createArgument().setValue("-tag");
+                                toExecute.createArgument().setValue(line);
                             }
                             in.close();
                         } catch (final IOException ioe) {
-                            throw new BuildException(
-                                "Couldn't read "
-                                + " tag file from "
-                                + tagDefFile.getAbsolutePath(), ioe);
+                            throw new BuildException("Couldn't read  tag file from "
+                                    + tagDefFile.getAbsolutePath(), ioe);
                         }
                     }
                 }
@@ -2235,7 +2230,7 @@ public class Javadoc extends Task {
             if (useExternalFile) {
                 // TODO what is the following doing?
                 //     should it run if !javadoc4 && executable != null?
-                if (sourceFileName.indexOf(" ") > -1) {
+                if (sourceFileName.contains(" ")) {
                     String name = sourceFileName;
                     if (File.separatorChar == '\\') {
                         name = sourceFileName.replace(File.separatorChar, '/');
@@ -2271,9 +2266,8 @@ public class Javadoc extends Task {
     }
 
     private boolean containsWhitespace(final String s) {
-        final int len = s.length();
-        for (int i = 0; i < len; i++) {
-            if (Character.isWhitespace(s.charAt(i))) {
+        for (char c : s.toCharArray()) {
+            if (Character.isWhitespace(c)) {
                 return true;
             }
         }
@@ -2283,10 +2277,8 @@ public class Javadoc extends Task {
     private String quoteString(final String str, final char delim) {
         final StringBuffer buf = new StringBuffer(str.length() * 2);
         buf.append(delim);
-        final int len = str.length();
         boolean lastCharWasCR = false;
-        for (int i = 0; i < len; i++) {
-            final char c = str.charAt(i);
+        for (final char c : str.toCharArray()) {
             if (c == delim) { // can't put the non-constant delim into a case
                 buf.append('\\').append(c);
                 lastCharWasCR = false;
@@ -2422,11 +2414,10 @@ public class Javadoc extends Task {
             final File baseDir = ds.getDir(getProject());
             log("scanning " + baseDir + " for packages.", Project.MSG_DEBUG);
             final DirectoryScanner dsc = ds.getDirectoryScanner(getProject());
-            final String[] dirs = dsc.getIncludedDirectories();
             boolean containsPackages = false;
-            for (int i = 0; i < dirs.length; i++) {
+            for (String dir : dsc.getIncludedDirectories()) {
                 // are there any java files in this directory?
-                final File pd = new File(baseDir, dirs[i]);
+                final File pd = new File(baseDir, dir);
                 final String[] files = pd.list(new FilenameFilter () {
                         public boolean accept(final File dir1, final String name) {
                             return name.endsWith(".java")
@@ -2436,7 +2427,7 @@ public class Javadoc extends Task {
                     });
 
                 if (files.length > 0) {
-                    if ("".equals(dirs[i])) {
+                    if ("".equals(dir)) {
                         log(baseDir
                             + " contains source files in the default package,"
                             + " you must specify them as source files"
@@ -2445,7 +2436,7 @@ public class Javadoc extends Task {
                     } else {
                         containsPackages = true;
                         final String packageName =
-                            dirs[i].replace(File.separatorChar, '.');
+                                dir.replace(File.separatorChar, '.');
                         if (!addedPackages.contains(packageName)) {
                             addedPackages.add(packageName);
                             pn.addElement(packageName);
@@ -2525,7 +2516,7 @@ public class Javadoc extends Task {
 
         // check if file may be vulnerable because it was not
         // patched with "validURL(url)":
-        if (fileContents.indexOf("function validURL(url) {") < 0) {
+        if (!fileContents.contains("function validURL(url) {")) {
             // we need to patch the file!
             final String patchedFileContents = patchContent(fileContents, fixData);
             if (!patchedFileContents.equals(fileContents)) {
