@@ -39,7 +39,9 @@ import org.apache.tools.ant.BuildException;
 import org.apache.tools.ant.DirectoryScanner;
 import org.apache.tools.ant.DynamicConfigurator;
 import org.apache.tools.ant.Project;
+import org.apache.tools.ant.ProjectComponent;
 import org.apache.tools.ant.PropertyHelper;
+import org.apache.tools.ant.taskdefs.optional.TraXLiaison;
 import org.apache.tools.ant.types.CommandlineJava;
 import org.apache.tools.ant.types.Environment;
 import org.apache.tools.ant.types.Mapper;
@@ -53,9 +55,11 @@ import org.apache.tools.ant.types.resources.FileProvider;
 import org.apache.tools.ant.types.resources.FileResource;
 import org.apache.tools.ant.types.resources.Resources;
 import org.apache.tools.ant.types.resources.Union;
+import org.apache.tools.ant.util.ClasspathUtils;
 import org.apache.tools.ant.util.FileNameMapper;
 import org.apache.tools.ant.util.FileUtils;
 import org.apache.tools.ant.util.ResourceUtils;
+import org.apache.tools.ant.util.StringUtils;
 
 /**
  * Processes a set of XML documents via XSLT. This is
@@ -116,7 +120,7 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
     private boolean force = false;
 
     /** XSL output properties to be used */
-    private final Vector outputProperties = new Vector();
+    private final Vector<OutputProperty> outputProperties = new Vector<OutputProperty>();
 
     /** for resolving entities such as dtds */
     private final XMLCatalog xmlCatalog = new XMLCatalog();
@@ -604,6 +608,7 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
     /**
      * Whether to suppress warning messages of the processor.
      *
+     * @param b boolean
      * @since Ant 1.8.0
      */
     public void setSuppressWarnings(final boolean b) {
@@ -613,6 +618,7 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
     /**
      * Whether to suppress warning messages of the processor.
      *
+     * @return boolean
      * @since Ant 1.8.0
      */
     public boolean getSuppressWarnings() {
@@ -622,6 +628,7 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
     /**
      * Whether transformation errors should make the build fail.
      *
+     * @param b boolean
      * @since Ant 1.8.0
      */
     public void setFailOnTransformationError(final boolean b) {
@@ -631,6 +638,7 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
     /**
      * Whether any errors should make the build fail.
      *
+     * @param b boolean
      * @since Ant 1.8.0
      */
     public void setFailOnError(final boolean b) {
@@ -640,6 +648,7 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
     /**
      * Whether the build should fail if the nested resource collection is empty.
      *
+     * @param b boolean
      * @since Ant 1.8.0
      */
     public void setFailOnNoResources(final boolean b) {
@@ -649,6 +658,7 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
     /**
      * A system property to set during transformation.
      *
+     * @param sysp Environment.Variable
      * @since Ant 1.8.0
      */
     public void addSysproperty(final Environment.Variable sysp) {
@@ -658,6 +668,7 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
     /**
      * A set of system properties to set during transformation.
      *
+     * @param sysp PropertySet
      * @since Ant 1.8.0
      */
     public void addSyspropertyset(final PropertySet sysp) {
@@ -671,6 +682,7 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
      * processor other than trax or if the Transformer is not Xalan2's
      * transformer implementation.</p>
      *
+     * @return TraceConfiguration
      * @since Ant 1.8.0
      */
     public TraceConfiguration createTrace() {
@@ -685,6 +697,7 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
     /**
      * Configuration for Xalan2 traces.
      *
+     * @return TraceConfiguration
      * @since Ant 1.8.0
      */
     public TraceConfiguration getTraceConfiguration() {
@@ -701,7 +714,7 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
      */
     private void resolveProcessor(final String proc) throws Exception {
         if (proc.equals(PROCESSOR_TRAX)) {
-            liaison = new org.apache.tools.ant.taskdefs.optional.TraXLiaison();
+            liaison = new TraXLiaison();
         } else {
             //anything else is a classname
             final Class clazz = loadClass(proc);
@@ -716,9 +729,8 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
      * As a side effect, the loader is set as the thread context classloader
      * @param classname the name of the class to load.
      * @return the requested class.
-     * @exception Exception if the class could not be loaded.
      */
-    private Class loadClass(final String classname) throws Exception {
+    private Class loadClass(final String classname) throws ClassNotFoundException {
         setupLoader();
         if (loader == null) {
             return Class.forName(classname);
@@ -750,7 +762,7 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
 
     /**
      * specifies a single XML document to be styled. Should be used
-     * with the <tt>out</tt> attribute; ; required if <tt>out</tt> is set
+     * with the <tt>out</tt> attribute; required if <tt>out</tt> is set
      *
      * @param inFile the input file
      */
@@ -829,7 +841,7 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
             if (outFileName == null || outFileName.length == 0) {
                 log("Skipping " + inFile + " it cannot get mapped to output.", Project.MSG_VERBOSE);
                 return;
-            } else if (outFileName == null || outFileName.length > 1) {
+            } else if (outFileName.length > 1) {
                 log("Skipping " + inFile + " its mapping is ambiguos.", Project.MSG_VERBOSE);
                 return;
             }
@@ -928,7 +940,7 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
      * Get an enumeration on the outputproperties.
      * @return the outputproperties
      */
-    public Enumeration getOutputProperties() {
+    public Enumeration<OutputProperty> getOutputProperties() {
         return outputProperties.elements();
     }
 
@@ -950,7 +962,7 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
                 try {
                     resolveProcessor(PROCESSOR_TRAX);
                 } catch (final Throwable e1) {
-                    e1.printStackTrace();
+                    log(StringUtils.getStackTrace(e1), Project.MSG_ERR);
                     handleError(e1);
                 }
             }
@@ -1018,6 +1030,7 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
         }
 
         /**
+         * @param type String
          * @see ParamType
          * @since Ant 1.9.3
          */
@@ -1053,6 +1066,7 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
         }
 
         /**
+         * @return String
          * @see ParamType
          * @since Ant 1.9.3
          */
@@ -1297,10 +1311,10 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
                 if (p.shouldUse()) {
                     final Object evaluatedParam = evaluateParam(p);
                     if (liaison instanceof XSLTLiaison4) {
-                        ((XSLTLiaison4)liaison).addParam(p.getName(), evaluatedParam);
+                        ((XSLTLiaison4) liaison).addParam(p.getName(), evaluatedParam);
                     } else {
                         if (evaluatedParam == null || evaluatedParam instanceof String) {
-                            liaison.addParam(p.getName(), (String)evaluatedParam);
+                            liaison.addParam(p.getName(), (String) evaluatedParam);
                         } else {
                             log("XSLTLiaison '" + liaison.getClass().getName()
                                     + "' supports only String parameters. Converting parameter '" + p.getName()
@@ -1377,7 +1391,7 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
      * @since Ant 1.7
      */
     private void setLiaisonDynamicFileParameters(
-        final XSLTLiaison liaison, final File inFile) throws Exception {
+        final XSLTLiaison liaison, final File inFile) throws Exception { //NOSONAR
         if (fileNameParameter != null) {
             liaison.addParam(fileNameParameter, inFile.getName());
         }
@@ -1385,7 +1399,7 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
             final String fileName = FileUtils.getRelativePath(baseDir, inFile);
             final File file = new File(fileName);
             // Give always a slash as file separator, so the stylesheet could be sure about that
-            // Use '.' so a dir+"/"+name would not result in an absolute path
+            // Use '.' so a dir + "/" + name would not result in an absolute path
             liaison.addParam(fileDirParameter, file.getParent() != null ? file.getParent().replace(
                     '\\', '/') : ".");
         }
@@ -1409,6 +1423,7 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
      * Throws an exception with the given message if failOnError is
      * true, otherwise logs the message using the WARN level.
      *
+     * @param msg String
      * @since Ant 1.8.0
      */
     protected void handleError(final String msg) {
@@ -1424,6 +1439,7 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
      * failOnError is true, otherwise logs the message using the WARN
      * level.
      *
+     * @param ex Throwable
      * @since Ant 1.8.0
      */
     protected void handleError(final Throwable ex) {
@@ -1439,6 +1455,7 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
      * failOnError and failOnTransformationError are true, otherwise
      * logs the message using the WARN level.
      *
+     * @param ex Exception
      * @since Ant 1.8.0
      */
     protected void handleTransformationError(final Exception ex) {
@@ -1462,7 +1479,12 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
         /**
          * the list of factory attributes to use for TraXLiaison
          */
-        private final Vector attributes = new Vector();
+        private final List<Attribute> attributes = new ArrayList<Attribute>();
+
+        /**
+         * the list of factory features to use for TraXLiaison
+         */
+        private final List<Feature> features = new ArrayList<Feature>();
 
         /**
          * @return the name of the factory.
@@ -1484,15 +1506,34 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
          * @param attr the newly created factory attribute
          */
         public void addAttribute(final Attribute attr) {
-            attributes.addElement(attr);
+            attributes.add(attr);
         }
 
         /**
          * return the attribute elements.
          * @return the enumeration of attributes
          */
-        public Enumeration getAttributes() {
-            return attributes.elements();
+        public Enumeration<Attribute> getAttributes() {
+            return Collections.enumeration(attributes);
+        }
+
+        /**
+         * Create an instance of a factory feature.
+         * @param feature the newly created feature
+         * @since Ant 1.9.8
+         */
+        public void addFeature(final Feature feature) {
+            features.add(feature);
+        }
+
+        /**
+         * The configured features.
+         * @since Ant 1.9.8
+         *
+         * @return Iterable&lt;Feature&gt;
+         */
+        public Iterable<Feature> getFeatures() {
+            return features;
         }
 
         /**
@@ -1503,7 +1544,9 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
          *  <li>http://xml.apache.org/xalan/features/incremental (true|false) </li>
          * </ul>
          */
-        public static class Attribute implements DynamicConfigurator {
+        public static class Attribute
+            extends ProjectComponent
+            implements DynamicConfigurator {
 
             /** attribute name, mostly processor specific */
             private String name;
@@ -1519,7 +1562,7 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
             }
 
             /**
-             * @return the output property value.
+             * @return the attribute value.
              */
             public Object getValue() {
                 return value;
@@ -1560,11 +1603,61 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
                             this.value = value;
                         }
                     }
+                } else if ("valueref".equalsIgnoreCase(name)) {
+                    this.value = getProject().getReference(value);
+                } else if ("classloaderforpath".equalsIgnoreCase(name)) {
+                    this.value =
+                        ClasspathUtils.getClassLoaderForPath(getProject(),
+                                                             new Reference(getProject(),
+                                                                           value));
                 } else {
                     throw new BuildException("Unsupported attribute: " + name);
                 }
             }
         } // -- class Attribute
+
+        /**
+         * A feature for the TraX factory.
+         * @since Ant 1.9.8
+         */
+        public static class Feature {
+            private String name;
+            private boolean value;
+
+            public Feature() { }
+            public Feature(String name, boolean value) {
+                this.name = name;
+                this.value = value;
+            }
+
+            /**
+             * @param name the feature name.
+             */
+            public void setName(String name) {
+                this.name = name;
+            }
+
+            /**
+             * @param value the feature value.
+             */
+            public void setValue(boolean value) {
+                this.value = value;
+            }
+
+            /**
+             * @return the feature name.
+             */
+            public String getName() {
+                return name;
+            }
+
+            /**
+             * @return the feature value.
+             */
+            public boolean getValue() {
+                return value;
+            }
+        }
     } // -- class Factory
 
     /**
@@ -1601,6 +1694,8 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
         /**
          * Set to true if the listener is to print events that occur
          * as each node is 'executed' in the stylesheet.
+         *
+         * @param b boolean
          */
         public void setElements(final boolean b) {
             elements = b;
@@ -1609,6 +1704,8 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
         /**
          * True if the listener is to print events that occur as each
          * node is 'executed' in the stylesheet.
+         *
+         * @return boolean
          */
         public boolean getElements() {
             return elements;
@@ -1617,6 +1714,8 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
         /**
          * Set to true if the listener is to print information after
          * each extension event.
+         *
+         * @param b boolean
          */
         public void setExtension(final boolean b) {
             extension = b;
@@ -1625,6 +1724,8 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
         /**
          * True if the listener is to print information after each
          * extension event.
+         *
+         * @return boolean
          */
         public boolean getExtension() {
             return extension;
@@ -1633,6 +1734,8 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
         /**
          * Set to true if the listener is to print information after
          * each result-tree generation event.
+         *
+         * @param b boolean
          */
         public void setGeneration(final boolean b) {
             generation = b;
@@ -1641,6 +1744,8 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
         /**
          * True if the listener is to print information after each
          * result-tree generation event.
+         *
+         * @return boolean
          */
         public boolean getGeneration() {
             return generation;
@@ -1649,6 +1754,8 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
         /**
          * Set to true if the listener is to print information after
          * each selection event.
+         *
+         * @param b boolean
          */
         public void setSelection(final boolean b) {
             selection = b;
@@ -1657,6 +1764,8 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
         /**
          * True if the listener is to print information after each
          * selection event.
+         *
+         * @return boolean
          */
         public boolean getSelection() {
             return selection;
@@ -1665,6 +1774,8 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
         /**
          * Set to true if the listener is to print an event whenever a
          * template is invoked.
+         *
+         * @param b boolean
          */
         public void setTemplates(final boolean b) {
             templates = b;
@@ -1673,6 +1784,8 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
         /**
          * True if the listener is to print an event whenever a
          * template is invoked.
+         *
+         * @return boolean
          */
         public boolean getTemplates() {
             return templates;
@@ -1680,6 +1793,8 @@ public class XSLTProcess extends MatchingTask implements XSLTLogger {
 
         /**
          * The stream to write traces to.
+         *
+         * @return OutputStream
          */
         public java.io.OutputStream getOutputStream() {
             return new LogOutputStream(XSLTProcess.this);
