@@ -22,14 +22,14 @@ import java.io.BufferedWriter;
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.FileOutputStream;
-import java.io.InputStreamReader;
 import java.io.IOException;
 import java.io.InputStream;
+import java.io.InputStreamReader;
 import java.io.OutputStream;
 import java.io.OutputStreamWriter;
 import java.io.Reader;
 import java.io.Writer;
-import java.util.Iterator;
+
 import org.apache.tools.ant.BuildException;
 import org.apache.tools.ant.Project;
 import org.apache.tools.ant.Task;
@@ -213,7 +213,7 @@ public class ReplaceRegExp extends Task {
      * want to only replace the first occurrence of a regular expression on
      * each line, which is not easy to do when processing the file as a whole.
      * Defaults to <i>false</i>.
-     * 
+     *
      * @param byline the byline attribute as a string
      * @deprecated since 1.6.x.
      *             Use setByLine(boolean).
@@ -234,7 +234,7 @@ public class ReplaceRegExp extends Task {
      * want to only replace the first occurrence of a regular expression on
      * each line, which is not easy to do when processing the file as a whole.
      * Defaults to <i>false</i>.
-     * 
+     *
      * @param byline the byline attribute
      */
     public void setByLine(boolean byline) {
@@ -465,6 +465,7 @@ public class ReplaceRegExp extends Task {
      *
      * @throws BuildException is there is a problem in the task execution.
      */
+    @Override
     public void execute() throws BuildException {
         if (regex == null) {
             throw new BuildException("No expression to match.");
