@@ -101,7 +101,7 @@ public class ConstantPool {
         if (entry instanceof Utf8CPInfo) {
             Utf8CPInfo utf8Info = (Utf8CPInfo) entry;
 
-            utf8Indexes.put(utf8Info.getValue(), new Integer(index));
+            utf8Indexes.put(utf8Info.getValue(), Integer.valueOf(index));
         }
 
         return index;
