@@ -228,9 +228,8 @@ public class FilterSet extends DataType implements Cloneable {
         //silly hack to avoid stack overflow...
         if (!readingFiles) {
             readingFiles = true;
-            final int size = filtersFiles.size();
-            for (int i = 0; i < size; i++) {
-                readFiltersFromFile(filtersFiles.get(i));
+            for (File filtersFile : filtersFiles) {
+                readFiltersFromFile(filtersFile);
             }
             filtersFiles.clear();
             readingFiles = false;
@@ -617,8 +616,7 @@ public class FilterSet extends DataType implements Cloneable {
         }
         passedTokens.addElement(parent);
         String value = iReplaceTokens(line);
-        if (value.indexOf(beginToken) == -1 && !duplicateToken
-                && recurseDepth == 1) {
+        if (!value.contains(beginToken) && !duplicateToken && recurseDepth == 1) {
             passedTokens = null;
         } else if (duplicateToken) {
             // should always be the case...
