@@ -68,7 +68,7 @@ public class StatementWriter {
     private static final MethodCaller iteratorNextMethod = MethodCaller.newInterface(Iterator.class, "next");
     private static final MethodCaller iteratorHasNextMethod = MethodCaller.newInterface(Iterator.class, "hasNext");
     
-    private WriterController controller;
+    private final WriterController controller;
     public StatementWriter(WriterController controller) {
         this.controller = controller;
     }
@@ -94,6 +94,13 @@ public class StatementWriter {
         }
         compileStack.pop();
 
+        // GROOVY-7647
+        if (block.getLastLineNumber() > 0) {
+            MethodVisitor mv = controller.getMethodVisitor();
+            Label blockEnd = new Label(); mv.visitLabel(blockEnd);
+            mv.visitLineNumber(block.getLastLineNumber(), blockEnd);
+        }
+
         controller.getOperandStack().popDownTo(mark);
     }
 
