@@ -18,8 +18,19 @@
  */
 package org.codehaus.groovy.runtime;
 
-import groovy.lang.*;
-
+import groovy.lang.Closure;
+import groovy.lang.EmptyRange;
+import groovy.lang.GroovyInterceptable;
+import groovy.lang.GroovyObject;
+import groovy.lang.GroovyRuntimeException;
+import groovy.lang.GroovySystem;
+import groovy.lang.IntRange;
+import groovy.lang.MetaClass;
+import groovy.lang.MissingMethodException;
+import groovy.lang.MissingPropertyException;
+import groovy.lang.NumberRange;
+import groovy.lang.ObjectRange;
+import groovy.lang.Tuple;
 import org.codehaus.groovy.runtime.metaclass.MissingMethodExceptionNoStack;
 import org.codehaus.groovy.runtime.metaclass.MissingMethodExecutionFailed;
 import org.codehaus.groovy.runtime.metaclass.MissingPropertyExceptionNoStack;
@@ -28,14 +39,15 @@ import org.codehaus.groovy.runtime.wrappers.GroovyObjectWrapper;
 import org.codehaus.groovy.runtime.wrappers.PojoWrapper;
 import org.codehaus.groovy.runtime.wrappers.Wrapper;
 
-import java.util.*;
+import java.util.ArrayList;
+import java.util.Iterator;
+import java.util.List;
+import java.util.Map;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
 /**
  * A static helper class to interface bytecode and runtime
- *
- * @author Jochen Theodorou
  */
 public class ScriptBytecodeAdapter {
     public static final Object[] EMPTY_ARGS = {};
@@ -631,10 +643,13 @@ public class ScriptBytecodeAdapter {
                 return new IntRange(inclusive, ifrom, ito);
             } // else fall through for EmptyRange
         }
+        if (!inclusive && compareEqual(from, to)) {
+            return new EmptyRange((Comparable) from);
+        }
+        if (from instanceof Number && to instanceof Number) {
+            return new NumberRange(comparableNumber((Number) from), comparableNumber((Number) to), inclusive);
+        }
         if (!inclusive) {
-            if (compareEqual(from, to)) {
-                return new EmptyRange((Comparable) from);
-            }
             if (compareGreaterThan(from, to)) {
                 to = invokeMethod0(ScriptBytecodeAdapter.class, to, "next");
             } else {
@@ -645,6 +660,11 @@ public class ScriptBytecodeAdapter {
         return new ObjectRange((Comparable) from, (Comparable) to);
     }
 
+    @SuppressWarnings("unchecked")
+    private static <T extends Number & Comparable> T comparableNumber(Number n) {
+        return (T) n;
+    }
+
     //assert
     public static void assertFailed(Object expression, Object message) {
         InvokerHelper.assertFailed(expression, message);
@@ -759,7 +779,7 @@ public class ScriptBytecodeAdapter {
 
     //regexpr
     public static Pattern regexPattern(Object regex) {
-        return StringGroovyMethods.bitwiseNegate(regex.toString());
+        return StringGroovyMethods.bitwiseNegate((CharSequence)regex.toString());
     }
 
     public static Matcher findRegex(Object left, Object right) throws Throwable {
@@ -787,7 +807,11 @@ public class ScriptBytecodeAdapter {
             } else if (value.getClass().isArray()) {
                 ret.addAll(DefaultTypeTransformation.primitiveArrayToList(value));
             } else {
-                throw new IllegalArgumentException("cannot spread the type " + value.getClass().getName() + " with value " + value);
+                String error = "cannot spread the type " + value.getClass().getName() + " with value " + value;
+                if (value instanceof Map) {
+                    error += ", did you mean to use the spread-map operator instead?";
+                }
+                throw new IllegalArgumentException(error);
             }
             spreadPos++;
         }
