@@ -1,15 +1,24 @@
-/*******************************************************************************
- * Copyright (c) 2010, 2014 Sonatype, Inc.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
- *
- * Contributors:
- *    Sonatype, Inc. - initial API and implementation
- *******************************************************************************/
 package org.eclipse.aether.internal.impl;
 
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ * 
+ *  http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+
 import java.io.File;
 import java.io.IOException;
 import java.util.ArrayList;
@@ -17,6 +26,7 @@ import java.util.Arrays;
 import java.util.Collection;
 import java.util.IdentityHashMap;
 import java.util.List;
+import static java.util.Objects.requireNonNull;
 import java.util.Set;
 
 import javax.inject.Inject;
@@ -134,61 +144,37 @@ public class DefaultDeployer
 
     public DefaultDeployer setFileProcessor( FileProcessor fileProcessor )
     {
-        if ( fileProcessor == null )
-        {
-            throw new IllegalArgumentException( "file processor has not been specified" );
-        }
-        this.fileProcessor = fileProcessor;
+        this.fileProcessor = requireNonNull( fileProcessor, "file processor cannot be null" );
         return this;
     }
 
     public DefaultDeployer setRepositoryEventDispatcher( RepositoryEventDispatcher repositoryEventDispatcher )
     {
-        if ( repositoryEventDispatcher == null )
-        {
-            throw new IllegalArgumentException( "repository event dispatcher has not been specified" );
-        }
-        this.repositoryEventDispatcher = repositoryEventDispatcher;
+        this.repositoryEventDispatcher = requireNonNull( repositoryEventDispatcher, "repository event dispatcher cannot be null" );
         return this;
     }
 
     public DefaultDeployer setRepositoryConnectorProvider( RepositoryConnectorProvider repositoryConnectorProvider )
     {
-        if ( repositoryConnectorProvider == null )
-        {
-            throw new IllegalArgumentException( "repository connector provider has not been specified" );
-        }
-        this.repositoryConnectorProvider = repositoryConnectorProvider;
+        this.repositoryConnectorProvider = requireNonNull( repositoryConnectorProvider, "repository connector provider cannot be null" );
         return this;
     }
 
     public DefaultDeployer setRemoteRepositoryManager( RemoteRepositoryManager remoteRepositoryManager )
     {
-        if ( remoteRepositoryManager == null )
-        {
-            throw new IllegalArgumentException( "remote repository manager has not been specified" );
-        }
-        this.remoteRepositoryManager = remoteRepositoryManager;
+        this.remoteRepositoryManager = requireNonNull( remoteRepositoryManager, "remote repository provider cannot be null" );
         return this;
     }
 
     public DefaultDeployer setUpdateCheckManager( UpdateCheckManager updateCheckManager )
     {
-        if ( updateCheckManager == null )
-        {
-            throw new IllegalArgumentException( "update check manager has not been specified" );
-        }
-        this.updateCheckManager = updateCheckManager;
+        this.updateCheckManager = requireNonNull( updateCheckManager, "update check manager cannot be null" );
         return this;
     }
 
     public DefaultDeployer addMetadataGeneratorFactory( MetadataGeneratorFactory factory )
     {
-        if ( factory == null )
-        {
-            throw new IllegalArgumentException( "metadata generator factory has not been specified" );
-        }
-        metadataFactories.add( factory );
+        metadataFactories.add( requireNonNull( factory, "metadata generator factory cannot be null" ) );
         return this;
     }
 
@@ -207,21 +193,13 @@ public class DefaultDeployer
 
     public DefaultDeployer setSyncContextFactory( SyncContextFactory syncContextFactory )
     {
-        if ( syncContextFactory == null )
-        {
-            throw new IllegalArgumentException( "sync context factory has not been specified" );
-        }
-        this.syncContextFactory = syncContextFactory;
+        this.syncContextFactory = requireNonNull( syncContextFactory, "sync context factory cannot be null" );
         return this;
     }
 
     public DefaultDeployer setOfflineController( OfflineController offlineController )
     {
-        if ( offlineController == null )
-        {
-            throw new IllegalArgumentException( "offline controller has not been specified" );
-        }
-        this.offlineController = offlineController;
+        this.offlineController = requireNonNull( offlineController, "offline controller cannot be null" );
         return this;
     }
 
@@ -506,7 +484,7 @@ public class DefaultDeployer
 
         private final RepositoryEventDispatcher dispatcher;
 
-        public EventCatapult( RepositorySystemSession session, RequestTrace trace, RemoteRepository repository,
+        EventCatapult( RepositorySystemSession session, RequestTrace trace, RemoteRepository repository,
                               RepositoryEventDispatcher dispatcher )
         {
             this.session = session;
@@ -581,7 +559,7 @@ public class DefaultDeployer
 
         private final ArtifactUpload transfer;
 
-        public ArtifactUploadListener( EventCatapult catapult, ArtifactUpload transfer, Logger logger )
+        ArtifactUploadListener( EventCatapult catapult, ArtifactUpload transfer, Logger logger )
         {
             super( catapult.getSession(), logger );
             this.catapult = catapult;
@@ -620,7 +598,7 @@ public class DefaultDeployer
 
         private final MetadataUpload transfer;
 
-        public MetadataUploadListener( EventCatapult catapult, MetadataUpload transfer, Logger logger )
+        MetadataUploadListener( EventCatapult catapult, MetadataUpload transfer, Logger logger )
         {
             super( catapult.getSession(), logger );
             this.catapult = catapult;
