@@ -1,15 +1,24 @@
-/*******************************************************************************
- * Copyright (c) 2012, 2014 Sonatype, Inc.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
- *
- * Contributors:
- *    Sonatype, Inc. - initial API and implementation
- *******************************************************************************/
 package org.eclipse.aether.util.graph.transformer;
 
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ * 
+ *  http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
@@ -21,6 +30,7 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.ListIterator;
 import java.util.Map;
+import static java.util.Objects.requireNonNull;
 
 import org.eclipse.aether.RepositoryException;
 import org.eclipse.aether.RepositorySystemSession;
@@ -99,26 +109,10 @@ public final class ConflictResolver
     public ConflictResolver( VersionSelector versionSelector, ScopeSelector scopeSelector,
                              OptionalitySelector optionalitySelector, ScopeDeriver scopeDeriver )
     {
-        if ( versionSelector == null )
-        {
-            throw new IllegalArgumentException( "version selector not specified" );
-        }
-        this.versionSelector = versionSelector;
-        if ( scopeSelector == null )
-        {
-            throw new IllegalArgumentException( "scope selector not specified" );
-        }
-        this.scopeSelector = scopeSelector;
-        if ( scopeDeriver == null )
-        {
-            throw new IllegalArgumentException( "scope deriver not specified" );
-        }
-        this.scopeDeriver = scopeDeriver;
-        if ( optionalitySelector == null )
-        {
-            throw new IllegalArgumentException( "optionality selector not specified" );
-        }
-        this.optionalitySelector = optionalitySelector;
+        this.versionSelector = requireNonNull( versionSelector, "version selector cannot be null" );
+        this.scopeSelector = requireNonNull( scopeSelector, "scope selector cannot be null" );
+        this.optionalitySelector = requireNonNull( optionalitySelector, "optionality selector cannot be null" );
+        this.scopeDeriver = requireNonNull( scopeDeriver, "scope deriver cannot be null" );
     }
 
     public DependencyNode transformGraph( DependencyNode node, DependencyGraphTransformationContext context )
@@ -135,7 +129,7 @@ public final class ConflictResolver
 
         @SuppressWarnings( "unchecked" )
         Map<String, Object> stats = (Map<String, Object>) context.get( TransformationContextKeys.STATS );
-        long time1 = System.currentTimeMillis();
+        long time1 = System.nanoTime();
 
         @SuppressWarnings( "unchecked" )
         Collection<Collection<?>> conflictIdCycles =
@@ -222,7 +216,7 @@ public final class ConflictResolver
 
         if ( stats != null )
         {
-            long time2 = System.currentTimeMillis();
+            long time2 = System.nanoTime();
             stats.put( "ConflictResolver.totalTime", time2 - time1 );
             stats.put( "ConflictResolver.conflictItemCount", state.totalConflictItems );
         }
@@ -292,7 +286,7 @@ public final class ConflictResolver
                         loser.setData( NODE_DATA_ORIGINAL_SCOPE, loser.getDependency().getScope() );
                         loser.setData( NODE_DATA_ORIGINAL_OPTIONALITY, loser.getDependency().isOptional() );
                         loser.setScope( item.getScopes().iterator().next() );
-                        loser.setChildren( Collections.<DependencyNode> emptyList() );
+                        loser.setChildren( Collections.<DependencyNode>emptyList() );
                         childIt.set( loser );
                     }
                     else
@@ -1148,7 +1142,7 @@ public final class ConflictResolver
      * <p>
      * <strong>Note:</strong> Implementations must be stateless.
      */
-    public static abstract class VersionSelector
+    public abstract static class VersionSelector
     {
 
         /**
@@ -1192,7 +1186,7 @@ public final class ConflictResolver
      * <p>
      * <strong>Note:</strong> Implementations must be stateless.
      */
-    public static abstract class ScopeSelector
+    public abstract static class ScopeSelector
     {
 
         /**
@@ -1235,7 +1229,7 @@ public final class ConflictResolver
      * <p>
      * <strong>Note:</strong> Implementations must be stateless.
      */
-    public static abstract class ScopeDeriver
+    public abstract static class ScopeDeriver
     {
 
         /**
@@ -1278,7 +1272,7 @@ public final class ConflictResolver
      * <p>
      * <strong>Note:</strong> Implementations must be stateless.
      */
-    public static abstract class OptionalitySelector
+    public abstract static class OptionalitySelector
     {
 
         /**
