@@ -16,23 +16,19 @@
 
 package org.gradle.api.internal.tasks;
 
-import org.apache.commons.lang.StringUtils;
 import org.gradle.api.GradleException;
+import org.gradle.api.internal.TaskOutputCachingState;
 import org.gradle.api.tasks.TaskState;
 
+import javax.annotation.Nullable;
+
 public class TaskStateInternal implements TaskState {
     private boolean executing;
-    private boolean executed;
+    private boolean actionable = true;
     private boolean didWork;
     private Throwable failure;
-    private String description;
-    private String skippedMessage;
-    private boolean skipped;
-    private boolean upToDate;
-
-    public TaskStateInternal(String description) {
-        this.description = description;
-    }
+    private TaskOutputCachingState taskOutputCaching = DefaultTaskOutputCachingState.disabled(TaskOutputCachingDisabledReasonCategory.UNKNOWN, "Cacheability was not determined");
+    private TaskExecutionOutcome outcome;
 
     public boolean getDidWork() {
         return didWork;
@@ -43,51 +39,35 @@ public class TaskStateInternal implements TaskState {
     }
 
     public boolean getExecuted() {
-        return executed;
+        return outcome != null;
     }
 
-    /**
-     * Marks this task as executed. This method can be called multiple times.
-     */
-    public void executed() {
-        this.executed = true;
+    public boolean isConfigurable() {
+        return !getExecuted() && !executing;
     }
 
-    public boolean isConfigurable(){
-        return !executed && !executing;
+    @Nullable
+    public TaskExecutionOutcome getOutcome() {
+        return outcome;
+    }
+
+    public void setOutcome(TaskExecutionOutcome outcome) {
+        assert this.outcome == null;
+        this.outcome = outcome;
     }
 
     /**
      * Marks this task as executed with the given failure. This method can be called at most once.
      */
-    public void executed(Throwable failure) {
+    public void setOutcome(Throwable failure) {
         assert this.failure == null;
-        this.executed = true;
+        this.outcome = TaskExecutionOutcome.EXECUTED;
         this.failure = failure;
     }
 
-    /**
-     * Marks this task as skipped.
-     */
-    public void skipped(String skipMessage) {
-        this.executed = true;
-        this.skipped = true;
-        this.skippedMessage = skipMessage;
-    }
-
-    /**
-     * Marks this task as up-to-date.
-     */
-    public void upToDate() {
-        upToDate("UP-TO-DATE");
-    }
-
-    /**
-     * Marks this task as up-to-date with a custom message.
-     */
-    public void upToDate(String skipMessage) {
-        skipped(skipMessage);
-        upToDate = true;
+    public void setAborted(String message) {
+        this.outcome = TaskExecutionOutcome.EXECUTED;
+        this.failure = new GradleException(message);
     }
 
     public boolean getExecuting() {
@@ -98,6 +78,14 @@ public class TaskStateInternal implements TaskState {
         this.executing = executing;
     }
 
+    public void setTaskOutputCaching(TaskOutputCachingState taskOutputCaching) {
+        this.taskOutputCaching = taskOutputCaching;
+    }
+
+    public TaskOutputCachingState getTaskOutputCaching() {
+        return taskOutputCaching;
+    }
+
     public Throwable getFailure() {
         return failure;
     }
@@ -112,18 +100,36 @@ public class TaskStateInternal implements TaskState {
         if (failure instanceof Error) {
             throw (Error) failure;
         }
-        throw new GradleException(String.format("%s failed with an exception.", StringUtils.capitalize(description)), failure);
+        throw new GradleException("Task failed with an exception.", failure);
     }
 
     public boolean getSkipped() {
-        return skipped;
+        return outcome != null && outcome.isSkipped();
     }
 
     public String getSkipMessage() {
-        return skippedMessage;
+        return outcome != null ? outcome.getMessage() : null;
     }
 
     public boolean getUpToDate() {
-        return upToDate;
+        return outcome != null && outcome.isUpToDate();
     }
+
+    @Override
+    public boolean getNoSource() {
+        return outcome == TaskExecutionOutcome.NO_SOURCE;
+    }
+
+    public boolean isFromCache() {
+        return outcome == TaskExecutionOutcome.FROM_CACHE;
+    }
+
+    public boolean isActionable() {
+        return actionable;
+    }
+
+    public void setActionable(boolean actionable) {
+        this.actionable = actionable;
+    }
+
 }
