@@ -18,16 +18,18 @@
  */
 package groovy.lang;
 
-import groovy.ui.GroovyMain;
 import groovy.security.GroovyCodeSourcePermission;
-
+import groovy.ui.GroovyMain;
+import org.apache.groovy.plugin.GroovyRunner;
+import org.apache.groovy.plugin.GroovyRunnerRegistry;
 import org.codehaus.groovy.control.CompilationFailedException;
 import org.codehaus.groovy.control.CompilerConfiguration;
-import org.codehaus.groovy.plugin.GroovyRunner;
 import org.codehaus.groovy.runtime.InvokerHelper;
 import org.codehaus.groovy.runtime.InvokerInvocationException;
 
-import java.io.*;
+import java.io.File;
+import java.io.IOException;
+import java.io.Reader;
 import java.lang.reflect.Constructor;
 import java.lang.reflect.InvocationTargetException;
 import java.net.URI;
@@ -36,22 +38,21 @@ import java.security.PrivilegedAction;
 import java.security.PrivilegedActionException;
 import java.security.PrivilegedExceptionAction;
 import java.util.List;
-import java.util.Map;
+import java.util.concurrent.atomic.AtomicInteger;
+
+import static org.codehaus.groovy.runtime.InvokerHelper.MAIN_METHOD_NAME;
 
 /**
  * Represents a groovy shell capable of running arbitrary groovy scripts
- *
- * @author <a href="mailto:james@coredevelopers.net">James Strachan</a>
- * @author Guillaume Laforge
- * @author Paul King
  */
 public class GroovyShell extends GroovyObjectSupport {
 
     public static final String DEFAULT_CODE_BASE = "/groovy/shell";
+    private static final String[] EMPTY_STRING_ARRAY = new String[0];
 
-    private Binding context;
-    private int counter;
-    private CompilerConfiguration config;
+    private final Binding context;
+    private final AtomicInteger counter = new AtomicInteger(0);
+    private final CompilerConfiguration config;
     private GroovyClassLoader loader;
 
     public static void main(String[] args) {
@@ -153,8 +154,7 @@ public class GroovyShell extends GroovyObjectSupport {
      * @param list       the command line arguments to pass in
      */
     public Object run(File scriptFile, List list) throws CompilationFailedException, IOException {
-        String[] args = new String[list.size()];
-        return run(scriptFile, (String[]) list.toArray(args));
+        return run(scriptFile, (String[]) list.toArray(EMPTY_STRING_ARRAY));
     }
 
     /**
@@ -165,9 +165,7 @@ public class GroovyShell extends GroovyObjectSupport {
      * @param list       the command line arguments to pass in
      */
     public Object run(String scriptText, String fileName, List list) throws CompilationFailedException {
-        String[] args = new String[list.size()];
-        list.toArray(args);
-        return run(scriptText, fileName, args);
+        return run(scriptText, fileName, (String[]) list.toArray(EMPTY_STRING_ARRAY));
     }
 
     /**
@@ -258,69 +256,42 @@ public class GroovyShell extends GroovyObjectSupport {
         if (Script.class.isAssignableFrom(scriptClass)) {
             // treat it just like a script if it is one
             try {
-                Constructor constructor = scriptClass.getConstructor(Binding.class);
-                Script script = (Script) constructor.newInstance(context);
+                Script script = InvokerHelper.newScript(scriptClass, context);
                 return script.run();
-            } catch (InstantiationException e) {
+            } catch (InstantiationException | InvocationTargetException | IllegalAccessException e) {
                 // ignore instantiation errors,, try to do main
-            } catch (IllegalAccessException e) {
-               // ignore instantiation errors, try to do main
-            } catch (NoSuchMethodException e) {
-                try {
-                    // Fallback for non-standard "Scripts" that don't have contextual constructor.
-                    Script script = (Script) scriptClass.newInstance();
-                    script.setBinding(context);
-                    return script.run();
-                } catch (InstantiationException e1) {
-                    // ignore instantiation errors, try to do main
-                } catch (IllegalAccessException e1) {
-                    // ignore instantiation errors, try to do main
-                }
-            } catch (InvocationTargetException e) {
-                // ignore instantiation errors, try to do main
             }
         }
         try {
             // let's find a main method
-            scriptClass.getMethod("main", String[].class);
+            scriptClass.getMethod(MAIN_METHOD_NAME, String[].class);
             // if that main method exist, invoke it
-            return InvokerHelper.invokeMethod(scriptClass, "main", new Object[]{args});
+            return InvokerHelper.invokeMethod(scriptClass, MAIN_METHOD_NAME, new Object[]{args});
         } catch (NoSuchMethodException e) {
             // if it implements Runnable, try to instantiate it
             if (Runnable.class.isAssignableFrom(scriptClass)) {
                 return runRunnable(scriptClass, args);
             }
-            // if it's a JUnit 3.8.x test, run it with an appropriate runner
-            if (isJUnit3Test(scriptClass)) {
-                return runJUnit3Test(scriptClass);
-            }
-            // if it's a JUnit 3.8.x test suite, run it with an appropriate runner
-            if (isJUnit3TestSuite(scriptClass)) {
-                return runJUnit3TestSuite(scriptClass);
-            }
-            // if it's a JUnit 4.x test, run it with an appropriate runner
-            if (isJUnit4Test(scriptClass)) {
-                return runJUnit4Test(scriptClass);
-            }
-            for (Map.Entry<String, GroovyRunner> entry : GroovySystem.RUNNER_REGISTRY.entrySet()) {
-                GroovyRunner runner = entry.getValue();
-                if (runner != null && runner.canRun(scriptClass, this.loader)) {
+            GroovyRunnerRegistry runnerRegistry = GroovyRunnerRegistry.getInstance();
+            for (GroovyRunner runner : runnerRegistry) {
+                if (runner.canRun(scriptClass, this.loader)) {
                     return runner.run(scriptClass, this.loader);
                 }
             }
-            String message = "This script or class could not be run.\n" +
+            StringBuilder message = new StringBuilder("This script or class could not be run.\n" +
                     "It should either:\n" +
                     "- have a main method,\n" +
                     "- be a JUnit test or extend GroovyTestCase,\n" +
                     "- implement the Runnable interface,\n" +
-                    "- or be compatible with a registered script runner. Known runners:\n";
-            if (GroovySystem.RUNNER_REGISTRY.isEmpty()) {
-                message += "  * <none>";
+                    "- or be compatible with a registered script runner. Known runners:\n");
+            if (runnerRegistry.isEmpty()) {
+                message.append("  * <none>");
+            } else {
+                for (String key : runnerRegistry.keySet()) {
+                    message.append("  * ").append(key).append("\n");
+                }
             }
-            for (Map.Entry<String, GroovyRunner> entry : GroovySystem.RUNNER_REGISTRY.entrySet()) {
-                message += "  * " + entry.getKey() + "\n";
-            }
-            throw new GroovyRuntimeException(message);
+            throw new GroovyRuntimeException(message.toString());
         }
     }
 
@@ -328,9 +299,10 @@ public class GroovyShell extends GroovyObjectSupport {
         Constructor constructor = null;
         Runnable runnable = null;
         Throwable reason = null;
+
         try {
             // first, fetch the constructor taking String[] as parameter
-            constructor = scriptClass.getConstructor((new String[]{}).getClass());
+            constructor = scriptClass.getConstructor(String[].class);
             try {
                 // instantiate a runnable and run it
                 runnable = (Runnable) constructor.newInstance(new Object[]{args});
@@ -361,126 +333,6 @@ public class GroovyShell extends GroovyObjectSupport {
         return null;
     }
 
-    /**
-     * Run the specified class extending TestCase as a unit test.
-     * This is done through reflection, to avoid adding a dependency to the JUnit framework.
-     * Otherwise, developers embedding Groovy and using GroovyShell to load/parse/compile
-     * groovy scripts and classes would have to add another dependency on their classpath.
-     *
-     * @param scriptClass the class to be run as a unit test
-     */
-    private static Object runJUnit3Test(Class scriptClass) {
-        try {
-            Object testSuite = InvokerHelper.invokeConstructorOf("junit.framework.TestSuite", new Object[]{scriptClass});
-            return InvokerHelper.invokeStaticMethod("junit.textui.TestRunner", "run", new Object[]{testSuite});
-        } catch (ClassNotFoundException e) {
-            throw new GroovyRuntimeException("Failed to run the unit test. JUnit is not on the Classpath.", e);
-        }
-    }
-
-    /**
-     * Run the specified class extending TestSuite as a unit test.
-     * This is done through reflection, to avoid adding a dependency to the JUnit framework.
-     * Otherwise, developers embedding Groovy and using GroovyShell to load/parse/compile
-     * groovy scripts and classes would have to add another dependency on their classpath.
-     *
-     * @param scriptClass the class to be run as a unit test
-     */
-    private static Object runJUnit3TestSuite(Class scriptClass) {
-        try {
-            Object testSuite = InvokerHelper.invokeStaticMethod(scriptClass, "suite", new Object[]{});
-            return InvokerHelper.invokeStaticMethod("junit.textui.TestRunner", "run", new Object[]{testSuite});
-        } catch (ClassNotFoundException e) {
-            throw new GroovyRuntimeException("Failed to run the unit test. JUnit is not on the Classpath.", e);
-        }
-    }
-
-    private Object runJUnit4Test(Class scriptClass) {
-        try {
-            return InvokerHelper.invokeStaticMethod("org.codehaus.groovy.vmplugin.v5.JUnit4Utils",
-                    "realRunJUnit4Test", new Object[]{scriptClass, this.loader});
-        } catch (ClassNotFoundException e) {
-            throw new GroovyRuntimeException("Failed to run the JUnit 4 test.", e);
-        }
-    }
-
-    /**
-     * Utility method to check through reflection if the class appears to be a
-     * JUnit 3.8.x test, i.e. checks if it extends JUnit 3.8.x's TestCase.
-     *
-     * @param scriptClass the class we want to check
-     * @return true if the class appears to be a test
-     */
-    private boolean isJUnit3Test(Class scriptClass) {
-        // check if the parsed class is a GroovyTestCase,
-        // so that it is possible to run it as a JUnit test
-        boolean isUnitTestCase = false;
-        try {
-            try {
-                Class testCaseClass = this.loader.loadClass("junit.framework.TestCase");
-                // if scriptClass extends testCaseClass
-                if (testCaseClass.isAssignableFrom(scriptClass)) {
-                    isUnitTestCase = true;
-                }
-            } catch (ClassNotFoundException e) {
-                // fall through
-            }
-        } catch (Throwable e) {
-            // fall through
-        }
-        return isUnitTestCase;
-    }
-
-     /**
-     * Utility method to check through reflection if the class appears to be a
-     * JUnit 3.8.x test suite, i.e. checks if it extends JUnit 3.8.x's TestSuite.
-     *
-     * @param scriptClass the class we want to check
-     * @return true if the class appears to be a test
-     */
-    private boolean isJUnit3TestSuite(Class scriptClass) {
-        // check if the parsed class is a TestSuite,
-        // so that it is possible to run it as a JUnit test
-        boolean isUnitTestSuite = false;
-        try {
-            try {
-                Class testSuiteClass = this.loader.loadClass("junit.framework.TestSuite");
-                // if scriptClass extends TestSuiteClass
-                if (testSuiteClass.isAssignableFrom(scriptClass)) {
-                    isUnitTestSuite = true;
-                }
-            } catch (ClassNotFoundException e) {
-                // fall through
-            }
-        } catch (Throwable e) {
-            // fall through
-        }
-        return isUnitTestSuite;
-    }
-
-    /**
-     * Utility method to check via reflection if the parsed class appears to be a JUnit4
-     * test, i.e. checks whether it appears to be using the relevant JUnit 4 annotations.
-     *
-     * @param scriptClass the class we want to check
-     * @return true if the class appears to be a test
-     */
-    private boolean isJUnit4Test(Class scriptClass) {
-        // check if there are appropriate class or method annotations
-        // that suggest we have a JUnit 4 test
-        boolean isTest = false;
-
-        try {
-            if (InvokerHelper.invokeStaticMethod("org.codehaus.groovy.vmplugin.v5.JUnit4Utils",
-                    "realIsJUnit4Test", new Object[]{scriptClass, this.loader}) == Boolean.TRUE) {
-                isTest = true;
-            }
-        } catch (ClassNotFoundException e) {
-            throw new GroovyRuntimeException("Failed to invoke the JUnit 4 helper class.", e);
-        }
-        return isTest;
-    }
-
     /**
      * Runs the given script text with command line arguments
      *
@@ -504,7 +356,7 @@ public class GroovyShell extends GroovyObjectSupport {
      * @param args      the command line arguments to pass in
      */
     public Object run(GroovyCodeSource source, List args) throws CompilationFailedException {
-        return run(source, ((String[]) args.toArray(new String[args.size()])));
+        return run(source, ((String[]) args.toArray(EMPTY_STRING_ARRAY)));
     }
 
     /**
@@ -525,7 +377,7 @@ public class GroovyShell extends GroovyObjectSupport {
      * @param args      the command line arguments to pass in
      */
     public Object run(URI source, List args) throws CompilationFailedException, IOException {
-        return run(new GroovyCodeSource(source), ((String[]) args.toArray(new String[args.size()])));
+        return run(new GroovyCodeSource(source), ((String[]) args.toArray(EMPTY_STRING_ARRAY)));
     }
 
     /**
@@ -546,7 +398,7 @@ public class GroovyShell extends GroovyObjectSupport {
      * @param list     the command line arguments to pass in
      */
     public Object run(final Reader in, final String fileName, List list) throws CompilationFailedException {
-        return run(in, fileName, (String[]) list.toArray(new String[list.size()]));
+        return run(in, fileName, (String[]) list.toArray(EMPTY_STRING_ARRAY));
     }
 
     /**
@@ -745,7 +597,7 @@ public class GroovyShell extends GroovyObjectSupport {
         return parse(in, generateScriptName());
     }
 
-    protected synchronized String generateScriptName() {
-        return "Script" + (++counter) + ".groovy";
+    protected String generateScriptName() {
+        return "Script" + counter.incrementAndGet() + ".groovy";
     }
 }
