@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2016 the original author or authors.
+ * Copyright 2012-2019 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -68,8 +68,7 @@ public final class SpringCli {
 	}
 
 	private static void addServiceLoaderCommands(CommandRunner runner) {
-		ServiceLoader<CommandFactory> factories = ServiceLoader
-				.load(CommandFactory.class);
+		ServiceLoader<CommandFactory> factories = ServiceLoader.load(CommandFactory.class);
 		for (CommandFactory factory : factories) {
 			runner.addCommands(factory.getCommands());
 		}
@@ -80,9 +79,8 @@ public final class SpringCli {
 	}
 
 	private static URL[] getExtensionURLs() {
-		List<URL> urls = new ArrayList<URL>();
-		String home = SystemPropertyUtils
-				.resolvePlaceholders("${spring.home:${SPRING_HOME:.}}");
+		List<URL> urls = new ArrayList<>();
+		String home = SystemPropertyUtils.resolvePlaceholders("${spring.home:${SPRING_HOME:.}}");
 		File extDirectory = new File(new File(home, "lib"), "ext");
 		if (extDirectory.isDirectory()) {
 			for (File file : extDirectory.listFiles()) {
@@ -96,7 +94,7 @@ public final class SpringCli {
 				}
 			}
 		}
-		return urls.toArray(new URL[urls.size()]);
+		return urls.toArray(new URL[0]);
 	}
 
 }
