@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2018 the original author or authors.
+ * Copyright 2012-2019 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -43,7 +43,7 @@ public class CommandRunner implements Iterable<Command> {
 
 	private final String name;
 
-	private final List<Command> commands = new ArrayList<Command>();
+	private final List<Command> commands = new ArrayList<>();
 
 	private Class<?>[] optionCommandClasses = {};
 
@@ -54,7 +54,7 @@ public class CommandRunner implements Iterable<Command> {
 	 * @param name the name of the runner or {@code null}
 	 */
 	public CommandRunner(String name) {
-		this.name = (StringUtils.hasLength(name) ? name + " " : "");
+		this.name = StringUtils.hasLength(name) ? name + " " : "";
 	}
 
 	/**
@@ -148,8 +148,7 @@ public class CommandRunner implements Iterable<Command> {
 	public Command findCommand(String name) {
 		for (Command candidate : this.commands) {
 			String candidateName = candidate.getName();
-			if (candidateName.equals(name) || (isOptionCommand(candidate)
-					&& ("--" + candidateName).equals(name))) {
+			if (candidateName.equals(name) || (isOptionCommand(candidate) && ("--" + candidateName).equals(name))) {
 				return candidate;
 			}
 		}
@@ -185,7 +184,7 @@ public class CommandRunner implements Iterable<Command> {
 	}
 
 	private String[] removeDebugFlags(String[] args) {
-		List<String> rtn = new ArrayList<String>(args.length);
+		List<String> rtn = new ArrayList<>(args.length);
 		boolean appArgsDetected = false;
 		for (String arg : args) {
 			// Allow apps to have a -d argument
@@ -195,7 +194,7 @@ public class CommandRunner implements Iterable<Command> {
 			}
 			rtn.add(arg);
 		}
-		return rtn.toArray(new String[rtn.size()]);
+		return StringUtils.toStringArray(rtn);
 	}
 
 	/**
@@ -252,8 +251,7 @@ public class CommandRunner implements Iterable<Command> {
 		if (options.contains(CommandException.Option.SHOW_USAGE)) {
 			showUsage();
 		}
-		if (debug || couldNotShowMessage
-				|| options.contains(CommandException.Option.STACK_TRACE)) {
+		if (debug || couldNotShowMessage || options.contains(CommandException.Option.STACK_TRACE)) {
 			printStackTrace(ex);
 		}
 		return 1;
@@ -280,19 +278,16 @@ public class CommandRunner implements Iterable<Command> {
 				String usageHelp = command.getUsageHelp();
 				String description = command.getDescription();
 				Log.info(String.format("%n  %1$s %2$-15s%n    %3$s", command.getName(),
-						(usageHelp != null) ? usageHelp : "",
-						(description != null) ? description : ""));
+						(usageHelp != null) ? usageHelp : "", (description != null) ? description : ""));
 			}
 		}
 		Log.info("");
 		Log.info("Common options:");
-		Log.info(String.format("%n  %1$s %2$-15s%n    %3$s", "-d, --debug",
-				"Verbose mode",
+		Log.info(String.format("%n  %1$s %2$-15s%n    %3$s", "-d, --debug", "Verbose mode",
 				"Print additional status information for the command you are running"));
 		Log.info("");
 		Log.info("");
-		Log.info("See '" + this.name
-				+ "help <command>' for more information on a specific command.");
+		Log.info("See '" + this.name + "help <command>' for more information on a specific command.");
 	}
 
 	protected void printStackTrace(Exception ex) {
