@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2014 the original author or authors.
+ * Copyright 2012-2019 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -33,8 +33,7 @@ public abstract class OptionParsingCommand extends AbstractCommand {
 
 	private final OptionHandler handler;
 
-	protected OptionParsingCommand(String name, String description,
-			OptionHandler handler) {
+	protected OptionParsingCommand(String name, String description, OptionHandler handler) {
 		super(name, description);
 		this.handler = handler;
 	}
