@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2015 the original author or authors.
+ * Copyright 2012-2019 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -31,8 +31,8 @@ import org.springframework.boot.loader.tools.LibraryScope;
 public class JarCommand extends ArchiveCommand {
 
 	public JarCommand() {
-		super("jar", "Create a self-contained executable jar "
-				+ "file from a Spring Groovy script", new JarOptionHandler());
+		super("jar", "Create a self-contained executable jar " + "file from a Spring Groovy script",
+				new JarOptionHandler());
 	}
 
 	private static final class JarOptionHandler extends ArchiveOptionHandler {
