@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2018 the original author or authors.
+ * Copyright 2012-2019 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -68,12 +68,11 @@ class InitializrServiceMetadata {
 	}
 
 	InitializrServiceMetadata(ProjectType defaultProjectType) {
-		this.dependencies = new HashMap<String, Dependency>();
-		this.projectTypes = new MetadataHolder<String, ProjectType>();
-		this.projectTypes.getContent().put(defaultProjectType.getId(),
-				defaultProjectType);
+		this.dependencies = new HashMap<>();
+		this.projectTypes = new MetadataHolder<>();
+		this.projectTypes.getContent().put(defaultProjectType.getId(), defaultProjectType);
 		this.projectTypes.setDefaultItem(defaultProjectType);
-		this.defaults = new HashMap<String, String>();
+		this.defaults = new HashMap<>();
 	}
 
 	/**
@@ -126,9 +125,8 @@ class InitializrServiceMetadata {
 		return this.defaults;
 	}
 
-	private Map<String, Dependency> parseDependencies(JSONObject root)
-			throws JSONException {
-		Map<String, Dependency> result = new HashMap<String, Dependency>();
+	private Map<String, Dependency> parseDependencies(JSONObject root) throws JSONException {
+		Map<String, Dependency> result = new HashMap<>();
 		if (!root.has(DEPENDENCIES_EL)) {
 			return result;
 		}
@@ -141,16 +139,14 @@ class InitializrServiceMetadata {
 		return result;
 	}
 
-	private MetadataHolder<String, ProjectType> parseProjectTypes(JSONObject root)
-			throws JSONException {
-		MetadataHolder<String, ProjectType> result = new MetadataHolder<String, ProjectType>();
+	private MetadataHolder<String, ProjectType> parseProjectTypes(JSONObject root) throws JSONException {
+		MetadataHolder<String, ProjectType> result = new MetadataHolder<>();
 		if (!root.has(TYPE_EL)) {
 			return result;
 		}
 		JSONObject type = root.getJSONObject(TYPE_EL);
 		JSONArray array = type.getJSONArray(VALUES_EL);
-		String defaultType = (type.has(DEFAULT_ATTRIBUTE)
-				? type.getString(DEFAULT_ATTRIBUTE) : null);
+		String defaultType = (type.has(DEFAULT_ATTRIBUTE) ? type.getString(DEFAULT_ATTRIBUTE) : null);
 		for (int i = 0; i < array.length(); i++) {
 			JSONObject typeJson = array.getJSONObject(i);
 			ProjectType projectType = parseType(typeJson, defaultType);
@@ -163,7 +159,7 @@ class InitializrServiceMetadata {
 	}
 
 	private Map<String, String> parseDefaults(JSONObject root) throws JSONException {
-		Map<String, String> result = new HashMap<String, String>();
+		Map<String, String> result = new HashMap<>();
 		Iterator<?> keys = root.keys();
 		while (keys.hasNext()) {
 			String key = (String) keys.next();
@@ -178,8 +174,7 @@ class InitializrServiceMetadata {
 		return result;
 	}
 
-	private void parseGroup(JSONObject group, Map<String, Dependency> dependencies)
-			throws JSONException {
+	private void parseGroup(JSONObject group, Map<String, Dependency> dependencies) throws JSONException {
 		if (group.has(VALUES_EL)) {
 			JSONArray content = group.getJSONArray(VALUES_EL);
 			for (int i = 0; i < content.length(); i++) {
@@ -196,13 +191,12 @@ class InitializrServiceMetadata {
 		return new Dependency(id, name, description);
 	}
 
-	private ProjectType parseType(JSONObject object, String defaultId)
-			throws JSONException {
+	private ProjectType parseType(JSONObject object, String defaultId) throws JSONException {
 		String id = getStringValue(object, ID_ATTRIBUTE, null);
 		String name = getStringValue(object, NAME_ATTRIBUTE, null);
 		String action = getStringValue(object, ACTION_ATTRIBUTE, null);
 		boolean defaultType = id.equals(defaultId);
-		Map<String, String> tags = new HashMap<String, String>();
+		Map<String, String> tags = new HashMap<>();
 		if (object.has("tags")) {
 			JSONObject jsonTags = object.getJSONObject("tags");
 			tags.putAll(parseStringItems(jsonTags));
@@ -210,13 +204,12 @@ class InitializrServiceMetadata {
 		return new ProjectType(id, name, action, defaultType, tags);
 	}
 
-	private String getStringValue(JSONObject object, String name, String defaultValue)
-			throws JSONException {
-		return (object.has(name) ? object.getString(name) : defaultValue);
+	private String getStringValue(JSONObject object, String name, String defaultValue) throws JSONException {
+		return object.has(name) ? object.getString(name) : defaultValue;
 	}
 
 	private Map<String, String> parseStringItems(JSONObject json) throws JSONException {
-		Map<String, String> result = new HashMap<String, String>();
+		Map<String, String> result = new HashMap<>();
 		for (Iterator<?> iterator = json.keys(); iterator.hasNext();) {
 			String key = (String) iterator.next();
 			Object value = json.get(key);
@@ -234,7 +227,7 @@ class InitializrServiceMetadata {
 		private T defaultItem;
 
 		private MetadataHolder() {
-			this.content = new HashMap<K, T>();
+			this.content = new HashMap<>();
 		}
 
 		public Map<K, T> getContent() {
