@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2016 the original author or authors.
+ * Copyright 2012-2019 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -38,7 +38,6 @@ import org.springframework.util.SystemPropertyUtils;
  * Shared logic for the {@link InstallCommand} and {@link UninstallCommand}.
  *
  * @author Andy Wilkinson
- * @since 1.2.0
  */
 class Installer {
 
@@ -46,10 +45,8 @@ class Installer {
 
 	private final Properties installCounts;
 
-	Installer(OptionSet options, CompilerOptionHandler compilerOptionHandler)
-			throws IOException {
-		this(new GroovyGrabDependencyResolver(
-				createCompilerConfiguration(options, compilerOptionHandler)));
+	Installer(OptionSet options, CompilerOptionHandler compilerOptionHandler) throws IOException {
+		this(new GroovyGrabDependencyResolver(createCompilerConfiguration(options, compilerOptionHandler)));
 	}
 
 	Installer(DependencyResolver resolver) throws IOException {
@@ -57,12 +54,11 @@ class Installer {
 		this.installCounts = loadInstallCounts();
 	}
 
-	private static GroovyCompilerConfiguration createCompilerConfiguration(
-			OptionSet options, CompilerOptionHandler compilerOptionHandler) {
+	private static GroovyCompilerConfiguration createCompilerConfiguration(OptionSet options,
+			CompilerOptionHandler compilerOptionHandler) {
 		List<RepositoryConfiguration> repositoryConfiguration = RepositoryConfigurationFactory
 				.createDefaultRepositoryConfiguration();
-		return new OptionSetGroovyCompilerConfiguration(options, compilerOptionHandler,
-				repositoryConfiguration) {
+		return new OptionSetGroovyCompilerConfiguration(options, compilerOptionHandler, repositoryConfiguration) {
 			@Override
 			public boolean isAutoconfigure() {
 				return false;
@@ -82,13 +78,9 @@ class Installer {
 	}
 
 	private void saveInstallCounts() throws IOException {
-		FileWriter writer = new FileWriter(getInstalled());
-		try {
+		try (FileWriter writer = new FileWriter(getInstalled())) {
 			this.installCounts.store(writer, null);
 		}
-		finally {
-			writer.close();
-		}
 	}
 
 	public void install(List<String> artifactIdentifiers) throws Exception {
@@ -99,8 +91,7 @@ class Installer {
 		for (File artifactFile : artifactFiles) {
 			int installCount = getInstallCount(artifactFile);
 			if (installCount == 0) {
-				FileCopyUtils.copy(artifactFile,
-						new File(extDirectory, artifactFile.getName()));
+				FileCopyUtils.copy(artifactFile, new File(extDirectory, artifactFile.getName()));
 			}
 			setInstallCount(artifactFile, installCount + 1);
 		}
@@ -149,14 +140,10 @@ class Installer {
 	}
 
 	private File getDefaultExtDirectory() {
-		String home = SystemPropertyUtils
-				.resolvePlaceholders("${spring.home:${SPRING_HOME:.}}");
+		String home = SystemPropertyUtils.resolvePlaceholders("${spring.home:${SPRING_HOME:.}}");
 		File extDirectory = new File(new File(home, "lib"), "ext");
-		if (!extDirectory.isDirectory()) {
-			if (!extDirectory.mkdirs()) {
-				throw new IllegalStateException(
-						"Failed to create ext directory " + extDirectory);
-			}
+		if (!extDirectory.isDirectory() && !extDirectory.mkdirs()) {
+			throw new IllegalStateException("Failed to create ext directory " + extDirectory);
 		}
 		return extDirectory;
 	}
