@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2018 the original author or authors.
+ * Copyright 2012-2019 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -58,7 +58,7 @@ public class OptionHandler {
 		return getParser().accepts(name, description);
 	}
 
-	public OptionSpecBuilder option(Collection<String> aliases, String description) {
+	public OptionSpecBuilder option(List<String> aliases, String description) {
 		return getParser().acceptsAll(aliases, description);
 	}
 
@@ -126,21 +126,14 @@ public class OptionHandler {
 
 	private static class OptionHelpFormatter implements HelpFormatter {
 
-		private final List<OptionHelp> help = new ArrayList<OptionHelp>();
+		private final List<OptionHelp> help = new ArrayList<>();
 
 		@Override
 		public String format(Map<String, ? extends OptionDescriptor> options) {
-			Comparator<OptionDescriptor> comparator = new Comparator<OptionDescriptor>() {
-				@Override
-				public int compare(OptionDescriptor first, OptionDescriptor second) {
-					return first.options().iterator().next()
-							.compareTo(second.options().iterator().next());
-				}
-			};
-
-			Set<OptionDescriptor> sorted = new TreeSet<OptionDescriptor>(comparator);
+			Comparator<OptionDescriptor> comparator = Comparator
+					.comparing((optionDescriptor) -> optionDescriptor.options().iterator().next());
+			Set<OptionDescriptor> sorted = new TreeSet<>(comparator);
 			sorted.addAll(options.values());
-
 			for (OptionDescriptor descriptor : sorted) {
 				if (!descriptor.representsNonOptions()) {
 					this.help.add(new OptionHelpAdapter(descriptor));
@@ -157,12 +150,12 @@ public class OptionHandler {
 
 	private static class OptionHelpAdapter implements OptionHelp {
 
-		private final LinkedHashSet<String> options;
+		private final Set<String> options;
 
 		private final String description;
 
 		OptionHelpAdapter(OptionDescriptor descriptor) {
-			this.options = new LinkedHashSet<String>();
+			this.options = new LinkedHashSet<>();
 			for (String option : descriptor.options()) {
 				String prefix = (option.length() != 1) ? "--" : "-";
 				this.options.add(prefix + option);
