@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2016 the original author or authors.
+ * Copyright 2012-2019 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -25,6 +25,7 @@ import joptsimple.OptionSet;
 
 import org.springframework.boot.cli.util.ResourceUtils;
 import org.springframework.util.Assert;
+import org.springframework.util.StringUtils;
 
 /**
  * Extract source file options (anything following '--' in an {@link OptionSet}).
@@ -71,7 +72,7 @@ public class SourceOptions {
 	}
 
 	private SourceOptions(List<?> nonOptionArguments, ClassLoader classLoader) {
-		List<String> sources = new ArrayList<String>();
+		List<String> sources = new ArrayList<>();
 		int sourceArgCount = 0;
 		for (Object option : nonOptionArguments) {
 			if (option instanceof String) {
@@ -79,7 +80,7 @@ public class SourceOptions {
 				if ("--".equals(filename)) {
 					break;
 				}
-				List<String> urls = new ArrayList<String>();
+				List<String> urls = new ArrayList<>();
 				File fileCandidate = new File(filename);
 				if (fileCandidate.isFile()) {
 					urls.add(fileCandidate.getAbsoluteFile().toURI().toString());
@@ -102,8 +103,7 @@ public class SourceOptions {
 				}
 			}
 		}
-		this.args = Collections.unmodifiableList(
-				nonOptionArguments.subList(sourceArgCount, nonOptionArguments.size()));
+		this.args = Collections.unmodifiableList(nonOptionArguments.subList(sourceArgCount, nonOptionArguments.size()));
 		Assert.isTrue(!sources.isEmpty(), "Please specify at least one file");
 		this.sources = Collections.unmodifiableList(sources);
 	}
@@ -125,7 +125,11 @@ public class SourceOptions {
 	}
 
 	public String[] getArgsArray() {
-		return this.args.toArray(new String[this.args.size()]);
+		return this.args.stream().map(this::asString).toArray(String[]::new);
+	}
+
+	private String asString(Object arg) {
+		return (arg != null) ? String.valueOf(arg) : null;
 	}
 
 	public List<String> getSources() {
@@ -133,7 +137,7 @@ public class SourceOptions {
 	}
 
 	public String[] getSourcesArray() {
-		return this.sources.toArray(new String[this.sources.size()]);
+		return StringUtils.toStringArray(this.sources);
 	}
 
 }
