@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2016 the original author or authors.
+ * Copyright 2012-2019 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -25,8 +25,7 @@ import org.springframework.boot.cli.compiler.GroovyCompilerConfiguration;
  *
  * @author Phillip Webb
  */
-public interface SpringApplicationRunnerConfiguration
-		extends GroovyCompilerConfiguration {
+public interface SpringApplicationRunnerConfiguration extends GroovyCompilerConfiguration {
 
 	/**
 	 * Returns {@code true} if the source file should be monitored for changes and
