@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2018 the original author or authors.
+ * Copyright 2012-2019 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -42,27 +42,26 @@ import org.springframework.boot.cli.util.Log;
  */
 public class CommandCompleter extends StringsCompleter {
 
-	private final Map<String, Completer> commandCompleters = new HashMap<String, Completer>();
+	private final Map<String, Completer> commandCompleters = new HashMap<>();
 
-	private final List<Command> commands = new ArrayList<Command>();
+	private final List<Command> commands = new ArrayList<>();
 
 	private final ConsoleReader console;
 
-	public CommandCompleter(ConsoleReader consoleReader,
-			ArgumentDelimiter argumentDelimiter, Iterable<Command> commands) {
+	public CommandCompleter(ConsoleReader consoleReader, ArgumentDelimiter argumentDelimiter,
+			Iterable<Command> commands) {
 		this.console = consoleReader;
-		List<String> names = new ArrayList<String>();
+		List<String> names = new ArrayList<>();
 		for (Command command : commands) {
 			this.commands.add(command);
 			names.add(command.getName());
-			List<String> options = new ArrayList<String>();
+			List<String> options = new ArrayList<>();
 			for (OptionHelp optionHelp : command.getOptionsHelp()) {
 				options.addAll(optionHelp.getOptions());
 			}
-			AggregateCompleter argumentCompleters = new AggregateCompleter(
-					new StringsCompleter(options), new FileNameCompleter());
-			ArgumentCompleter argumentCompleter = new ArgumentCompleter(argumentDelimiter,
-					argumentCompleters);
+			AggregateCompleter argumentCompleters = new AggregateCompleter(new StringsCompleter(options),
+					new FileNameCompleter());
+			ArgumentCompleter argumentCompleter = new ArgumentCompleter(argumentDelimiter, argumentCompleters);
 			argumentCompleter.setStrict(false);
 			this.commandCompleters.put(command.getName(), argumentCompleter);
 		}
@@ -95,20 +94,19 @@ public class CommandCompleter extends StringsCompleter {
 	private void printUsage(Command command) {
 		try {
 			int maxOptionsLength = 0;
-			List<OptionHelpLine> optionHelpLines = new ArrayList<OptionHelpLine>();
+			List<OptionHelpLine> optionHelpLines = new ArrayList<>();
 			for (OptionHelp optionHelp : command.getOptionsHelp()) {
 				OptionHelpLine optionHelpLine = new OptionHelpLine(optionHelp);
 				optionHelpLines.add(optionHelpLine);
-				maxOptionsLength = Math.max(maxOptionsLength,
-						optionHelpLine.getOptions().length());
+				maxOptionsLength = Math.max(maxOptionsLength, optionHelpLine.getOptions().length());
 			}
 
 			this.console.println();
 			this.console.println("Usage:");
 			this.console.println(command.getName() + " " + command.getUsageHelp());
 			for (OptionHelpLine optionHelpLine : optionHelpLines) {
-				this.console.println(String.format("\t%" + maxOptionsLength + "s: %s",
-						optionHelpLine.getOptions(), optionHelpLine.getUsage()));
+				this.console.println(String.format("\t%" + maxOptionsLength + "s: %s", optionHelpLine.getOptions(),
+						optionHelpLine.getUsage()));
 			}
 			this.console.drawLine();
 		}
@@ -127,12 +125,7 @@ public class CommandCompleter extends StringsCompleter {
 		private final String usage;
 
 		OptionHelpLine(OptionHelp optionHelp) {
-			StringBuilder options = new StringBuilder();
-			for (String option : optionHelp.getOptions()) {
-				options.append((options.length() != 0) ? ", " : "");
-				options.append(option);
-			}
-			this.options = options.toString();
+			this.options = String.join(", ", optionHelp.getOptions());
 			this.usage = optionHelp.getUsageHelp();
 		}
 
