@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2014 the original author or authors.
+ * Copyright 2012-2017 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -69,7 +69,7 @@ class ForkProcessCommand extends RunProcessCommand {
 
 	@Override
 	public ExitStatus run(String... args) throws Exception {
-		List<String> fullArgs = new ArrayList<String>();
+		List<String> fullArgs = new ArrayList<>();
 		fullArgs.add("-cp");
 		fullArgs.add(System.getProperty("java.class.path"));
 		fullArgs.add(MAIN_CLASS);
