@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2015 the original author or authors.
+ * Copyright 2012-2019 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -76,12 +76,10 @@ public abstract class AstUtils {
 	 * @return {@code true} if at least one of the annotations is found, otherwise
 	 * {@code false}
 	 */
-	public static boolean hasAtLeastOneAnnotation(AnnotatedNode node,
-			String... annotations) {
+	public static boolean hasAtLeastOneAnnotation(AnnotatedNode node, String... annotations) {
 		for (AnnotationNode annotationNode : node.getAnnotations()) {
 			for (String annotation : annotations) {
-				if (PatternMatchUtils.simpleMatch(annotation,
-						annotationNode.getClassNode().getName())) {
+				if (PatternMatchUtils.simpleMatch(annotation, annotationNode.getClassNode().getName())) {
 					return true;
 				}
 			}
@@ -98,7 +96,7 @@ public abstract class AstUtils {
 	 * @return {@code true} if at least one of the types is found, otherwise {@code false}
 	 */
 	public static boolean hasAtLeastOneFieldOrMethod(ClassNode node, String... types) {
-		Set<String> typesSet = new HashSet<String>(Arrays.asList(types));
+		Set<String> typesSet = new HashSet<>(Arrays.asList(types));
 		for (FieldNode field : node.getFields()) {
 			if (typesSet.contains(field.getType().getName())) {
 				return true;
@@ -130,7 +128,7 @@ public abstract class AstUtils {
 	}
 
 	public static boolean hasAtLeastOneInterface(ClassNode classNode, String... types) {
-		Set<String> typesSet = new HashSet<String>(Arrays.asList(types));
+		Set<String> typesSet = new HashSet<>(Arrays.asList(types));
 		for (ClassNode inter : classNode.getInterfaces()) {
 			if (typesSet.contains(inter.getName())) {
 				return true;
@@ -147,13 +145,11 @@ public abstract class AstUtils {
 	 * @param remove whether or not the extracted closure should be removed
 	 * @return a beans Closure if one can be found, null otherwise
 	 */
-	public static ClosureExpression getClosure(BlockStatement block, String name,
-			boolean remove) {
+	public static ClosureExpression getClosure(BlockStatement block, String name, boolean remove) {
 		for (ExpressionStatement statement : getExpressionStatements(block)) {
 			Expression expression = statement.getExpression();
 			if (expression instanceof MethodCallExpression) {
-				ClosureExpression closure = getClosure(name,
-						(MethodCallExpression) expression);
+				ClosureExpression closure = getClosure(name, (MethodCallExpression) expression);
 				if (closure != null) {
 					if (remove) {
 						block.getStatements().remove(statement);
@@ -165,9 +161,8 @@ public abstract class AstUtils {
 		return null;
 	}
 
-	private static List<ExpressionStatement> getExpressionStatements(
-			BlockStatement block) {
-		ArrayList<ExpressionStatement> statements = new ArrayList<ExpressionStatement>();
+	private static List<ExpressionStatement> getExpressionStatements(BlockStatement block) {
+		List<ExpressionStatement> statements = new ArrayList<>();
 		for (Statement statement : block.getStatements()) {
 			if (statement instanceof ExpressionStatement) {
 				statements.add((ExpressionStatement) statement);
@@ -176,14 +171,10 @@ public abstract class AstUtils {
 		return statements;
 	}
 
-	private static ClosureExpression getClosure(String name,
-			MethodCallExpression expression) {
+	private static ClosureExpression getClosure(String name, MethodCallExpression expression) {
 		Expression method = expression.getMethod();
-		if (method instanceof ConstantExpression) {
-			if (name.equals(((ConstantExpression) method).getValue())) {
-				return (ClosureExpression) ((ArgumentListExpression) expression
-						.getArguments()).getExpression(0);
-			}
+		if (method instanceof ConstantExpression && name.equals(((ConstantExpression) method).getValue())) {
+			return (ClosureExpression) ((ArgumentListExpression) expression.getArguments()).getExpression(0);
 		}
 		return null;
 	}
