@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2018 the original author or authors.
+ * Copyright 2012-2019 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -74,8 +74,7 @@ public class DependencyCustomizer {
 	}
 
 	public String getVersion(String artifactId, String defaultVersion) {
-		String version = this.dependencyResolutionContext.getArtifactCoordinatesResolver()
-				.getVersion(artifactId);
+		String version = this.dependencyResolutionContext.getArtifactCoordinatesResolver().getVersion(artifactId);
 		if (version == null) {
 			version = defaultVersion;
 		}
@@ -88,7 +87,7 @@ public class DependencyCustomizer {
 	 * @param classNames the class names to test
 	 * @return a nested {@link DependencyCustomizer}
 	 */
-	public DependencyCustomizer ifAnyMissingClasses(final String... classNames) {
+	public DependencyCustomizer ifAnyMissingClasses(String... classNames) {
 		return new DependencyCustomizer(this) {
 			@Override
 			protected boolean canAdd() {
@@ -111,7 +110,7 @@ public class DependencyCustomizer {
 	 * @param classNames the class names to test
 	 * @return a nested {@link DependencyCustomizer}
 	 */
-	public DependencyCustomizer ifAllMissingClasses(final String... classNames) {
+	public DependencyCustomizer ifAllMissingClasses(String... classNames) {
 		return new DependencyCustomizer(this) {
 			@Override
 			protected boolean canAdd() {
@@ -135,7 +134,7 @@ public class DependencyCustomizer {
 	 * @param paths the paths to test
 	 * @return a nested {@link DependencyCustomizer}
 	 */
-	public DependencyCustomizer ifAllResourcesPresent(final String... paths) {
+	public DependencyCustomizer ifAllResourcesPresent(String... paths) {
 		return new DependencyCustomizer(this) {
 			@Override
 			protected boolean canAdd() {
@@ -161,7 +160,7 @@ public class DependencyCustomizer {
 	 * @param paths the paths to test
 	 * @return a nested {@link DependencyCustomizer}
 	 */
-	public DependencyCustomizer ifAnyResourcesPresent(final String... paths) {
+	public DependencyCustomizer ifAnyResourcesPresent(String... paths) {
 		return new DependencyCustomizer(this) {
 			@Override
 			protected boolean canAdd() {
@@ -201,7 +200,7 @@ public class DependencyCustomizer {
 	 * {@link ArtifactCoordinatesResolver}.
 	 * @param module the module ID
 	 * @param transitive {@code true} if the transitive dependencies should also be added,
-	 * otherwise {@code false}.
+	 * otherwise {@code false}
 	 * @return this {@link DependencyCustomizer} for continued use
 	 */
 	public DependencyCustomizer add(String module, boolean transitive) {
@@ -216,25 +215,22 @@ public class DependencyCustomizer {
 	 * @param classifier the classifier, may be {@code null}
 	 * @param type the type, may be {@code null}
 	 * @param transitive {@code true} if the transitive dependencies should also be added,
-	 * otherwise {@code false}.
+	 * otherwise {@code false}
 	 * @return this {@link DependencyCustomizer} for continued use
 	 */
-	public DependencyCustomizer add(String module, String classifier, String type,
-			boolean transitive) {
+	public DependencyCustomizer add(String module, String classifier, String type, boolean transitive) {
 		if (canAdd()) {
 			ArtifactCoordinatesResolver artifactCoordinatesResolver = this.dependencyResolutionContext
 					.getArtifactCoordinatesResolver();
-			this.classNode.addAnnotation(
-					createGrabAnnotation(artifactCoordinatesResolver.getGroupId(module),
-							artifactCoordinatesResolver.getArtifactId(module),
-							artifactCoordinatesResolver.getVersion(module), classifier,
-							type, transitive));
+			this.classNode.addAnnotation(createGrabAnnotation(artifactCoordinatesResolver.getGroupId(module),
+					artifactCoordinatesResolver.getArtifactId(module), artifactCoordinatesResolver.getVersion(module),
+					classifier, type, transitive));
 		}
 		return this;
 	}
 
-	private AnnotationNode createGrabAnnotation(String group, String module,
-			String version, String classifier, String type, boolean transitive) {
+	private AnnotationNode createGrabAnnotation(String group, String module, String version, String classifier,
+			String type, boolean transitive) {
 		AnnotationNode annotationNode = new AnnotationNode(new ClassNode(Grab.class));
 		annotationNode.addMember("group", new ConstantExpression(group));
 		annotationNode.addMember("module", new ConstantExpression(module));
