@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2018 the original author or authors.
+ * Copyright 2012-2019 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -18,6 +18,7 @@ package org.springframework.boot.cli.compiler;
 
 import java.io.ByteArrayInputStream;
 import java.io.File;
+import java.io.IOException;
 import java.io.InputStream;
 import java.net.MalformedURLException;
 import java.net.URL;
@@ -25,6 +26,7 @@ import java.net.URLClassLoader;
 import java.security.AccessController;
 import java.security.PrivilegedAction;
 import java.util.ArrayList;
+import java.util.Enumeration;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Map;
@@ -53,7 +55,7 @@ public class ExtendedGroovyClassLoader extends GroovyClassLoader {
 
 	private static final URL[] NO_URLS = new URL[] {};
 
-	private final Map<String, byte[]> classResources = new HashMap<String, byte[]>();
+	private final Map<String, byte[]> classResources = new HashMap<>();
 
 	private final GroovyCompilerScope scope;
 
@@ -84,8 +86,7 @@ public class ExtendedGroovyClassLoader extends GroovyClassLoader {
 			return super.findClass(name);
 		}
 		catch (ClassNotFoundException ex) {
-			if (this.scope == GroovyCompilerScope.DEFAULT
-					&& name.startsWith(SHARED_PACKAGE)) {
+			if (this.scope == GroovyCompilerScope.DEFAULT && name.startsWith(SHARED_PACKAGE)) {
 				Class<?> sharedClass = findSharedClass(name);
 				if (sharedClass != null) {
 					return sharedClass;
@@ -98,14 +99,10 @@ public class ExtendedGroovyClassLoader extends GroovyClassLoader {
 	private Class<?> findSharedClass(String name) {
 		try {
 			String path = name.replace('.', '/').concat(".class");
-			InputStream inputStream = getParent().getResourceAsStream(path);
-			if (inputStream != null) {
-				try {
+			try (InputStream inputStream = getParent().getResourceAsStream(path)) {
+				if (inputStream != null) {
 					return defineClass(name, FileCopyUtils.copyToByteArray(inputStream));
 				}
-				finally {
-					inputStream.close();
-				}
 			}
 			return null;
 		}
@@ -126,23 +123,23 @@ public class ExtendedGroovyClassLoader extends GroovyClassLoader {
 
 	@Override
 	public ClassCollector createCollector(CompilationUnit unit, SourceUnit su) {
-		InnerLoader loader = AccessController
-				.doPrivileged(new PrivilegedAction<InnerLoader>() {
-					@Override
-					public InnerLoader run() {
-						return new InnerLoader(ExtendedGroovyClassLoader.this) {
-							// Don't return URLs from the inner loader so that Tomcat only
-							// searches the parent. Fixes 'TLD skipped' issues
-							@Override
-							public URL[] getURLs() {
-								return NO_URLS;
-							}
-						};
-					}
-				});
+		InnerLoader loader = AccessController.doPrivileged(getInnerLoader());
 		return new ExtendedClassCollector(loader, unit, su);
 	}
 
+	private PrivilegedAction<InnerLoader> getInnerLoader() {
+		return () -> new InnerLoader(ExtendedGroovyClassLoader.this) {
+
+			// Don't return URLs from the inner loader so that Tomcat only
+			// searches the parent. Fixes 'TLD skipped' issues
+			@Override
+			public URL[] getURLs() {
+				return NO_URLS;
+			}
+
+		};
+	}
+
 	public CompilerConfiguration getConfiguration() {
 		return this.configuration;
 	}
@@ -152,16 +149,14 @@ public class ExtendedGroovyClassLoader extends GroovyClassLoader {
 	 */
 	protected class ExtendedClassCollector extends ClassCollector {
 
-		protected ExtendedClassCollector(InnerLoader loader, CompilationUnit unit,
-				SourceUnit su) {
+		protected ExtendedClassCollector(InnerLoader loader, CompilationUnit unit, SourceUnit su) {
 			super(loader, unit, su);
 		}
 
 		@Override
 		protected Class<?> createClass(byte[] code, ClassNode classNode) {
 			Class<?> createdClass = super.createClass(code, classNode);
-			ExtendedGroovyClassLoader.this.classResources
-					.put(classNode.getName().replace('.', '/') + ".class", code);
+			ExtendedGroovyClassLoader.this.classResources.put(classNode.getName().replace('.', '/') + ".class", code);
 			return createdClass;
 		}
 
@@ -179,17 +174,18 @@ public class ExtendedGroovyClassLoader extends GroovyClassLoader {
 
 		DefaultScopeParentClassLoader(ClassLoader parent) {
 			super(parent);
-			this.groovyOnlyClassLoader = new URLClassLoader(getGroovyJars(parent), null);
+			this.groovyOnlyClassLoader = new URLClassLoader(getGroovyJars(parent),
+					getClass().getClassLoader().getParent());
 		}
 
-		private URL[] getGroovyJars(final ClassLoader parent) {
-			Set<URL> urls = new HashSet<URL>();
+		private URL[] getGroovyJars(ClassLoader parent) {
+			Set<URL> urls = new HashSet<>();
 			findGroovyJarsDirectly(parent, urls);
 			if (urls.isEmpty()) {
 				findGroovyJarsFromClassPath(urls);
 			}
 			Assert.state(!urls.isEmpty(), "Unable to find groovy JAR");
-			return new ArrayList<URL>(urls).toArray(new URL[urls.size()]);
+			return new ArrayList<>(urls).toArray(new URL[0]);
 		}
 
 		private void findGroovyJarsDirectly(ClassLoader classLoader, Set<URL> urls) {
@@ -234,9 +230,15 @@ public class ExtendedGroovyClassLoader extends GroovyClassLoader {
 		}
 
 		@Override
-		protected Class<?> loadClass(String name, boolean resolve)
-				throws ClassNotFoundException {
-			this.groovyOnlyClassLoader.loadClass(name);
+		public Enumeration<URL> getResources(String name) throws IOException {
+			return this.groovyOnlyClassLoader.getResources(name);
+		}
+
+		@Override
+		protected Class<?> loadClass(String name, boolean resolve) throws ClassNotFoundException {
+			if (!name.startsWith("java.")) {
+				this.groovyOnlyClassLoader.loadClass(name);
+			}
 			return super.loadClass(name, resolve);
 		}
 
