@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2016 the original author or authors.
+ * Copyright 2012-2019 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -39,20 +39,16 @@ public class RabbitCompilerAutoConfiguration extends CompilerAutoConfiguration {
 	}
 
 	@Override
-	public void applyDependencies(DependencyCustomizer dependencies)
-			throws CompilationFailedException {
+	public void applyDependencies(DependencyCustomizer dependencies) throws CompilationFailedException {
 		dependencies.add("spring-rabbit");
 
 	}
 
 	@Override
 	public void applyImports(ImportCustomizer imports) throws CompilationFailedException {
-		imports.addStarImports("org.springframework.amqp.rabbit.annotation",
-				"org.springframework.amqp.rabbit.core",
-				"org.springframework.amqp.rabbit.config",
-				"org.springframework.amqp.rabbit.connection",
-				"org.springframework.amqp.rabbit.listener",
-				"org.springframework.amqp.rabbit.listener.adapter",
+		imports.addStarImports("org.springframework.amqp.rabbit.annotation", "org.springframework.amqp.rabbit.core",
+				"org.springframework.amqp.rabbit.config", "org.springframework.amqp.rabbit.connection",
+				"org.springframework.amqp.rabbit.listener", "org.springframework.amqp.rabbit.listener.adapter",
 				"org.springframework.amqp.core");
 	}
 
