@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2013 the original author or authors.
+ * Copyright 2012-2019 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -34,24 +34,21 @@ public class SpringMvcCompilerAutoConfiguration extends CompilerAutoConfiguratio
 
 	@Override
 	public boolean matches(ClassNode classNode) {
-		return AstUtils.hasAtLeastOneAnnotation(classNode, "Controller", "RestController",
-				"EnableWebMvc");
+		return AstUtils.hasAtLeastOneAnnotation(classNode, "Controller", "RestController", "EnableWebMvc");
 	}
 
 	@Override
 	public void applyDependencies(DependencyCustomizer dependencies) {
 		dependencies.ifAnyMissingClasses("org.springframework.web.servlet.mvc.Controller")
 				.add("spring-boot-starter-web");
-		dependencies.ifAnyMissingClasses("groovy.text.TemplateEngine")
-				.add("groovy-templates");
+		dependencies.ifAnyMissingClasses("groovy.text.TemplateEngine").add("groovy-templates");
 	}
 
 	@Override
 	public void applyImports(ImportCustomizer imports) {
 		imports.addStarImports("org.springframework.web.bind.annotation",
-				"org.springframework.web.servlet.config.annotation",
-				"org.springframework.web.servlet", "org.springframework.http",
-				"org.springframework.web.servlet.handler", "org.springframework.http",
+				"org.springframework.web.servlet.config.annotation", "org.springframework.web.servlet",
+				"org.springframework.http", "org.springframework.web.servlet.handler", "org.springframework.http",
 				"org.springframework.ui", "groovy.text");
 		imports.addStaticImport(GroovyTemplate.class.getName(), "template");
 	}
