@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2018 the original author or authors.
+ * Copyright 2012-2019 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -32,22 +32,19 @@ public class SpringWebsocketCompilerAutoConfiguration extends CompilerAutoConfig
 
 	@Override
 	public boolean matches(ClassNode classNode) {
-		return AstUtils.hasAtLeastOneAnnotation(classNode, "EnableWebSocket",
-				"EnableWebSocketMessageBroker");
+		return AstUtils.hasAtLeastOneAnnotation(classNode, "EnableWebSocket", "EnableWebSocketMessageBroker");
 	}
 
 	@Override
 	public void applyDependencies(DependencyCustomizer dependencies) {
-		dependencies.ifAnyMissingClasses(
-				"org.springframework.web.socket.config.annotation.EnableWebSocket")
+		dependencies.ifAnyMissingClasses("org.springframework.web.socket.config.annotation.EnableWebSocket")
 				.add("spring-boot-starter-websocket").add("spring-messaging");
 	}
 
 	@Override
 	public void applyImports(ImportCustomizer imports) {
 		imports.addStarImports("org.springframework.messaging.handler.annotation",
-				"org.springframework.messaging.simp.config",
-				"org.springframework.web.socket.handler",
+				"org.springframework.messaging.simp.config", "org.springframework.web.socket.handler",
 				"org.springframework.web.socket.sockjs.transport.handler",
 				"org.springframework.web.socket.config.annotation")
 				.addImports("org.springframework.web.socket.WebSocketHandler");
