@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2015 the original author or authors.
+ * Copyright 2012-2017 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -31,7 +31,7 @@ public class CompositeDependencyManagement implements DependencyManagement {
 
 	private final List<DependencyManagement> delegates;
 
-	private final List<Dependency> dependencies = new ArrayList<Dependency>();
+	private final List<Dependency> dependencies = new ArrayList<>();
 
 	public CompositeDependencyManagement(DependencyManagement... delegates) {
 		this.delegates = Arrays.asList(delegates);
