@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2018 the original author or authors.
+ * Copyright 2012-2019 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -56,7 +56,7 @@ public class AetherGrapeEngine implements GrapeEngine {
 	private static final Collection<Exclusion> WILDCARD_EXCLUSION;
 
 	static {
-		List<Exclusion> exclusions = new ArrayList<Exclusion>();
+		List<Exclusion> exclusions = new ArrayList<>();
 		exclusions.add(new Exclusion("*", "*", "*", "*"));
 		WILDCARD_EXCLUSION = Collections.unmodifiableList(exclusions);
 	}
@@ -73,18 +73,15 @@ public class AetherGrapeEngine implements GrapeEngine {
 
 	private final List<RemoteRepository> repositories;
 
-	public AetherGrapeEngine(GroovyClassLoader classLoader,
-			RepositorySystem repositorySystem,
-			DefaultRepositorySystemSession repositorySystemSession,
-			List<RemoteRepository> remoteRepositories,
+	public AetherGrapeEngine(GroovyClassLoader classLoader, RepositorySystem repositorySystem,
+			DefaultRepositorySystemSession repositorySystemSession, List<RemoteRepository> remoteRepositories,
 			DependencyResolutionContext resolutionContext, boolean quiet) {
 		this.classLoader = classLoader;
 		this.repositorySystem = repositorySystem;
 		this.session = repositorySystemSession;
 		this.resolutionContext = resolutionContext;
-		this.repositories = new ArrayList<RemoteRepository>();
-		List<RemoteRepository> remotes = new ArrayList<RemoteRepository>(
-				remoteRepositories);
+		this.repositories = new ArrayList<>();
+		List<RemoteRepository> remotes = new ArrayList<>(remoteRepositories);
 		Collections.reverse(remotes); // priority is reversed in addRepository
 		for (RemoteRepository repository : remotes) {
 			addRepository(repository);
@@ -92,27 +89,17 @@ public class AetherGrapeEngine implements GrapeEngine {
 		this.progressReporter = getProgressReporter(this.session, quiet);
 	}
 
-	private ProgressReporter getProgressReporter(DefaultRepositorySystemSession session,
-			boolean quiet) {
-		String progressReporter = (quiet ? "none" : System.getProperty(
-				"org.springframework.boot.cli.compiler.grape.ProgressReporter"));
-		if ("detail".equals(progressReporter)
-				|| Boolean.getBoolean("groovy.grape.report.downloads")) {
+	private ProgressReporter getProgressReporter(DefaultRepositorySystemSession session, boolean quiet) {
+		String progressReporter = (quiet ? "none"
+				: System.getProperty("org.springframework.boot.cli.compiler.grape.ProgressReporter"));
+		if ("detail".equals(progressReporter) || Boolean.getBoolean("groovy.grape.report.downloads")) {
 			return new DetailedProgressReporter(session, System.out);
 		}
-		else if ("none".equals(progressReporter)) {
-			return new ProgressReporter() {
-
-				@Override
-				public void finished() {
-
-				}
-
+		if ("none".equals(progressReporter)) {
+			return () -> {
 			};
 		}
-		else {
-			return new SummaryProgressReporter(session, System.out);
-		}
+		return new SummaryProgressReporter(session, System.out);
 	}
 
 	@Override
@@ -131,10 +118,7 @@ public class AetherGrapeEngine implements GrapeEngine {
 				classLoader.addURL(file.toURI().toURL());
 			}
 		}
-		catch (ArtifactResolutionException ex) {
-			throw new DependencyResolutionFailedException(ex);
-		}
-		catch (MalformedURLException ex) {
+		catch (ArtifactResolutionException | MalformedURLException ex) {
 			throw new DependencyResolutionFailedException(ex);
 		}
 		return null;
@@ -142,10 +126,9 @@ public class AetherGrapeEngine implements GrapeEngine {
 
 	@SuppressWarnings("unchecked")
 	private List<Exclusion> createExclusions(Map<?, ?> args) {
-		List<Exclusion> exclusions = new ArrayList<Exclusion>();
+		List<Exclusion> exclusions = new ArrayList<>();
 		if (args != null) {
-			List<Map<String, Object>> exclusionMaps = (List<Map<String, Object>>) args
-					.get("excludes");
+			List<Map<String, Object>> exclusionMaps = (List<Map<String, Object>>) args.get("excludes");
 			if (exclusionMaps != null) {
 				for (Map<String, Object> exclusionMap : exclusionMaps) {
 					exclusions.add(createExclusion(exclusionMap));
@@ -161,17 +144,15 @@ public class AetherGrapeEngine implements GrapeEngine {
 		return new Exclusion(group, module, "*", "*");
 	}
 
-	private List<Dependency> createDependencies(Map<?, ?>[] dependencyMaps,
-			List<Exclusion> exclusions) {
-		List<Dependency> dependencies = new ArrayList<Dependency>(dependencyMaps.length);
+	private List<Dependency> createDependencies(Map<?, ?>[] dependencyMaps, List<Exclusion> exclusions) {
+		List<Dependency> dependencies = new ArrayList<>(dependencyMaps.length);
 		for (Map<?, ?> dependencyMap : dependencyMaps) {
 			dependencies.add(createDependency(dependencyMap, exclusions));
 		}
 		return dependencies;
 	}
 
-	private Dependency createDependency(Map<?, ?> dependencyMap,
-			List<Exclusion> exclusions) {
+	private Dependency createDependency(Map<?, ?> dependencyMap, List<Exclusion> exclusions) {
 		Artifact artifact = createArtifact(dependencyMap);
 		if (isTransitive(dependencyMap)) {
 			return new Dependency(artifact, JavaScopes.COMPILE, false, exclusions);
@@ -201,8 +182,7 @@ public class AetherGrapeEngine implements GrapeEngine {
 			}
 		}
 		else if (ext != null && !type.equals(ext)) {
-			throw new IllegalArgumentException(
-					"If both type and ext are specified they must have the same value");
+			throw new IllegalArgumentException("If both type and ext are specified they must have the same value");
 		}
 		return type;
 	}
@@ -213,16 +193,15 @@ public class AetherGrapeEngine implements GrapeEngine {
 	}
 
 	private List<Dependency> getDependencies(DependencyResult dependencyResult) {
-		List<Dependency> dependencies = new ArrayList<Dependency>();
+		List<Dependency> dependencies = new ArrayList<>();
 		for (ArtifactResult artifactResult : dependencyResult.getArtifactResults()) {
-			dependencies.add(
-					new Dependency(artifactResult.getArtifact(), JavaScopes.COMPILE));
+			dependencies.add(new Dependency(artifactResult.getArtifact(), JavaScopes.COMPILE));
 		}
 		return dependencies;
 	}
 
 	private List<File> getFiles(DependencyResult dependencyResult) {
-		List<File> files = new ArrayList<File>();
+		List<File> files = new ArrayList<>();
 		for (ArtifactResult result : dependencyResult.getArtifactResults()) {
 			files.add(result.getArtifact().getFile());
 		}
@@ -238,8 +217,7 @@ public class AetherGrapeEngine implements GrapeEngine {
 	public void addResolver(Map<String, Object> args) {
 		String name = (String) args.get("name");
 		String root = (String) args.get("root");
-		RemoteRepository.Builder builder = new RemoteRepository.Builder(name, "default",
-				root);
+		RemoteRepository.Builder builder = new RemoteRepository.Builder(name, "default", root);
 		RemoteRepository repository = builder.build();
 		addRepository(repository);
 	}
@@ -255,8 +233,7 @@ public class AetherGrapeEngine implements GrapeEngine {
 	}
 
 	private RemoteRepository getPossibleMirror(RemoteRepository remoteRepository) {
-		RemoteRepository mirror = this.session.getMirrorSelector()
-				.getMirror(remoteRepository);
+		RemoteRepository mirror = this.session.getMirrorSelector().getMirror(remoteRepository);
 		if (mirror != null) {
 			return mirror;
 		}
@@ -275,8 +252,7 @@ public class AetherGrapeEngine implements GrapeEngine {
 	private RemoteRepository applyAuthentication(RemoteRepository repository) {
 		if (repository.getAuthentication() == null) {
 			RemoteRepository.Builder builder = new RemoteRepository.Builder(repository);
-			builder.setAuthentication(this.session.getAuthenticationSelector()
-					.getAuthentication(repository));
+			builder.setAuthentication(this.session.getAuthenticationSelector().getAuthentication(repository));
 			repository = builder.build();
 		}
 		return repository;
@@ -298,24 +274,22 @@ public class AetherGrapeEngine implements GrapeEngine {
 		List<Dependency> dependencies = createDependencies(dependencyMaps, exclusions);
 		try {
 			List<File> files = resolve(dependencies);
-			List<URI> uris = new ArrayList<URI>(files.size());
+			List<URI> uris = new ArrayList<>(files.size());
 			for (File file : files) {
 				uris.add(file.toURI());
 			}
-			return uris.toArray(new URI[uris.size()]);
+			return uris.toArray(new URI[0]);
 		}
 		catch (Exception ex) {
 			throw new DependencyResolutionFailedException(ex);
 		}
 	}
 
-	private List<File> resolve(List<Dependency> dependencies)
-			throws ArtifactResolutionException {
+	private List<File> resolve(List<Dependency> dependencies) throws ArtifactResolutionException {
 		try {
 			CollectRequest collectRequest = getCollectRequest(dependencies);
 			DependencyRequest dependencyRequest = getDependencyRequest(collectRequest);
-			DependencyResult result = this.repositorySystem
-					.resolveDependencies(this.session, dependencyRequest);
+			DependencyResult result = this.repositorySystem.resolveDependencies(this.session, dependencyRequest);
 			addManagedDependencies(result);
 			return getFiles(result);
 		}
@@ -328,18 +302,15 @@ public class AetherGrapeEngine implements GrapeEngine {
 	}
 
 	private CollectRequest getCollectRequest(List<Dependency> dependencies) {
-		CollectRequest collectRequest = new CollectRequest((Dependency) null,
-				dependencies, new ArrayList<RemoteRepository>(this.repositories));
-		collectRequest
-				.setManagedDependencies(this.resolutionContext.getManagedDependencies());
+		CollectRequest collectRequest = new CollectRequest((Dependency) null, dependencies,
+				new ArrayList<>(this.repositories));
+		collectRequest.setManagedDependencies(this.resolutionContext.getManagedDependencies());
 		return collectRequest;
 	}
 
 	private DependencyRequest getDependencyRequest(CollectRequest collectRequest) {
-		DependencyRequest dependencyRequest = new DependencyRequest(collectRequest,
-				DependencyFilterUtils.classpathFilter(JavaScopes.COMPILE,
-						JavaScopes.RUNTIME));
-		return dependencyRequest;
+		return new DependencyRequest(collectRequest,
+				DependencyFilterUtils.classpathFilter(JavaScopes.COMPILE, JavaScopes.RUNTIME));
 	}
 
 	private void addManagedDependencies(DependencyResult result) {
@@ -353,8 +324,7 @@ public class AetherGrapeEngine implements GrapeEngine {
 
 	@Override
 	public Object grab(String endorsedModule) {
-		throw new UnsupportedOperationException(
-				"Grabbing an endorsed module is not supported");
+		throw new UnsupportedOperationException("Grabbing an endorsed module is not supported");
 	}
 
 }
