@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2014 the original author or authors.
+ * Copyright 2012-2017 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -31,7 +31,7 @@ import org.eclipse.aether.repository.RemoteRepository;
  */
 public class CompositeProxySelector implements ProxySelector {
 
-	private List<ProxySelector> selectors = new ArrayList<ProxySelector>();
+	private List<ProxySelector> selectors = new ArrayList<>();
 
 	public CompositeProxySelector(List<ProxySelector> selectors) {
 		this.selectors = selectors;
