@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2018 the original author or authors.
+ * Copyright 2012-2019 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -34,25 +34,22 @@ import org.springframework.util.StringUtils;
  *
  * @author Andy Wilkinson
  */
-public class DefaultRepositorySystemSessionAutoConfiguration
-		implements RepositorySystemSessionAutoConfiguration {
+public class DefaultRepositorySystemSessionAutoConfiguration implements RepositorySystemSessionAutoConfiguration {
 
 	@Override
-	public void apply(DefaultRepositorySystemSession session,
-			RepositorySystem repositorySystem) {
+	public void apply(DefaultRepositorySystemSession session, RepositorySystem repositorySystem) {
 
 		if (session.getLocalRepositoryManager() == null) {
 			LocalRepository localRepository = new LocalRepository(getM2RepoDirectory());
-			LocalRepositoryManager localRepositoryManager = repositorySystem
-					.newLocalRepositoryManager(session, localRepository);
+			LocalRepositoryManager localRepositoryManager = repositorySystem.newLocalRepositoryManager(session,
+					localRepository);
 			session.setLocalRepositoryManager(localRepositoryManager);
 		}
 
 		ProxySelector existing = session.getProxySelector();
 		if (existing == null || !(existing instanceof CompositeProxySelector)) {
 			JreProxySelector fallback = new JreProxySelector();
-			ProxySelector selector = (existing != null)
-					? new CompositeProxySelector(Arrays.asList(existing, fallback))
+			ProxySelector selector = (existing != null) ? new CompositeProxySelector(Arrays.asList(existing, fallback))
 					: fallback;
 			session.setProxySelector(selector);
 		}
