@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2018 the original author or authors.
+ * Copyright 2012-2019 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -92,8 +92,8 @@ public final class RepositoryConfiguration {
 
 	@Override
 	public String toString() {
-		return "RepositoryConfiguration [name=" + this.name + ", uri=" + this.uri
-				+ ", snapshotsEnabled=" + this.snapshotsEnabled + "]";
+		return "RepositoryConfiguration [name=" + this.name + ", uri=" + this.uri + ", snapshotsEnabled="
+				+ this.snapshotsEnabled + "]";
 	}
 
 }
