@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2016 the original author or authors.
+ * Copyright 2012-2019 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -74,17 +74,15 @@ public abstract class ResourceUtils {
 			return getUrlsFromWildcardPath(path, classLoader);
 		}
 		catch (Exception ex) {
-			throw new IllegalArgumentException(
-					"Cannot create URL from path [" + path + "]", ex);
+			throw new IllegalArgumentException("Cannot create URL from path [" + path + "]", ex);
 		}
 	}
 
-	private static List<String> getUrlsFromWildcardPath(String path,
-			ClassLoader classLoader) throws IOException {
+	private static List<String> getUrlsFromWildcardPath(String path, ClassLoader classLoader) throws IOException {
 		if (path.contains(":")) {
 			return getUrlsFromPrefixedWildcardPath(path, classLoader);
 		}
-		Set<String> result = new LinkedHashSet<String>();
+		Set<String> result = new LinkedHashSet<>();
 		try {
 			result.addAll(getUrls(FILE_URL_PREFIX + path, classLoader));
 		}
@@ -93,21 +91,19 @@ public abstract class ResourceUtils {
 		}
 		path = stripLeadingSlashes(path);
 		result.addAll(getUrls(ALL_CLASSPATH_URL_PREFIX + path, classLoader));
-		return new ArrayList<String>(result);
+		return new ArrayList<>(result);
 	}
 
-	private static List<String> getUrlsFromPrefixedWildcardPath(String path,
-			ClassLoader classLoader) throws IOException {
-		Resource[] resources = new PathMatchingResourcePatternResolver(
-				new FileSearchResourceLoader(classLoader)).getResources(path);
-		List<String> result = new ArrayList<String>();
+	private static List<String> getUrlsFromPrefixedWildcardPath(String path, ClassLoader classLoader)
+			throws IOException {
+		Resource[] resources = new PathMatchingResourcePatternResolver(new FileSearchResourceLoader(classLoader))
+				.getResources(path);
+		List<String> result = new ArrayList<>();
 		for (Resource resource : resources) {
 			if (resource.exists()) {
-				if (resource.getURI().getScheme().equals("file")) {
-					if (resource.getFile().isDirectory()) {
-						result.addAll(getChildFiles(resource));
-						continue;
-					}
+				if (resource.getURI().getScheme().equals("file") && resource.getFile().isDirectory()) {
+					result.addAll(getChildFiles(resource));
+					continue;
 				}
 				result.add(absolutePath(resource));
 			}
@@ -116,9 +112,8 @@ public abstract class ResourceUtils {
 	}
 
 	private static List<String> getChildFiles(Resource resource) throws IOException {
-		Resource[] children = new PathMatchingResourcePatternResolver()
-				.getResources(resource.getURL() + "/**");
-		List<String> childFiles = new ArrayList<String>();
+		Resource[] children = new PathMatchingResourcePatternResolver().getResources(resource.getURL() + "/**");
+		List<String> childFiles = new ArrayList<>();
 		for (Resource child : children) {
 			if (!child.getFile().isDirectory()) {
 				childFiles.add(absolutePath(child));
@@ -154,14 +149,11 @@ public abstract class ResourceUtils {
 		public Resource getResource(String location) {
 			Assert.notNull(location, "Location must not be null");
 			if (location.startsWith(CLASSPATH_URL_PREFIX)) {
-				return new ClassPathResource(
-						location.substring(CLASSPATH_URL_PREFIX.length()),
-						getClassLoader());
+				return new ClassPathResource(location.substring(CLASSPATH_URL_PREFIX.length()), getClassLoader());
 			}
 			else {
 				if (location.startsWith(FILE_URL_PREFIX)) {
-					Resource resource = this.files.getResource(location);
-					return resource;
+					return this.files.getResource(location);
 				}
 				try {
 					// Try to parse the location as a URL...
