@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2018 the original author or authors.
+ * Copyright 2012-2019 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -20,7 +20,6 @@ import java.util.Collection;
 import java.util.Collections;
 import java.util.List;
 import java.util.Map;
-import java.util.Map.Entry;
 import java.util.Properties;
 
 import org.apache.commons.logging.Log;
@@ -89,11 +88,9 @@ import org.springframework.util.StringUtils;
  * @author Dave Syer
  * @author Andy Wilkinson
  */
-public class CloudFoundryVcapEnvironmentPostProcessor
-		implements EnvironmentPostProcessor, Ordered {
+public class CloudFoundryVcapEnvironmentPostProcessor implements EnvironmentPostProcessor, Ordered {
 
-	private static final Log logger = LogFactory
-			.getLog(CloudFoundryVcapEnvironmentPostProcessor.class);
+	private static final Log logger = LogFactory.getLog(CloudFoundryVcapEnvironmentPostProcessor.class);
 
 	private static final String VCAP_APPLICATION = "VCAP_APPLICATION";
 
@@ -102,8 +99,6 @@ public class CloudFoundryVcapEnvironmentPostProcessor
 	// Before ConfigFileApplicationListener so values there can use these ones
 	private int order = ConfigFileApplicationListener.DEFAULT_ORDER - 1;
 
-	private final JsonParser parser = JsonParserFactory.getJsonParser();
-
 	public void setOrder(int order) {
 		this.order = order;
 	}
@@ -114,24 +109,19 @@ public class CloudFoundryVcapEnvironmentPostProcessor
 	}
 
 	@Override
-	public void postProcessEnvironment(ConfigurableEnvironment environment,
-			SpringApplication application) {
+	public void postProcessEnvironment(ConfigurableEnvironment environment, SpringApplication application) {
 		if (CloudPlatform.CLOUD_FOUNDRY.isActive(environment)) {
 			Properties properties = new Properties();
-			addWithPrefix(properties, getPropertiesFromApplication(environment),
-					"vcap.application.");
-			addWithPrefix(properties, getPropertiesFromServices(environment),
-					"vcap.services.");
+			JsonParser jsonParser = JsonParserFactory.getJsonParser();
+			addWithPrefix(properties, getPropertiesFromApplication(environment, jsonParser), "vcap.application.");
+			addWithPrefix(properties, getPropertiesFromServices(environment, jsonParser), "vcap.services.");
 			MutablePropertySources propertySources = environment.getPropertySources();
-			if (propertySources.contains(
-					CommandLinePropertySource.COMMAND_LINE_PROPERTY_SOURCE_NAME)) {
-				propertySources.addAfter(
-						CommandLinePropertySource.COMMAND_LINE_PROPERTY_SOURCE_NAME,
+			if (propertySources.contains(CommandLinePropertySource.COMMAND_LINE_PROPERTY_SOURCE_NAME)) {
+				propertySources.addAfter(CommandLinePropertySource.COMMAND_LINE_PROPERTY_SOURCE_NAME,
 						new PropertiesPropertySource("vcap", properties));
 			}
 			else {
-				propertySources
-						.addFirst(new PropertiesPropertySource("vcap", properties));
+				propertySources.addFirst(new PropertiesPropertySource("vcap", properties));
 			}
 		}
 	}
@@ -143,11 +133,11 @@ public class CloudFoundryVcapEnvironmentPostProcessor
 		}
 	}
 
-	private Properties getPropertiesFromApplication(Environment environment) {
+	private Properties getPropertiesFromApplication(Environment environment, JsonParser parser) {
 		Properties properties = new Properties();
 		try {
 			String property = environment.getProperty(VCAP_APPLICATION, "{}");
-			Map<String, Object> map = this.parser.parseMap(property);
+			Map<String, Object> map = parser.parseMap(property);
 			extractPropertiesFromApplication(properties, map);
 		}
 		catch (Exception ex) {
@@ -156,11 +146,11 @@ public class CloudFoundryVcapEnvironmentPostProcessor
 		return properties;
 	}
 
-	private Properties getPropertiesFromServices(Environment environment) {
+	private Properties getPropertiesFromServices(Environment environment, JsonParser parser) {
 		Properties properties = new Properties();
 		try {
 			String property = environment.getProperty(VCAP_SERVICES, "{}");
-			Map<String, Object> map = this.parser.parseMap(property);
+			Map<String, Object> map = parser.parseMap(property);
 			extractPropertiesFromServices(properties, map);
 		}
 		catch (Exception ex) {
@@ -169,15 +159,13 @@ public class CloudFoundryVcapEnvironmentPostProcessor
 		return properties;
 	}
 
-	private void extractPropertiesFromApplication(Properties properties,
-			Map<String, Object> map) {
+	private void extractPropertiesFromApplication(Properties properties, Map<String, Object> map) {
 		if (map != null) {
 			flatten(properties, map, "");
 		}
 	}
 
-	private void extractPropertiesFromServices(Properties properties,
-			Map<String, Object> map) {
+	private void extractPropertiesFromServices(Properties properties, Map<String, Object> map) {
 		if (map != null) {
 			for (Object services : map.values()) {
 				@SuppressWarnings("unchecked")
@@ -197,40 +185,38 @@ public class CloudFoundryVcapEnvironmentPostProcessor
 
 	@SuppressWarnings("unchecked")
 	private void flatten(Properties properties, Map<String, Object> input, String path) {
-		for (Entry<String, Object> entry : input.entrySet()) {
-			String key = getFullKey(path, entry.getKey());
-			Object value = entry.getValue();
+		input.forEach((key, value) -> {
+			String name = getPropertyName(path, key);
 			if (value instanceof Map) {
 				// Need a compound key
-				flatten(properties, (Map<String, Object>) value, key);
+				flatten(properties, (Map<String, Object>) value, name);
 			}
 			else if (value instanceof Collection) {
 				// Need a compound key
 				Collection<Object> collection = (Collection<Object>) value;
-				properties.put(key,
-						StringUtils.collectionToCommaDelimitedString(collection));
+				properties.put(name, StringUtils.collectionToCommaDelimitedString(collection));
 				int count = 0;
 				for (Object item : collection) {
 					String itemKey = "[" + (count++) + "]";
-					flatten(properties, Collections.singletonMap(itemKey, item), key);
+					flatten(properties, Collections.singletonMap(itemKey, item), name);
 				}
 			}
 			else if (value instanceof String) {
-				properties.put(key, value);
+				properties.put(name, value);
 			}
 			else if (value instanceof Number) {
-				properties.put(key, value.toString());
+				properties.put(name, value.toString());
 			}
 			else if (value instanceof Boolean) {
-				properties.put(key, value.toString());
+				properties.put(name, value.toString());
 			}
 			else {
-				properties.put(key, (value != null) ? value : "");
+				properties.put(name, (value != null) ? value : "");
 			}
-		}
+		});
 	}
 
-	private String getFullKey(String path, String key) {
+	private String getPropertyName(String path, String key) {
 		if (!StringUtils.hasText(path)) {
 			return key;
 		}
