@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2017 the original author or authors.
+ * Copyright 2012-2019 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -40,8 +40,7 @@ import org.springframework.util.StringUtils;
  * @author Dave Syer
  * @author Phillip Webb
  */
-public class DelegatingApplicationListener
-		implements ApplicationListener<ApplicationEvent>, Ordered {
+public class DelegatingApplicationListener implements ApplicationListener<ApplicationEvent>, Ordered {
 
 	// NOTE: Similar to org.springframework.web.context.ContextLoader
 
@@ -70,26 +69,22 @@ public class DelegatingApplicationListener
 	}
 
 	@SuppressWarnings("unchecked")
-	private List<ApplicationListener<ApplicationEvent>> getListeners(
-			ConfigurableEnvironment environment) {
+	private List<ApplicationListener<ApplicationEvent>> getListeners(ConfigurableEnvironment environment) {
 		if (environment == null) {
 			return Collections.emptyList();
 		}
 		String classNames = environment.getProperty(PROPERTY_NAME);
-		List<ApplicationListener<ApplicationEvent>> listeners = new ArrayList<ApplicationListener<ApplicationEvent>>();
+		List<ApplicationListener<ApplicationEvent>> listeners = new ArrayList<>();
 		if (StringUtils.hasLength(classNames)) {
 			for (String className : StringUtils.commaDelimitedListToSet(classNames)) {
 				try {
-					Class<?> clazz = ClassUtils.forName(className,
-							ClassUtils.getDefaultClassLoader());
-					Assert.isAssignable(ApplicationListener.class, clazz, "class ["
-							+ className + "] must implement ApplicationListener");
-					listeners.add((ApplicationListener<ApplicationEvent>) BeanUtils
-							.instantiateClass(clazz));
+					Class<?> clazz = ClassUtils.forName(className, ClassUtils.getDefaultClassLoader());
+					Assert.isAssignable(ApplicationListener.class, clazz,
+							"class [" + className + "] must implement ApplicationListener");
+					listeners.add((ApplicationListener<ApplicationEvent>) BeanUtils.instantiateClass(clazz));
 				}
 				catch (Exception ex) {
-					throw new ApplicationContextException(
-							"Failed to load context listener class [" + className + "]",
+					throw new ApplicationContextException("Failed to load context listener class [" + className + "]",
 							ex);
 				}
 			}
