@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2015 the original author or authors.
+ * Copyright 2012-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -30,10 +30,15 @@ import org.springframework.beans.factory.annotation.Qualifier;
  *
  * @author Dave Syer
  */
-@Qualifier
+@Qualifier(ConfigurationPropertiesBinding.VALUE)
 @Target({ ElementType.TYPE, ElementType.METHOD })
 @Retention(RetentionPolicy.RUNTIME)
 @Documented
 public @interface ConfigurationPropertiesBinding {
 
+	/**
+	 * Concrete value for the {@link Qualifier @Qualifier}.
+	 */
+	String VALUE = "org.springframework.boot.context.properties.ConfigurationPropertiesBinding";
+
 }
