@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2018 the original author or authors.
+ * Copyright 2012-2019 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -19,13 +19,14 @@ package org.springframework.boot.env;
 import java.util.Collection;
 import java.util.LinkedHashMap;
 import java.util.Map;
-
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
+import java.util.Objects;
 
 import org.springframework.boot.SpringApplication;
 import org.springframework.boot.json.JsonParser;
 import org.springframework.boot.json.JsonParserFactory;
+import org.springframework.boot.origin.Origin;
+import org.springframework.boot.origin.OriginLookup;
+import org.springframework.boot.origin.PropertySourceOrigin;
 import org.springframework.core.Ordered;
 import org.springframework.core.env.ConfigurableEnvironment;
 import org.springframework.core.env.Environment;
@@ -45,10 +46,21 @@ import org.springframework.web.context.support.StandardServletEnvironment;
  *
  * @author Dave Syer
  * @author Phillip Webb
+ * @author Madhura Bhave
+ * @author Artsiom Yudovin
  * @since 1.3.0
  */
-public class SpringApplicationJsonEnvironmentPostProcessor
-		implements EnvironmentPostProcessor, Ordered {
+public class SpringApplicationJsonEnvironmentPostProcessor implements EnvironmentPostProcessor, Ordered {
+
+	/**
+	 * Name of the {@code spring.application.json} property.
+	 */
+	public static final String SPRING_APPLICATION_JSON_PROPERTY = "spring.application.json";
+
+	/**
+	 * Name of the {@code SPRING_APPLICATION_JSON} environment variable.
+	 */
+	public static final String SPRING_APPLICATION_JSON_ENVIRONMENT_VARIABLE = "SPRING_APPLICATION_JSON";
 
 	private static final String SERVLET_ENVIRONMENT_CLASS = "org.springframework.web."
 			+ "context.support.StandardServletEnvironment";
@@ -58,9 +70,6 @@ public class SpringApplicationJsonEnvironmentPostProcessor
 	 */
 	public static final int DEFAULT_ORDER = Ordered.HIGHEST_PRECEDENCE + 5;
 
-	private static final Log logger = LogFactory
-			.getLog(SpringApplicationJsonEnvironmentPostProcessor.class);
-
 	private int order = DEFAULT_ORDER;
 
 	@Override
@@ -73,26 +82,17 @@ public class SpringApplicationJsonEnvironmentPostProcessor
 	}
 
 	@Override
-	public void postProcessEnvironment(ConfigurableEnvironment environment,
-			SpringApplication application) {
-		String json = environment.resolvePlaceholders(
-				"${spring.application.json:${SPRING_APPLICATION_JSON:}}");
-		if (StringUtils.hasText(json)) {
-			processJson(environment, json);
-		}
+	public void postProcessEnvironment(ConfigurableEnvironment environment, SpringApplication application) {
+		MutablePropertySources propertySources = environment.getPropertySources();
+		propertySources.stream().map(JsonPropertyValue::get).filter(Objects::nonNull).findFirst()
+				.ifPresent((v) -> processJson(environment, v));
 	}
 
-	private void processJson(ConfigurableEnvironment environment, String json) {
-		try {
-			JsonParser parser = JsonParserFactory.getJsonParser();
-			Map<String, Object> map = parser.parseMap(json);
-			if (!map.isEmpty()) {
-				addJsonPropertySource(environment,
-						new MapPropertySource("spring.application.json", flatten(map)));
-			}
-		}
-		catch (Exception ex) {
-			logger.warn("Cannot parse JSON for spring.application.json: " + json, ex);
+	private void processJson(ConfigurableEnvironment environment, JsonPropertyValue propertyValue) {
+		JsonParser parser = JsonParserFactory.getJsonParser();
+		Map<String, Object> map = parser.parseMap(propertyValue.getJson());
+		if (!map.isEmpty()) {
+			addJsonPropertySource(environment, new JsonPropertySource(propertyValue, flatten(map)));
 		}
 	}
 
@@ -102,17 +102,14 @@ public class SpringApplicationJsonEnvironmentPostProcessor
 	 * @return the flattened map
 	 */
 	private Map<String, Object> flatten(Map<String, Object> map) {
-		Map<String, Object> result = new LinkedHashMap<String, Object>();
+		Map<String, Object> result = new LinkedHashMap<>();
 		flatten(null, result, map);
 		return result;
 	}
 
-	private void flatten(String prefix, Map<String, Object> result,
-			Map<String, Object> map) {
-		prefix = (prefix != null) ? prefix + "." : "";
-		for (Map.Entry<String, Object> entry : map.entrySet()) {
-			extract(prefix + entry.getKey(), result, entry.getValue());
-		}
+	private void flatten(String prefix, Map<String, Object> result, Map<String, Object> map) {
+		String namePrefix = (prefix != null) ? prefix + "." : "";
+		map.forEach((key, value) -> extract(namePrefix + key, result, value));
 	}
 
 	@SuppressWarnings("unchecked")
@@ -132,8 +129,7 @@ public class SpringApplicationJsonEnvironmentPostProcessor
 		}
 	}
 
-	private void addJsonPropertySource(ConfigurableEnvironment environment,
-			PropertySource<?> source) {
+	private void addJsonPropertySource(ConfigurableEnvironment environment, PropertySource<?> source) {
 		MutablePropertySources sources = environment.getPropertySources();
 		String name = findPropertySource(sources);
 		if (sources.contains(name)) {
@@ -145,12 +141,65 @@ public class SpringApplicationJsonEnvironmentPostProcessor
 	}
 
 	private String findPropertySource(MutablePropertySources sources) {
-		if (ClassUtils.isPresent(SERVLET_ENVIRONMENT_CLASS, null) && sources
-				.contains(StandardServletEnvironment.JNDI_PROPERTY_SOURCE_NAME)) {
+		if (ClassUtils.isPresent(SERVLET_ENVIRONMENT_CLASS, null)
+				&& sources.contains(StandardServletEnvironment.JNDI_PROPERTY_SOURCE_NAME)) {
 			return StandardServletEnvironment.JNDI_PROPERTY_SOURCE_NAME;
 
 		}
 		return StandardEnvironment.SYSTEM_PROPERTIES_PROPERTY_SOURCE_NAME;
 	}
 
+	private static class JsonPropertySource extends MapPropertySource implements OriginLookup<String> {
+
+		private final JsonPropertyValue propertyValue;
+
+		JsonPropertySource(JsonPropertyValue propertyValue, Map<String, Object> source) {
+			super(SPRING_APPLICATION_JSON_PROPERTY, source);
+			this.propertyValue = propertyValue;
+		}
+
+		@Override
+		public Origin getOrigin(String key) {
+			return this.propertyValue.getOrigin();
+		}
+
+	}
+
+	private static class JsonPropertyValue {
+
+		private static final String[] CANDIDATES = { SPRING_APPLICATION_JSON_PROPERTY,
+				SPRING_APPLICATION_JSON_ENVIRONMENT_VARIABLE };
+
+		private final PropertySource<?> propertySource;
+
+		private final String propertyName;
+
+		private final String json;
+
+		JsonPropertyValue(PropertySource<?> propertySource, String propertyName, String json) {
+			this.propertySource = propertySource;
+			this.propertyName = propertyName;
+			this.json = json;
+		}
+
+		public String getJson() {
+			return this.json;
+		}
+
+		public Origin getOrigin() {
+			return PropertySourceOrigin.get(this.propertySource, this.propertyName);
+		}
+
+		public static JsonPropertyValue get(PropertySource<?> propertySource) {
+			for (String candidate : CANDIDATES) {
+				Object value = propertySource.getProperty(candidate);
+				if (value != null && value instanceof String && StringUtils.hasLength((String) value)) {
+					return new JsonPropertyValue(propertySource, candidate, (String) value);
+				}
+			}
+			return null;
+		}
+
+	}
+
 }
