@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2018 the original author or authors.
+ * Copyright 2012-2019 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -36,9 +36,8 @@ import org.codehaus.groovy.control.CompilationFailedException;
  */
 public abstract class GroovyTemplate {
 
-	public static String template(String name)
-			throws IOException, CompilationFailedException, ClassNotFoundException {
-		return template(name, Collections.<String, Object>emptyMap());
+	public static String template(String name) throws IOException, CompilationFailedException, ClassNotFoundException {
+		return template(name, Collections.emptyMap());
 	}
 
 	public static String template(String name, Map<String, ?> model)
@@ -46,8 +45,7 @@ public abstract class GroovyTemplate {
 		return template(new GStringTemplateEngine(), name, model);
 	}
 
-	public static String template(TemplateEngine engine, String name,
-			Map<String, ?> model)
+	public static String template(TemplateEngine engine, String name, Map<String, ?> model)
 			throws IOException, CompilationFailedException, ClassNotFoundException {
 		Writable writable = getTemplate(engine, name).make(model);
 		StringWriter result = new StringWriter();
