@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2016 the original author or authors.
+ * Copyright 2012-2019 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 
 package org.springframework.boot.info;
 
-import java.util.Date;
+import java.time.Instant;
 import java.util.Iterator;
 import java.util.Map;
 import java.util.Properties;
@@ -55,16 +55,16 @@ public class InfoProperties implements Iterable<InfoProperties.Entry> {
 	}
 
 	/**
-	 * Return the value of the specified property as a {@link Date} or {@code null} if the
-	 * value is not a valid {@link Long} representation of an epoch time.
+	 * Return the value of the specified property as an {@link Instant} or {@code null} if
+	 * the value is not a valid {@link Long} representation of an epoch time.
 	 * @param key the key of the property
 	 * @return the property value
 	 */
-	public Date getDate(String key) {
+	public Instant getInstant(String key) {
 		String s = get(key);
 		if (s != null) {
 			try {
-				return new Date(Long.parseLong(s));
+				return Instant.ofEpochMilli(Long.parseLong(s));
 			}
 			catch (NumberFormatException ex) {
 				// Not valid epoch time
@@ -83,8 +83,7 @@ public class InfoProperties implements Iterable<InfoProperties.Entry> {
 	 * @return a {@link PropertySource}
 	 */
 	public PropertySource<?> toPropertySource() {
-		return new PropertiesPropertySource(getClass().getSimpleName(),
-				copy(this.entries));
+		return new PropertiesPropertySource(getClass().getSimpleName(), copy(this.entries));
 	}
 
 	private Properties copy(Properties properties) {
