@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2015 the original author or authors.
+ * Copyright 2012-2017 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -23,15 +23,13 @@ import java.io.IOException;
  *
  * @author Phillip Webb
  */
+@FunctionalInterface
 public interface Libraries {
 
 	/**
 	 * Represents no libraries.
 	 */
-	Libraries NONE = new Libraries() {
-		@Override
-		public void doWithLibraries(LibraryCallback callback) throws IOException {
-		}
+	Libraries NONE = (callback) -> {
 	};
 
 	/**
