@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2018 the original author or authors.
+ * Copyright 2012-2019 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -25,7 +25,6 @@ import java.io.InputStream;
 import java.util.ArrayDeque;
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.Collection;
 import java.util.Collections;
 import java.util.Comparator;
 import java.util.Deque;
@@ -42,6 +41,7 @@ import org.springframework.asm.ClassReader;
 import org.springframework.asm.ClassVisitor;
 import org.springframework.asm.MethodVisitor;
 import org.springframework.asm.Opcodes;
+import org.springframework.asm.SpringAsmInfo;
 import org.springframework.asm.Type;
 
 /**
@@ -57,24 +57,21 @@ public abstract class MainClassFinder {
 
 	private static final Type STRING_ARRAY_TYPE = Type.getType(String[].class);
 
-	private static final Type MAIN_METHOD_TYPE = Type.getMethodType(Type.VOID_TYPE,
-			STRING_ARRAY_TYPE);
+	private static final Type MAIN_METHOD_TYPE = Type.getMethodType(Type.VOID_TYPE, STRING_ARRAY_TYPE);
 
 	private static final String MAIN_METHOD_NAME = "main";
 
-	private static final FileFilter CLASS_FILE_FILTER = new FileFilter() {
-		@Override
-		public boolean accept(File file) {
-			return (file.isFile() && file.getName().endsWith(DOT_CLASS));
-		}
-	};
+	private static final FileFilter CLASS_FILE_FILTER = MainClassFinder::isClassFile;
 
-	private static final FileFilter PACKAGE_FOLDER_FILTER = new FileFilter() {
-		@Override
-		public boolean accept(File file) {
-			return file.isDirectory() && !file.getName().startsWith(".");
-		}
-	};
+	private static final FileFilter PACKAGE_FOLDER_FILTER = MainClassFinder::isPackageFolder;
+
+	private static boolean isClassFile(File file) {
+		return file.isFile() && file.getName().endsWith(DOT_CLASS);
+	}
+
+	private static boolean isPackageFolder(File file) {
+		return file.isDirectory() && !file.getName().startsWith(".");
+	}
 
 	/**
 	 * Find the main class from a given folder.
@@ -83,12 +80,7 @@ public abstract class MainClassFinder {
 	 * @throws IOException if the folder cannot be read
 	 */
 	public static String findMainClass(File rootFolder) throws IOException {
-		return doWithMainClasses(rootFolder, new MainClassCallback<String>() {
-			@Override
-			public String doWith(MainClass mainClass) {
-				return mainClass.getName();
-			}
-		});
+		return doWithMainClasses(rootFolder, MainClass::getName);
 	}
 
 	/**
@@ -111,51 +103,12 @@ public abstract class MainClassFinder {
 	 * @return the main class or {@code null}
 	 * @throws IOException if the folder cannot be read
 	 */
-	public static String findSingleMainClass(File rootFolder, String annotationName)
-			throws IOException {
+	public static String findSingleMainClass(File rootFolder, String annotationName) throws IOException {
 		SingleMainClassCallback callback = new SingleMainClassCallback(annotationName);
 		MainClassFinder.doWithMainClasses(rootFolder, callback);
 		return callback.getMainClassName();
 	}
 
-	/**
-	 * Find a single main class from the given {@code rootFolders}. A main class annotated
-	 * with an annotation with the given {@code annotationName} will be preferred over a
-	 * main class with no such annotation.
-	 * @param rootFolders the root folders to search
-	 * @param annotationName the name of the annotation that may be present on the main
-	 * class
-	 * @return the main class or {@code null}
-	 * @throws IOException if a root folder cannot be read
-	 * @since 1.5.5
-	 */
-	public static String findSingleMainClass(Collection<File> rootFolders,
-			String annotationName) throws IOException {
-		SingleMainClassCallback callback = new SingleMainClassCallback(annotationName);
-		doWithMainClasses(rootFolders, callback);
-		return callback.getMainClassName();
-	}
-
-	/**
-	 * Perform the given callback operation on all main classes from the given root
-	 * folder.
-	 * @param <T> the result type
-	 * @param rootFolders the root folders
-	 * @param callback the callback
-	 * @return the first callback result or {@code null}
-	 * @throws IOException in case of I/O errors
-	 */
-	static <T> T doWithMainClasses(Collection<File> rootFolders,
-			MainClassCallback<T> callback) throws IOException {
-		for (File rootFolder : rootFolders) {
-			T result = doWithMainClasses(rootFolder, callback);
-			if (result != null) {
-				return result;
-			}
-		}
-		return null;
-	}
-
 	/**
 	 * Perform the given callback operation on all main classes from the given root
 	 * folder.
@@ -165,37 +118,29 @@ public abstract class MainClassFinder {
 	 * @return the first callback result or {@code null}
 	 * @throws IOException in case of I/O errors
 	 */
-	static <T> T doWithMainClasses(File rootFolder, MainClassCallback<T> callback)
-			throws IOException {
+	static <T> T doWithMainClasses(File rootFolder, MainClassCallback<T> callback) throws IOException {
 		if (!rootFolder.exists()) {
 			return null; // nothing to do
 		}
 		if (!rootFolder.isDirectory()) {
-			throw new IllegalArgumentException(
-					"Invalid root folder '" + rootFolder + "'");
+			throw new IllegalArgumentException("Invalid root folder '" + rootFolder + "'");
 		}
 		String prefix = rootFolder.getAbsolutePath() + "/";
-		Deque<File> stack = new ArrayDeque<File>();
+		Deque<File> stack = new ArrayDeque<>();
 		stack.push(rootFolder);
 		while (!stack.isEmpty()) {
 			File file = stack.pop();
 			if (file.isFile()) {
-				InputStream inputStream = new FileInputStream(file);
-				try {
+				try (InputStream inputStream = new FileInputStream(file)) {
 					ClassDescriptor classDescriptor = createClassDescriptor(inputStream);
 					if (classDescriptor != null && classDescriptor.isMainMethodFound()) {
-						String className = convertToClassName(file.getAbsolutePath(),
-								prefix);
-						T result = callback.doWith(new MainClass(className,
-								classDescriptor.getAnnotationNames()));
+						String className = convertToClassName(file.getAbsolutePath(), prefix);
+						T result = callback.doWith(new MainClass(className, classDescriptor.getAnnotationNames()));
 						if (result != null) {
 							return result;
 						}
 					}
 				}
-				finally {
-					inputStream.close();
-				}
 			}
 			if (file.isDirectory()) {
 				pushAllSorted(stack, file.listFiles(PACKAGE_FOLDER_FILTER));
@@ -206,12 +151,7 @@ public abstract class MainClassFinder {
 	}
 
 	private static void pushAllSorted(Deque<File> stack, File[] files) {
-		Arrays.sort(files, new Comparator<File>() {
-			@Override
-			public int compare(File o1, File o2) {
-				return o1.getName().compareTo(o2.getName());
-			}
-		});
+		Arrays.sort(files, Comparator.comparing(File::getName));
 		for (File file : files) {
 			stack.push(file);
 		}
@@ -224,15 +164,8 @@ public abstract class MainClassFinder {
 	 * @return the main class or {@code null}
 	 * @throws IOException if the jar file cannot be read
 	 */
-	public static String findMainClass(JarFile jarFile, String classesLocation)
-			throws IOException {
-		return doWithMainClasses(jarFile, classesLocation,
-				new MainClassCallback<String>() {
-					@Override
-					public String doWith(MainClass mainClass) {
-						return mainClass.getName();
-					}
-				});
+	public static String findMainClass(JarFile jarFile, String classesLocation) throws IOException {
+		return doWithMainClasses(jarFile, classesLocation, MainClass::getName);
 	}
 
 	/**
@@ -242,8 +175,7 @@ public abstract class MainClassFinder {
 	 * @return the main class or {@code null}
 	 * @throws IOException if the jar file cannot be read
 	 */
-	public static String findSingleMainClass(JarFile jarFile, String classesLocation)
-			throws IOException {
+	public static String findSingleMainClass(JarFile jarFile, String classesLocation) throws IOException {
 		return findSingleMainClass(jarFile, classesLocation, null);
 	}
 
@@ -258,8 +190,8 @@ public abstract class MainClassFinder {
 	 * @return the main class or {@code null}
 	 * @throws IOException if the jar file cannot be read
 	 */
-	public static String findSingleMainClass(JarFile jarFile, String classesLocation,
-			String annotationName) throws IOException {
+	public static String findSingleMainClass(JarFile jarFile, String classesLocation, String annotationName)
+			throws IOException {
 		SingleMainClassCallback callback = new SingleMainClassCallback(annotationName);
 		MainClassFinder.doWithMainClasses(jarFile, classesLocation, callback);
 		return callback.getMainClassName();
@@ -274,28 +206,21 @@ public abstract class MainClassFinder {
 	 * @return the first callback result or {@code null}
 	 * @throws IOException in case of I/O errors
 	 */
-	static <T> T doWithMainClasses(JarFile jarFile, String classesLocation,
-			MainClassCallback<T> callback) throws IOException {
+	static <T> T doWithMainClasses(JarFile jarFile, String classesLocation, MainClassCallback<T> callback)
+			throws IOException {
 		List<JarEntry> classEntries = getClassEntries(jarFile, classesLocation);
-		Collections.sort(classEntries, new ClassEntryComparator());
+		classEntries.sort(new ClassEntryComparator());
 		for (JarEntry entry : classEntries) {
-			InputStream inputStream = new BufferedInputStream(
-					jarFile.getInputStream(entry));
-			try {
+			try (InputStream inputStream = new BufferedInputStream(jarFile.getInputStream(entry))) {
 				ClassDescriptor classDescriptor = createClassDescriptor(inputStream);
 				if (classDescriptor != null && classDescriptor.isMainMethodFound()) {
-					String className = convertToClassName(entry.getName(),
-							classesLocation);
-					T result = callback.doWith(new MainClass(className,
-							classDescriptor.getAnnotationNames()));
+					String className = convertToClassName(entry.getName(), classesLocation);
+					T result = callback.doWith(new MainClass(className, classDescriptor.getAnnotationNames()));
 					if (result != null) {
 						return result;
 					}
 				}
 			}
-			finally {
-				inputStream.close();
-			}
 		}
 		return null;
 	}
@@ -310,15 +235,13 @@ public abstract class MainClassFinder {
 		return name;
 	}
 
-	private static List<JarEntry> getClassEntries(JarFile source,
-			String classesLocation) {
+	private static List<JarEntry> getClassEntries(JarFile source, String classesLocation) {
 		classesLocation = (classesLocation != null) ? classesLocation : "";
 		Enumeration<JarEntry> sourceEntries = source.entries();
-		List<JarEntry> classEntries = new ArrayList<JarEntry>();
+		List<JarEntry> classEntries = new ArrayList<>();
 		while (sourceEntries.hasMoreElements()) {
 			JarEntry entry = sourceEntries.nextElement();
-			if (entry.getName().startsWith(classesLocation)
-					&& entry.getName().endsWith(DOT_CLASS)) {
+			if (entry.getName().startsWith(classesLocation) && entry.getName().endsWith(DOT_CLASS)) {
 				classEntries.add(entry);
 			}
 		}
@@ -358,12 +281,12 @@ public abstract class MainClassFinder {
 
 	private static class ClassDescriptor extends ClassVisitor {
 
-		private final Set<String> annotationNames = new LinkedHashSet<String>();
+		private final Set<String> annotationNames = new LinkedHashSet<>();
 
 		private boolean mainMethodFound;
 
 		ClassDescriptor() {
-			super(Opcodes.ASM4);
+			super(SpringAsmInfo.ASM_VERSION);
 		}
 
 		@Override
@@ -373,10 +296,8 @@ public abstract class MainClassFinder {
 		}
 
 		@Override
-		public MethodVisitor visitMethod(int access, String name, String desc,
-				String signature, String[] exceptions) {
-			if (isAccess(access, Opcodes.ACC_PUBLIC, Opcodes.ACC_STATIC)
-					&& MAIN_METHOD_NAME.equals(name)
+		public MethodVisitor visitMethod(int access, String name, String desc, String signature, String[] exceptions) {
+			if (isAccess(access, Opcodes.ACC_PUBLIC, Opcodes.ACC_STATIC) && MAIN_METHOD_NAME.equals(name)
 					&& MAIN_METHOD_TYPE.getDescriptor().equals(desc)) {
 				this.mainMethodFound = true;
 			}
@@ -436,8 +357,7 @@ public abstract class MainClassFinder {
 		 */
 		MainClass(String name, Set<String> annotationNames) {
 			this.name = name;
-			this.annotationNames = Collections
-					.unmodifiableSet(new HashSet<String>(annotationNames));
+			this.annotationNames = Collections.unmodifiableSet(new HashSet<>(annotationNames));
 		}
 
 		String getName() {
@@ -482,10 +402,9 @@ public abstract class MainClassFinder {
 	 * Find a single main class, throwing an {@link IllegalStateException} if multiple
 	 * candidates exist.
 	 */
-	private static final class SingleMainClassCallback
-			implements MainClassCallback<Object> {
+	private static final class SingleMainClassCallback implements MainClassCallback<Object> {
 
-		private final Set<MainClass> mainClasses = new LinkedHashSet<MainClass>();
+		private final Set<MainClass> mainClasses = new LinkedHashSet<>();
 
 		private final String annotationName;
 
@@ -500,7 +419,7 @@ public abstract class MainClassFinder {
 		}
 
 		private String getMainClassName() {
-			Set<MainClass> matchingMainClasses = new LinkedHashSet<MainClass>();
+			Set<MainClass> matchingMainClasses = new LinkedHashSet<>();
 			if (this.annotationName != null) {
 				for (MainClass mainClass : this.mainClasses) {
 					if (mainClass.getAnnotationNames().contains(this.annotationName)) {
@@ -513,11 +432,9 @@ public abstract class MainClassFinder {
 			}
 			if (matchingMainClasses.size() > 1) {
 				throw new IllegalStateException(
-						"Unable to find a single main class from the following candidates "
-								+ matchingMainClasses);
+						"Unable to find a single main class from the following candidates " + matchingMainClasses);
 			}
-			return (matchingMainClasses.isEmpty() ? null
-					: matchingMainClasses.iterator().next().getName());
+			return (matchingMainClasses.isEmpty() ? null : matchingMainClasses.iterator().next().getName());
 		}
 
 	}
