@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2016 the original author or authors.
+ * Copyright 2012-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,7 +17,6 @@
 package org.springframework.boot.loader.tools;
 
 import sun.misc.Signal;
-import sun.misc.SignalHandler;
 
 /**
  * Utilities for working with signal handling.
@@ -26,7 +25,6 @@ import sun.misc.SignalHandler;
  * @since 1.1.0
  */
 @SuppressWarnings("restriction")
-@UsesUnsafeJava
 public final class SignalUtils {
 
 	private static final Signal SIG_INT = new Signal("INT");
@@ -38,13 +36,8 @@ public final class SignalUtils {
 	 * Handle {@literal INT} signals by calling the specified {@link Runnable}.
 	 * @param runnable the runnable to call on SIGINT.
 	 */
-	public static void attachSignalHandler(final Runnable runnable) {
-		Signal.handle(SIG_INT, new SignalHandler() {
-			@Override
-			public void handle(Signal signal) {
-				runnable.run();
-			}
-		});
+	public static void attachSignalHandler(Runnable runnable) {
+		Signal.handle(SIG_INT, (signal) -> runnable.run());
 	}
 
 }
