@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2016 the original author or authors.
+ * Copyright 2012-2019 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -48,7 +48,7 @@ import org.springframework.util.StringUtils;
  */
 public class JavaLoggingSystem extends AbstractLoggingSystem {
 
-	private static final LogLevels<Level> LEVELS = new LogLevels<Level>();
+	private static final LogLevels<Level> LEVELS = new LogLevels<>();
 
 	static {
 		LEVELS.map(LogLevel.TRACE, Level.FINEST);
@@ -76,8 +76,7 @@ public class JavaLoggingSystem extends AbstractLoggingSystem {
 	}
 
 	@Override
-	protected void loadDefaults(LoggingInitializationContext initializationContext,
-			LogFile logFile) {
+	protected void loadDefaults(LoggingInitializationContext initializationContext, LogFile logFile) {
 		if (logFile != null) {
 			loadConfiguration(getPackagedConfigFile("logging-file.properties"), logFile);
 		}
@@ -87,26 +86,23 @@ public class JavaLoggingSystem extends AbstractLoggingSystem {
 	}
 
 	@Override
-	protected void loadConfiguration(LoggingInitializationContext initializationContext,
-			String location, LogFile logFile) {
+	protected void loadConfiguration(LoggingInitializationContext initializationContext, String location,
+			LogFile logFile) {
 		loadConfiguration(location, logFile);
 	}
 
 	protected void loadConfiguration(String location, LogFile logFile) {
 		Assert.notNull(location, "Location must not be null");
 		try {
-			String configuration = FileCopyUtils.copyToString(
-					new InputStreamReader(ResourceUtils.getURL(location).openStream()));
+			String configuration = FileCopyUtils
+					.copyToString(new InputStreamReader(ResourceUtils.getURL(location).openStream()));
 			if (logFile != null) {
-				configuration = configuration.replace("${LOG_FILE}",
-						StringUtils.cleanPath(logFile.toString()));
+				configuration = configuration.replace("${LOG_FILE}", StringUtils.cleanPath(logFile.toString()));
 			}
-			LogManager.getLogManager().readConfiguration(
-					new ByteArrayInputStream(configuration.getBytes()));
+			LogManager.getLogManager().readConfiguration(new ByteArrayInputStream(configuration.getBytes()));
 		}
 		catch (Exception ex) {
-			throw new IllegalStateException(
-					"Could not initialize Java logging from " + location, ex);
+			throw new IllegalStateException("Could not initialize Java logging from " + location, ex);
 		}
 	}
 
@@ -117,7 +113,6 @@ public class JavaLoggingSystem extends AbstractLoggingSystem {
 
 	@Override
 	public void setLogLevel(String loggerName, LogLevel level) {
-		Assert.notNull(level, "Level must not be null");
 		if (loggerName == null || ROOT_LOGGER_NAME.equals(loggerName)) {
 			loggerName = "";
 		}
@@ -129,12 +124,12 @@ public class JavaLoggingSystem extends AbstractLoggingSystem {
 
 	@Override
 	public List<LoggerConfiguration> getLoggerConfigurations() {
-		List<LoggerConfiguration> result = new ArrayList<LoggerConfiguration>();
+		List<LoggerConfiguration> result = new ArrayList<>();
 		Enumeration<String> names = LogManager.getLogManager().getLoggerNames();
 		while (names.hasMoreElements()) {
 			result.add(getLoggerConfiguration(names.nextElement()));
 		}
-		Collections.sort(result, CONFIGURATION_COMPARATOR);
+		result.sort(CONFIGURATION_COMPARATOR);
 		return Collections.unmodifiableList(result);
 	}
 
@@ -146,8 +141,7 @@ public class JavaLoggingSystem extends AbstractLoggingSystem {
 		}
 		LogLevel level = LEVELS.convertNativeToSystem(logger.getLevel());
 		LogLevel effectiveLevel = LEVELS.convertNativeToSystem(getEffectiveLevel(logger));
-		String name = (StringUtils.hasLength(logger.getName()) ? logger.getName()
-				: ROOT_LOGGER_NAME);
+		String name = (StringUtils.hasLength(logger.getName()) ? logger.getName() : ROOT_LOGGER_NAME);
 		return new LoggerConfiguration(name, level, effectiveLevel);
 	}
 
