@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2017 the original author or authors.
+ * Copyright 2002-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -32,6 +32,8 @@ import org.springframework.jmx.export.annotation.AnnotationMBeanExporter;
 import org.springframework.jmx.support.RegistrationPolicy;
 import org.springframework.jmx.support.WebSphereMBeanServerFactoryBean;
 import org.springframework.jndi.JndiLocatorDelegate;
+import org.springframework.lang.Nullable;
+import org.springframework.util.Assert;
 import org.springframework.util.ClassUtils;
 import org.springframework.util.StringUtils;
 
@@ -51,10 +53,13 @@ public class MBeanExportConfiguration implements ImportAware, EnvironmentAware,
 
 	private static final String MBEAN_EXPORTER_BEAN_NAME = "mbeanExporter";
 
+	@Nullable
 	private AnnotationAttributes enableMBeanExport;
 
+	@Nullable
 	private Environment environment;
 
+	@Nullable
 	private BeanFactory beanFactory;
 
 
@@ -83,15 +88,16 @@ public class MBeanExportConfiguration implements ImportAware, EnvironmentAware,
 	@Role(BeanDefinition.ROLE_INFRASTRUCTURE)
 	public AnnotationMBeanExporter mbeanExporter() {
 		AnnotationMBeanExporter exporter = new AnnotationMBeanExporter();
-		setupDomain(exporter);
-		setupServer(exporter);
-		setupRegistrationPolicy(exporter);
+		Assert.state(this.enableMBeanExport != null, "No EnableMBeanExport annotation found");
+		setupDomain(exporter, this.enableMBeanExport);
+		setupServer(exporter, this.enableMBeanExport);
+		setupRegistrationPolicy(exporter, this.enableMBeanExport);
 		return exporter;
 	}
 
-	private void setupDomain(AnnotationMBeanExporter exporter) {
-		String defaultDomain = this.enableMBeanExport.getString("defaultDomain");
-		if (defaultDomain != null && this.environment != null) {
+	private void setupDomain(AnnotationMBeanExporter exporter, AnnotationAttributes enableMBeanExport) {
+		String defaultDomain = enableMBeanExport.getString("defaultDomain");
+		if (StringUtils.hasLength(defaultDomain) && this.environment != null) {
 			defaultDomain = this.environment.resolvePlaceholders(defaultDomain);
 		}
 		if (StringUtils.hasText(defaultDomain)) {
@@ -99,30 +105,40 @@ public class MBeanExportConfiguration implements ImportAware, EnvironmentAware,
 		}
 	}
 
-	private void setupServer(AnnotationMBeanExporter exporter) {
-		String server = this.enableMBeanExport.getString("server");
-		if (server != null && this.environment != null) {
+	private void setupServer(AnnotationMBeanExporter exporter, AnnotationAttributes enableMBeanExport) {
+		String server = enableMBeanExport.getString("server");
+		if (StringUtils.hasLength(server) && this.environment != null) {
 			server = this.environment.resolvePlaceholders(server);
 		}
 		if (StringUtils.hasText(server)) {
+			Assert.state(this.beanFactory != null, "No BeanFactory set");
 			exporter.setServer(this.beanFactory.getBean(server, MBeanServer.class));
 		}
 		else {
 			SpecificPlatform specificPlatform = SpecificPlatform.get();
 			if (specificPlatform != null) {
-				exporter.setServer(specificPlatform.getMBeanServer());
+				MBeanServer mbeanServer = specificPlatform.getMBeanServer();
+				if (mbeanServer != null) {
+					exporter.setServer(mbeanServer);
+				}
 			}
 		}
 	}
 
-	private void setupRegistrationPolicy(AnnotationMBeanExporter exporter) {
-		RegistrationPolicy registrationPolicy = this.enableMBeanExport.getEnum("registration");
+	private void setupRegistrationPolicy(AnnotationMBeanExporter exporter, AnnotationAttributes enableMBeanExport) {
+		RegistrationPolicy registrationPolicy = enableMBeanExport.getEnum("registration");
 		exporter.setRegistrationPolicy(registrationPolicy);
 	}
 
 
+	/**
+	 * Specific platforms that might need custom MBean handling.
+	 */
 	public enum SpecificPlatform {
 
+		/**
+		 * Weblogic.
+		 */
 		WEBLOGIC("weblogic.management.Helper") {
 			@Override
 			public MBeanServer getMBeanServer() {
@@ -135,6 +151,9 @@ public class MBeanExportConfiguration implements ImportAware, EnvironmentAware,
 			}
 		},
 
+		/**
+		 * Websphere.
+		 */
 		WEBSPHERE("com.ibm.websphere.management.AdminServiceFactory") {
 			@Override
 			public MBeanServer getMBeanServer() {
@@ -150,8 +169,10 @@ public class MBeanExportConfiguration implements ImportAware, EnvironmentAware,
 			this.identifyingClass = identifyingClass;
 		}
 
+		@Nullable
 		public abstract MBeanServer getMBeanServer();
 
+		@Nullable
 		public static SpecificPlatform get() {
 			ClassLoader classLoader = MBeanExportConfiguration.class.getClassLoader();
 			for (SpecificPlatform environment : values()) {
