@@ -19,14 +19,24 @@ package org.springframework.core;
 import java.lang.annotation.Annotation;
 import java.lang.reflect.AnnotatedElement;
 import java.lang.reflect.Constructor;
+import java.lang.reflect.Executable;
 import java.lang.reflect.Member;
 import java.lang.reflect.Method;
-import java.lang.reflect.Modifier;
+import java.lang.reflect.Parameter;
 import java.lang.reflect.ParameterizedType;
 import java.lang.reflect.Type;
 import java.util.HashMap;
+import java.util.List;
 import java.util.Map;
+import java.util.Optional;
+import java.util.function.Predicate;
+import java.util.stream.Collectors;
 
+import kotlin.reflect.KFunction;
+import kotlin.reflect.KParameter;
+import kotlin.reflect.jvm.ReflectJvmMapping;
+
+import org.springframework.lang.Nullable;
 import org.springframework.util.Assert;
 import org.springframework.util.ClassUtils;
 
@@ -43,6 +53,7 @@ import org.springframework.util.ClassUtils;
  * @author Rob Harrop
  * @author Andy Clement
  * @author Sam Brannen
+ * @author Sebastien Deleuze
  * @since 2.0
  * @see org.springframework.core.annotation.SynthesizingMethodParameter
  */
@@ -50,44 +61,38 @@ public class MethodParameter {
 
 	private static final Annotation[] EMPTY_ANNOTATION_ARRAY = new Annotation[0];
 
-	private static final Class<?> javaUtilOptionalClass;
-
-	static {
-		Class<?> clazz;
-		try {
-			clazz = ClassUtils.forName("java.util.Optional", MethodParameter.class.getClassLoader());
-		}
-		catch (ClassNotFoundException ex) {
-			// Java 8 not available - Optional references simply not supported then.
-			clazz = null;
-		}
-		javaUtilOptionalClass = clazz;
-	}
-
-
-	private final Method method;
-
-	private final Constructor<?> constructor;
+	private final Executable executable;
 
 	private final int parameterIndex;
 
+	@Nullable
+	private volatile Parameter parameter;
+
 	private int nestingLevel = 1;
 
-	/** Map from Integer level to Integer type index */
+	/** Map from Integer level to Integer type index. */
+	@Nullable
 	Map<Integer, Integer> typeIndexesPerLevel;
 
+	@Nullable
 	private volatile Class<?> containingClass;
 
+	@Nullable
 	private volatile Class<?> parameterType;
 
+	@Nullable
 	private volatile Type genericParameterType;
 
+	@Nullable
 	private volatile Annotation[] parameterAnnotations;
 
+	@Nullable
 	private volatile ParameterNameDiscoverer parameterNameDiscoverer;
 
+	@Nullable
 	private volatile String parameterName;
 
+	@Nullable
 	private volatile MethodParameter nestedMethodParameter;
 
 
@@ -114,10 +119,9 @@ public class MethodParameter {
 	 */
 	public MethodParameter(Method method, int parameterIndex, int nestingLevel) {
 		Assert.notNull(method, "Method must not be null");
-		this.method = method;
-		this.parameterIndex = parameterIndex;
+		this.executable = method;
+		this.parameterIndex = validateIndex(method, parameterIndex);
 		this.nestingLevel = nestingLevel;
-		this.constructor = null;
 	}
 
 	/**
@@ -139,10 +143,9 @@ public class MethodParameter {
 	 */
 	public MethodParameter(Constructor<?> constructor, int parameterIndex, int nestingLevel) {
 		Assert.notNull(constructor, "Constructor must not be null");
-		this.constructor = constructor;
-		this.parameterIndex = parameterIndex;
+		this.executable = constructor;
+		this.parameterIndex = validateIndex(constructor, parameterIndex);
 		this.nestingLevel = nestingLevel;
-		this.method = null;
 	}
 
 	/**
@@ -152,9 +155,9 @@ public class MethodParameter {
 	 */
 	public MethodParameter(MethodParameter original) {
 		Assert.notNull(original, "Original must not be null");
-		this.method = original.method;
-		this.constructor = original.constructor;
+		this.executable = original.executable;
 		this.parameterIndex = original.parameterIndex;
+		this.parameter = original.parameter;
 		this.nestingLevel = original.nestingLevel;
 		this.typeIndexesPerLevel = original.typeIndexesPerLevel;
 		this.containingClass = original.containingClass;
@@ -171,8 +174,9 @@ public class MethodParameter {
 	 * <p>Note: Either Method or Constructor is available.
 	 * @return the Method, or {@code null} if none
 	 */
+	@Nullable
 	public Method getMethod() {
-		return this.method;
+		return (this.executable instanceof Method ? (Method) this.executable : null);
 	}
 
 	/**
@@ -180,15 +184,16 @@ public class MethodParameter {
 	 * <p>Note: Either Method or Constructor is available.
 	 * @return the Constructor, or {@code null} if none
 	 */
+	@Nullable
 	public Constructor<?> getConstructor() {
-		return this.constructor;
+		return (this.executable instanceof Constructor ? (Constructor<?>) this.executable : null);
 	}
 
 	/**
 	 * Return the class that declares the underlying Method or Constructor.
 	 */
 	public Class<?> getDeclaringClass() {
-		return getMember().getDeclaringClass();
+		return this.executable.getDeclaringClass();
 	}
 
 	/**
@@ -196,15 +201,7 @@ public class MethodParameter {
 	 * @return the Method or Constructor as Member
 	 */
 	public Member getMember() {
-		// NOTE: no ternary expression to retain JDK <8 compatibility even when using
-		// the JDK 8 compiler (potentially selecting java.lang.reflect.Executable
-		// as common type, with that new base class not available on older JDKs)
-		if (this.method != null) {
-			return this.method;
-		}
-		else {
-			return this.constructor;
-		}
+		return this.executable;
 	}
 
 	/**
@@ -214,15 +211,32 @@ public class MethodParameter {
 	 * @return the Method or Constructor as AnnotatedElement
 	 */
 	public AnnotatedElement getAnnotatedElement() {
-		// NOTE: no ternary expression to retain JDK <8 compatibility even when using
-		// the JDK 8 compiler (potentially selecting java.lang.reflect.Executable
-		// as common type, with that new base class not available on older JDKs)
-		if (this.method != null) {
-			return this.method;
+		return this.executable;
+	}
+
+	/**
+	 * Return the wrapped executable.
+	 * @return the Method or Constructor as Executable
+	 * @since 5.0
+	 */
+	public Executable getExecutable() {
+		return this.executable;
+	}
+
+	/**
+	 * Return the {@link Parameter} descriptor for method/constructor parameter.
+	 * @since 5.0
+	 */
+	public Parameter getParameter() {
+		if (this.parameterIndex < 0) {
+			throw new IllegalStateException("Cannot retrieve Parameter descriptor for method return type");
 		}
-		else {
-			return this.constructor;
+		Parameter parameter = this.parameter;
+		if (parameter == null) {
+			parameter = getExecutable().getParameters()[this.parameterIndex];
+			this.parameter = parameter;
 		}
+		return parameter;
 	}
 
 	/**
@@ -275,6 +289,7 @@ public class MethodParameter {
 	 * if none specified (indicating the default type index)
 	 * @see #getNestingLevel()
 	 */
+	@Nullable
 	public Integer getTypeIndexForCurrentLevel() {
 		return getTypeIndexForLevel(this.nestingLevel);
 	}
@@ -285,6 +300,7 @@ public class MethodParameter {
 	 * @return the corresponding type index, or {@code null}
 	 * if none specified (indicating the default type index)
 	 */
+	@Nullable
 	public Integer getTypeIndexForLevel(int nestingLevel) {
 		return getTypeIndexesPerLevel().get(nestingLevel);
 	}
@@ -294,7 +310,7 @@ public class MethodParameter {
 	 */
 	private Map<Integer, Integer> getTypeIndexesPerLevel() {
 		if (this.typeIndexesPerLevel == null) {
-			this.typeIndexesPerLevel = new HashMap<Integer, Integer>(4);
+			this.typeIndexesPerLevel = new HashMap<>(4);
 		}
 		return this.typeIndexesPerLevel;
 	}
@@ -307,22 +323,43 @@ public class MethodParameter {
 	 * @since 4.3
 	 */
 	public MethodParameter nested() {
-		if (this.nestedMethodParameter != null) {
-			return this.nestedMethodParameter;
+		MethodParameter nestedParam = this.nestedMethodParameter;
+		if (nestedParam != null) {
+			return nestedParam;
 		}
-		MethodParameter nestedParam = clone();
+		nestedParam = clone();
 		nestedParam.nestingLevel = this.nestingLevel + 1;
 		this.nestedMethodParameter = nestedParam;
 		return nestedParam;
 	}
 
 	/**
-	 * Return whether this method parameter is declared as optional
-	 * in the form of Java 8's {@link java.util.Optional}.
+	 * Return whether this method indicates a parameter which is not required:
+	 * either in the form of Java 8's {@link java.util.Optional}, any variant
+	 * of a parameter-level {@code Nullable} annotation (such as from JSR-305
+	 * or the FindBugs set of annotations), or a language-level nullable type
+	 * declaration in Kotlin.
 	 * @since 4.3
 	 */
 	public boolean isOptional() {
-		return (getParameterType() == javaUtilOptionalClass);
+		return (getParameterType() == Optional.class || hasNullableAnnotation() ||
+				(KotlinDetector.isKotlinReflectPresent() &&
+						KotlinDetector.isKotlinType(getContainingClass()) &&
+						KotlinDelegate.isOptional(this)));
+	}
+
+	/**
+	 * Check whether this method parameter is annotated with any variant of a
+	 * {@code Nullable} annotation, e.g. {@code javax.annotation.Nullable} or
+	 * {@code edu.umd.cs.findbugs.annotations.Nullable}.
+	 */
+	private boolean hasNullableAnnotation() {
+		for (Annotation ann : getParameterAnnotations()) {
+			if ("Nullable".equals(ann.annotationType().getSimpleName())) {
+				return true;
+			}
+		}
+		return false;
 	}
 
 	/**
@@ -334,7 +371,7 @@ public class MethodParameter {
 	 * @see #nested()
 	 */
 	public MethodParameter nestedIfOptional() {
-		return (isOptional() ? nested() : this);
+		return (getParameterType() == Optional.class ? nested() : this);
 	}
 
 	/**
@@ -345,13 +382,14 @@ public class MethodParameter {
 	}
 
 	public Class<?> getContainingClass() {
-		return (this.containingClass != null ? this.containingClass : getDeclaringClass());
+		Class<?> containingClass = this.containingClass;
+		return (containingClass != null ? containingClass : getDeclaringClass());
 	}
 
 	/**
 	 * Set a resolved (generic) parameter type.
 	 */
-	void setParameterType(Class<?> parameterType) {
+	void setParameterType(@Nullable Class<?> parameterType) {
 		this.parameterType = parameterType;
 	}
 
@@ -367,9 +405,7 @@ public class MethodParameter {
 				paramType = (method != null ? method.getReturnType() : void.class);
 			}
 			else {
-				paramType = (this.method != null ?
-						this.method.getParameterTypes()[this.parameterIndex] :
-						this.constructor.getParameterTypes()[this.parameterIndex]);
+				paramType = this.executable.getParameterTypes()[this.parameterIndex];
 			}
 			this.parameterType = paramType;
 		}
@@ -389,12 +425,11 @@ public class MethodParameter {
 				paramType = (method != null ? method.getGenericReturnType() : void.class);
 			}
 			else {
-				Type[] genericParameterTypes = (this.method != null ?
-						this.method.getGenericParameterTypes() : this.constructor.getGenericParameterTypes());
+				Type[] genericParameterTypes = this.executable.getGenericParameterTypes();
 				int index = this.parameterIndex;
-				if (this.constructor != null && this.constructor.getDeclaringClass().isMemberClass() &&
-						!Modifier.isStatic(this.constructor.getDeclaringClass().getModifiers()) &&
-						genericParameterTypes.length == this.constructor.getParameterTypes().length - 1) {
+				if (this.executable instanceof Constructor &&
+						ClassUtils.isInnerClass(this.executable.getDeclaringClass()) &&
+						genericParameterTypes.length == this.executable.getParameterCount() - 1) {
 					// Bug in javac: type array excludes enclosing instance parameter
 					// for inner classes with at least one generic constructor parameter,
 					// so access it with the actual parameter index lowered by 1
@@ -476,8 +511,10 @@ public class MethodParameter {
 	 * @param annotationType the annotation type to look for
 	 * @return the annotation object, or {@code null} if not found
 	 */
+	@Nullable
 	public <A extends Annotation> A getMethodAnnotation(Class<A> annotationType) {
-		return adaptAnnotation(getAnnotatedElement().getAnnotation(annotationType));
+		A annotation = getAnnotatedElement().getAnnotation(annotationType);
+		return (annotation != null ? adaptAnnotation(annotation) : null);
 	}
 
 	/**
@@ -496,12 +533,11 @@ public class MethodParameter {
 	public Annotation[] getParameterAnnotations() {
 		Annotation[] paramAnns = this.parameterAnnotations;
 		if (paramAnns == null) {
-			Annotation[][] annotationArray = (this.method != null ?
-					this.method.getParameterAnnotations() : this.constructor.getParameterAnnotations());
+			Annotation[][] annotationArray = this.executable.getParameterAnnotations();
 			int index = this.parameterIndex;
-			if (this.constructor != null && this.constructor.getDeclaringClass().isMemberClass() &&
-					!Modifier.isStatic(this.constructor.getDeclaringClass().getModifiers()) &&
-					annotationArray.length == this.constructor.getParameterTypes().length - 1) {
+			if (this.executable instanceof Constructor &&
+					ClassUtils.isInnerClass(this.executable.getDeclaringClass()) &&
+					annotationArray.length == this.executable.getParameterCount() - 1) {
 				// Bug in javac in JDK <9: annotation array excludes enclosing instance parameter
 				// for inner classes, so access it with the actual parameter index lowered by 1
 				index = this.parameterIndex - 1;
@@ -528,6 +564,7 @@ public class MethodParameter {
 	 * @return the annotation object, or {@code null} if not found
 	 */
 	@SuppressWarnings("unchecked")
+	@Nullable
 	public <A extends Annotation> A getParameterAnnotation(Class<A> annotationType) {
 		Annotation[] anns = getParameterAnnotations();
 		for (Annotation ann : anns) {
@@ -553,7 +590,7 @@ public class MethodParameter {
 	 * this point; it just allows discovery to happen when the application calls
 	 * {@link #getParameterName()} (if ever).
 	 */
-	public void initParameterNameDiscovery(ParameterNameDiscoverer parameterNameDiscoverer) {
+	public void initParameterNameDiscovery(@Nullable ParameterNameDiscoverer parameterNameDiscoverer) {
 		this.parameterNameDiscoverer = parameterNameDiscoverer;
 	}
 
@@ -564,11 +601,20 @@ public class MethodParameter {
 	 * {@link #initParameterNameDiscovery ParameterNameDiscoverer}
 	 * has been set to begin with)
 	 */
+	@Nullable
 	public String getParameterName() {
+		if (this.parameterIndex < 0) {
+			return null;
+		}
 		ParameterNameDiscoverer discoverer = this.parameterNameDiscoverer;
 		if (discoverer != null) {
-			String[] parameterNames = (this.method != null ?
-					discoverer.getParameterNames(this.method) : discoverer.getParameterNames(this.constructor));
+			String[] parameterNames = null;
+			if (this.executable instanceof Method) {
+				parameterNames = discoverer.getParameterNames((Method) this.executable);
+			}
+			else if (this.executable instanceof Constructor) {
+				parameterNames = discoverer.getParameterNames((Constructor<?>) this.executable);
+			}
 			if (parameterNames != null) {
 				this.parameterName = parameterNames[this.parameterIndex];
 			}
@@ -612,17 +658,18 @@ public class MethodParameter {
 			return false;
 		}
 		MethodParameter otherParam = (MethodParameter) other;
-		return (this.parameterIndex == otherParam.parameterIndex && getMember().equals(otherParam.getMember()));
+		return (this.parameterIndex == otherParam.parameterIndex && getExecutable().equals(otherParam.getExecutable()));
 	}
 
 	@Override
 	public int hashCode() {
-		return (getMember().hashCode() * 31 + this.parameterIndex);
+		return (getExecutable().hashCode() * 31 + this.parameterIndex);
 	}
 
 	@Override
 	public String toString() {
-		return (this.method != null ? "method '" + this.method.getName() + "'" : "constructor") +
+		Method method = getMethod();
+		return (method != null ? "method '" + method.getName() + "'" : "constructor") +
 				" parameter " + this.parameterIndex;
 	}
 
@@ -634,23 +681,124 @@ public class MethodParameter {
 
 	/**
 	 * Create a new MethodParameter for the given method or constructor.
-	 * <p>This is a convenience constructor for scenarios where a
+	 * <p>This is a convenience factory method for scenarios where a
 	 * Method or Constructor reference is treated in a generic fashion.
 	 * @param methodOrConstructor the Method or Constructor to specify a parameter for
 	 * @param parameterIndex the index of the parameter
 	 * @return the corresponding MethodParameter instance
+	 * @deprecated as of 5.0, in favor of {@link #forExecutable}
 	 */
+	@Deprecated
 	public static MethodParameter forMethodOrConstructor(Object methodOrConstructor, int parameterIndex) {
-		if (methodOrConstructor instanceof Method) {
-			return new MethodParameter((Method) methodOrConstructor, parameterIndex);
-		}
-		else if (methodOrConstructor instanceof Constructor) {
-			return new MethodParameter((Constructor<?>) methodOrConstructor, parameterIndex);
-		}
-		else {
+		if (!(methodOrConstructor instanceof Executable)) {
 			throw new IllegalArgumentException(
 					"Given object [" + methodOrConstructor + "] is neither a Method nor a Constructor");
 		}
+		return forExecutable((Executable) methodOrConstructor, parameterIndex);
+	}
+
+	/**
+	 * Create a new MethodParameter for the given method or constructor.
+	 * <p>This is a convenience factory method for scenarios where a
+	 * Method or Constructor reference is treated in a generic fashion.
+	 * @param executable the Method or Constructor to specify a parameter for
+	 * @param parameterIndex the index of the parameter
+	 * @return the corresponding MethodParameter instance
+	 * @since 5.0
+	 */
+	public static MethodParameter forExecutable(Executable executable, int parameterIndex) {
+		if (executable instanceof Method) {
+			return new MethodParameter((Method) executable, parameterIndex);
+		}
+		else if (executable instanceof Constructor) {
+			return new MethodParameter((Constructor<?>) executable, parameterIndex);
+		}
+		else {
+			throw new IllegalArgumentException("Not a Method/Constructor: " + executable);
+		}
+	}
+
+	/**
+	 * Create a new MethodParameter for the given parameter descriptor.
+	 * <p>This is a convenience factory method for scenarios where a
+	 * Java 8 {@link Parameter} descriptor is already available.
+	 * @param parameter the parameter descriptor
+	 * @return the corresponding MethodParameter instance
+	 * @since 5.0
+	 */
+	public static MethodParameter forParameter(Parameter parameter) {
+		return forExecutable(parameter.getDeclaringExecutable(), findParameterIndex(parameter));
+	}
+
+	protected static int findParameterIndex(Parameter parameter) {
+		Executable executable = parameter.getDeclaringExecutable();
+		Parameter[] allParams = executable.getParameters();
+		// Try first with identity checks for greater performance.
+		for (int i = 0; i < allParams.length; i++) {
+			if (parameter == allParams[i]) {
+				return i;
+			}
+		}
+		// Potentially try again with object equality checks in order to avoid race
+		// conditions while invoking java.lang.reflect.Executable.getParameters().
+		for (int i = 0; i < allParams.length; i++) {
+			if (parameter.equals(allParams[i])) {
+				return i;
+			}
+		}
+		throw new IllegalArgumentException("Given parameter [" + parameter +
+				"] does not match any parameter in the declaring executable");
+	}
+
+	private static int validateIndex(Executable executable, int parameterIndex) {
+		int count = executable.getParameterCount();
+		Assert.isTrue(parameterIndex >= -1 && parameterIndex < count,
+				() -> "Parameter index needs to be between -1 and " + (count - 1));
+		return parameterIndex;
+	}
+
+
+	/**
+	 * Inner class to avoid a hard dependency on Kotlin at runtime.
+	 */
+	private static class KotlinDelegate {
+
+		/**
+		 * Check whether the specified {@link MethodParameter} represents a nullable Kotlin type
+		 * or an optional parameter (with a default value in the Kotlin declaration).
+		 */
+		public static boolean isOptional(MethodParameter param) {
+			Method method = param.getMethod();
+			Constructor<?> ctor = param.getConstructor();
+			int index = param.getParameterIndex();
+			if (method != null && index == -1) {
+				KFunction<?> function = ReflectJvmMapping.getKotlinFunction(method);
+				return (function != null && function.getReturnType().isMarkedNullable());
+			}
+			else {
+				KFunction<?> function = null;
+				Predicate<KParameter> predicate = null;
+				if (method != null) {
+					function = ReflectJvmMapping.getKotlinFunction(method);
+					predicate = p -> KParameter.Kind.VALUE.equals(p.getKind());
+				}
+				else if (ctor != null) {
+					function = ReflectJvmMapping.getKotlinFunction(ctor);
+					predicate = p -> KParameter.Kind.VALUE.equals(p.getKind()) ||
+							KParameter.Kind.INSTANCE.equals(p.getKind());
+				}
+				if (function != null) {
+					List<KParameter> parameters = function.getParameters();
+					KParameter parameter = parameters
+							.stream()
+							.filter(predicate)
+							.collect(Collectors.toList())
+							.get(index);
+					return (parameter.getType().isMarkedNullable() || parameter.isOptional());
+				}
+			}
+			return false;
+		}
 	}
 
 }
