@@ -1,11 +1,11 @@
 /*
- * Copyright 2002-2016 the original author or authors.
+ * Copyright 2002-2019 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -16,6 +16,7 @@
 
 package org.springframework.expression.spel.ast;
 
+import java.lang.reflect.Constructor;
 import java.lang.reflect.Field;
 import java.lang.reflect.Member;
 import java.lang.reflect.Method;
@@ -37,6 +38,9 @@ import org.springframework.expression.spel.ExpressionState;
 import org.springframework.expression.spel.SpelEvaluationException;
 import org.springframework.expression.spel.SpelMessage;
 import org.springframework.expression.spel.support.ReflectivePropertyAccessor;
+import org.springframework.lang.Nullable;
+import org.springframework.util.Assert;
+import org.springframework.util.ReflectionUtils;
 
 /**
  * An Indexer can index into some proceeding structure to access a particular piece of it.
@@ -51,7 +55,7 @@ import org.springframework.expression.spel.support.ReflectivePropertyAccessor;
 // TODO support correct syntax for multidimensional [][][] and not [,,,]
 public class Indexer extends SpelNodeImpl {
 
-	private static enum IndexedType {ARRAY, LIST, MAP, STRING, OBJECT}
+	private enum IndexedType {ARRAY, LIST, MAP, STRING, OBJECT}
 
 
 	// These fields are used when the indexer is being used as a property read accessor.
@@ -59,10 +63,13 @@ public class Indexer extends SpelNodeImpl {
 	// is used to read the property. If they do not match, the correct accessor is
 	// discovered and then cached for later use.
 
+	@Nullable
 	private String cachedReadName;
 
+	@Nullable
 	private Class<?> cachedReadTargetType;
 
+	@Nullable
 	private PropertyAccessor cachedReadAccessor;
 
 	// These fields are used when the indexer is being used as a property write accessor.
@@ -70,12 +77,16 @@ public class Indexer extends SpelNodeImpl {
 	// is used to write the property. If they do not match, the correct accessor is
 	// discovered and then cached for later use.
 
+	@Nullable
 	private String cachedWriteName;
 
+	@Nullable
 	private Class<?> cachedWriteTargetType;
 
+	@Nullable
 	private PropertyAccessor cachedWriteAccessor;
 
+	@Nullable
 	private IndexedType indexedType;
 
 
@@ -90,7 +101,7 @@ public class Indexer extends SpelNodeImpl {
 	}
 
 	@Override
-	public void setValue(ExpressionState state, Object newValue) throws EvaluationException {
+	public void setValue(ExpressionState state, @Nullable Object newValue) throws EvaluationException {
 		getValueRef(state).setValue(newValue);
 	}
 
@@ -103,79 +114,83 @@ public class Indexer extends SpelNodeImpl {
 	@Override
 	protected ValueRef getValueRef(ExpressionState state) throws EvaluationException {
 		TypedValue context = state.getActiveContextObject();
-		Object targetObject = context.getValue();
+		Object target = context.getValue();
 		TypeDescriptor targetDescriptor = context.getTypeDescriptor();
-		TypedValue indexValue = null;
-		Object index = null;
+		TypedValue indexValue;
+		Object index;
 
-		// This first part of the if clause prevents a 'double dereference' of
-		// the property (SPR-5847)
-		if (targetObject instanceof Map && (this.children[0] instanceof PropertyOrFieldReference)) {
+		// This first part of the if clause prevents a 'double dereference' of the property (SPR-5847)
+		if (target instanceof Map && (this.children[0] instanceof PropertyOrFieldReference)) {
 			PropertyOrFieldReference reference = (PropertyOrFieldReference) this.children[0];
 			index = reference.getName();
 			indexValue = new TypedValue(index);
 		}
 		else {
-			// In case the map key is unqualified, we want it evaluated against
-			// the root object so temporarily push that on whilst evaluating the key
+			// In case the map key is unqualified, we want it evaluated against the root object
+			// so temporarily push that on whilst evaluating the key
 			try {
 				state.pushActiveContextObject(state.getRootContextObject());
 				indexValue = this.children[0].getValueInternal(state);
 				index = indexValue.getValue();
+				Assert.state(index != null, "No index");
 			}
 			finally {
 				state.popActiveContextObject();
 			}
 		}
 
+		// Raise a proper exception in case of a null target
+		if (target == null) {
+			throw new SpelEvaluationException(getStartPosition(), SpelMessage.CANNOT_INDEX_INTO_NULL_VALUE);
+		}
+		// At this point, we need a TypeDescriptor for a non-null target object
+		Assert.state(targetDescriptor != null, "No type descriptor");
+
 		// Indexing into a Map
-		if (targetObject instanceof Map) {
+		if (target instanceof Map) {
 			Object key = index;
 			if (targetDescriptor.getMapKeyTypeDescriptor() != null) {
 				key = state.convertValue(key, targetDescriptor.getMapKeyTypeDescriptor());
 			}
 			this.indexedType = IndexedType.MAP;
-			return new MapIndexingValueRef(state.getTypeConverter(), (Map<?, ?>) targetObject, key, targetDescriptor);
+			return new MapIndexingValueRef(state.getTypeConverter(), (Map<?, ?>) target, key, targetDescriptor);
 		}
 
-		if (targetObject == null) {
-			throw new SpelEvaluationException(getStartPosition(), SpelMessage.CANNOT_INDEX_INTO_NULL_VALUE);
-		}
-
-		// if the object is something that looks indexable by an integer,
+		// If the object is something that looks indexable by an integer,
 		// attempt to treat the index value as a number
-		if (targetObject.getClass().isArray() || targetObject instanceof Collection || targetObject instanceof String) {
+		if (target.getClass().isArray() || target instanceof Collection || target instanceof String) {
 			int idx = (Integer) state.convertValue(index, TypeDescriptor.valueOf(Integer.class));
-			if (targetObject.getClass().isArray()) {
+			if (target.getClass().isArray()) {
 				this.indexedType = IndexedType.ARRAY;
-				return new ArrayIndexingValueRef(state.getTypeConverter(), targetObject, idx, targetDescriptor);
+				return new ArrayIndexingValueRef(state.getTypeConverter(), target, idx, targetDescriptor);
 			}
-			else if (targetObject instanceof Collection) {
-				if (targetObject instanceof List) {
+			else if (target instanceof Collection) {
+				if (target instanceof List) {
 					this.indexedType = IndexedType.LIST;
 				}
-				return new CollectionIndexingValueRef((Collection<?>) targetObject, idx, targetDescriptor,
+				return new CollectionIndexingValueRef((Collection<?>) target, idx, targetDescriptor,
 						state.getTypeConverter(), state.getConfiguration().isAutoGrowCollections(),
 						state.getConfiguration().getMaximumAutoGrowSize());
 			}
 			else {
 				this.indexedType = IndexedType.STRING;
-				return new StringIndexingLValue((String) targetObject, idx, targetDescriptor);
+				return new StringIndexingLValue((String) target, idx, targetDescriptor);
 			}
 		}
 
 		// Try and treat the index value as a property of the context object
-		// TODO could call the conversion service to convert the value to a String
-		if (String.class == indexValue.getTypeDescriptor().getType()) {
+		// TODO: could call the conversion service to convert the value to a String
+		TypeDescriptor valueType = indexValue.getTypeDescriptor();
+		if (valueType != null && String.class == valueType.getType()) {
 			this.indexedType = IndexedType.OBJECT;
-			return new PropertyIndexingValueRef(targetObject, (String) indexValue.getValue(),
-					state.getEvaluationContext(), targetDescriptor);
+			return new PropertyIndexingValueRef(
+					target, (String) index, state.getEvaluationContext(), targetDescriptor);
 		}
 
-		throw new SpelEvaluationException(getStartPosition(), SpelMessage.INDEXING_NOT_SUPPORTED_FOR_TYPE,
-				targetDescriptor.toString());
+		throw new SpelEvaluationException(
+				getStartPosition(), SpelMessage.INDEXING_NOT_SUPPORTED_FOR_TYPE, targetDescriptor);
 	}
-	
+
 	@Override
 	public boolean isCompilable() {
 		if (this.indexedType == IndexedType.ARRAY) {
@@ -188,16 +203,14 @@ public class Indexer extends SpelNodeImpl {
 			return (this.children[0] instanceof PropertyOrFieldReference || this.children[0].isCompilable());
 		}
 		else if (this.indexedType == IndexedType.OBJECT) {
-			// If the string name is changing the accessor is clearly going to change (so compilation is not possible)
-			if (this.cachedReadAccessor != null && 
-					(this.cachedReadAccessor instanceof ReflectivePropertyAccessor.OptimalPropertyAccessor) &&
-					(getChild(0) instanceof StringLiteral)) {
-				return true;
-			}
+			// If the string name is changing the accessor is clearly going to change (so no compilation possible)
+			return (this.cachedReadAccessor != null &&
+					this.cachedReadAccessor instanceof ReflectivePropertyAccessor.OptimalPropertyAccessor &&
+					getChild(0) instanceof StringLiteral);
 		}
 		return false;
 	}
-	
+
 	@Override
 	public void generateCode(MethodVisitor mv, CodeFlow cf) {
 		String descriptor = cf.lastDescriptor();
@@ -236,7 +249,7 @@ public class Indexer extends SpelNodeImpl {
 				mv.visitTypeInsn(CHECKCAST, "[C");
 				insn = CALOAD;
 			}
-			else { 
+			else {
 				mv.visitTypeInsn(CHECKCAST, "["+ this.exitTypeDescriptor +
 						(CodeFlow.isPrimitiveArray(this.exitTypeDescriptor) ? "" : ";"));
 						//depthPlusOne(exitTypeDescriptor)+"Ljava/lang/Object;");
@@ -271,12 +284,14 @@ public class Indexer extends SpelNodeImpl {
 				this.children[0].generateCode(mv, cf);
 				cf.exitCompilationScope();
 			}
-			mv.visitMethodInsn(INVOKEINTERFACE, "java/util/Map", "get", "(Ljava/lang/Object;)Ljava/lang/Object;", true);
-		} 
+			mv.visitMethodInsn(
+					INVOKEINTERFACE, "java/util/Map", "get", "(Ljava/lang/Object;)Ljava/lang/Object;", true);
+		}
 
 		else if (this.indexedType == IndexedType.OBJECT) {
 			ReflectivePropertyAccessor.OptimalPropertyAccessor accessor =
 					(ReflectivePropertyAccessor.OptimalPropertyAccessor) this.cachedReadAccessor;
+			Assert.state(accessor != null, "No cached read accessor");
 			Member member = accessor.member;
 			boolean isStatic = Modifier.isStatic(member.getModifiers());
 			String classDesc = member.getDeclaringClass().getName().replace('.', '/');
@@ -298,7 +313,7 @@ public class Indexer extends SpelNodeImpl {
 				mv.visitFieldInsn((isStatic ? GETSTATIC : GETFIELD), classDesc, member.getName(),
 						CodeFlow.toJvmDescriptor(((Field) member).getType()));
 			}
-		} 
+		}
 
 		cf.pushDescriptor(this.exitTypeDescriptor);
 	}
@@ -317,33 +332,13 @@ public class Indexer extends SpelNodeImpl {
 	}
 
 
-	private void setArrayElement(TypeConverter converter, Object ctx, int idx, Object newValue,
+	private void setArrayElement(TypeConverter converter, Object ctx, int idx, @Nullable Object newValue,
 			Class<?> arrayComponentType) throws EvaluationException {
 
-		if (arrayComponentType == Double.TYPE) {
-			double[] array = (double[]) ctx;
+		if (arrayComponentType == Boolean.TYPE) {
+			boolean[] array = (boolean[]) ctx;
 			checkAccess(array.length, idx);
-			array[idx] = convertValue(converter, newValue, Double.class);
-		}
-		else if (arrayComponentType == Float.TYPE) {
-			float[] array = (float[]) ctx;
-			checkAccess(array.length, idx);
-			array[idx] = convertValue(converter, newValue, Float.class);
-		}
-		else if (arrayComponentType == Long.TYPE) {
-			long[] array = (long[]) ctx;
-			checkAccess(array.length, idx);
-			array[idx] = convertValue(converter, newValue, Long.class);
-		}
-		else if (arrayComponentType == Integer.TYPE) {
-			int[] array = (int[]) ctx;
-			checkAccess(array.length, idx);
-			array[idx] = convertValue(converter, newValue, Integer.class);
-		}
-		else if (arrayComponentType == Short.TYPE) {
-			short[] array = (short[]) ctx;
-			checkAccess(array.length, idx);
-			array[idx] = convertValue(converter, newValue, Short.class);
+			array[idx] = convertValue(converter, newValue, Boolean.class);
 		}
 		else if (arrayComponentType == Byte.TYPE) {
 			byte[] array = (byte[]) ctx;
@@ -355,10 +350,30 @@ public class Indexer extends SpelNodeImpl {
 			checkAccess(array.length, idx);
 			array[idx] = convertValue(converter, newValue, Character.class);
 		}
-		else if (arrayComponentType == Boolean.TYPE) {
-			boolean[] array = (boolean[]) ctx;
+		else if (arrayComponentType == Double.TYPE) {
+			double[] array = (double[]) ctx;
 			checkAccess(array.length, idx);
-			array[idx] = convertValue(converter, newValue, Boolean.class);
+			array[idx] = convertValue(converter, newValue, Double.class);
+		}
+		else if (arrayComponentType == Float.TYPE) {
+			float[] array = (float[]) ctx;
+			checkAccess(array.length, idx);
+			array[idx] = convertValue(converter, newValue, Float.class);
+		}
+		else if (arrayComponentType == Integer.TYPE) {
+			int[] array = (int[]) ctx;
+			checkAccess(array.length, idx);
+			array[idx] = convertValue(converter, newValue, Integer.class);
+		}
+		else if (arrayComponentType == Long.TYPE) {
+			long[] array = (long[]) ctx;
+			checkAccess(array.length, idx);
+			array[idx] = convertValue(converter, newValue, Long.class);
+		}
+		else if (arrayComponentType == Short.TYPE) {
+			short[] array = (short[]) ctx;
+			checkAccess(array.length, idx);
+			array[idx] = convertValue(converter, newValue, Short.class);
 		}
 		else {
 			Object[] array = (Object[]) ctx;
@@ -369,34 +384,10 @@ public class Indexer extends SpelNodeImpl {
 
 	private Object accessArrayElement(Object ctx, int idx) throws SpelEvaluationException {
 		Class<?> arrayComponentType = ctx.getClass().getComponentType();
-		if (arrayComponentType == Double.TYPE) {
-			double[] array = (double[]) ctx;
+		if (arrayComponentType == Boolean.TYPE) {
+			boolean[] array = (boolean[]) ctx;
 			checkAccess(array.length, idx);
-			this.exitTypeDescriptor = "D";
-			return array[idx];
-		}
-		else if (arrayComponentType == Float.TYPE) {
-			float[] array = (float[]) ctx;
-			checkAccess(array.length, idx);
-			this.exitTypeDescriptor = "F";
-			return array[idx];
-		}
-		else if (arrayComponentType == Long.TYPE) {
-			long[] array = (long[]) ctx;
-			checkAccess(array.length, idx);
-			this.exitTypeDescriptor = "J";
-			return array[idx];
-		}
-		else if (arrayComponentType == Integer.TYPE) {
-			int[] array = (int[]) ctx;
-			checkAccess(array.length, idx);
-			this.exitTypeDescriptor = "I";
-			return array[idx];
-		}
-		else if (arrayComponentType == Short.TYPE) {
-			short[] array = (short[]) ctx;
-			checkAccess(array.length, idx);
-			this.exitTypeDescriptor = "S";
+			this.exitTypeDescriptor = "Z";
 			return array[idx];
 		}
 		else if (arrayComponentType == Byte.TYPE) {
@@ -411,10 +402,34 @@ public class Indexer extends SpelNodeImpl {
 			this.exitTypeDescriptor = "C";
 			return array[idx];
 		}
-		else if (arrayComponentType == Boolean.TYPE) {
-			boolean[] array = (boolean[]) ctx;
+		else if (arrayComponentType == Double.TYPE) {
+			double[] array = (double[]) ctx;
 			checkAccess(array.length, idx);
-			this.exitTypeDescriptor = "Z";
+			this.exitTypeDescriptor = "D";
+			return array[idx];
+		}
+		else if (arrayComponentType == Float.TYPE) {
+			float[] array = (float[]) ctx;
+			checkAccess(array.length, idx);
+			this.exitTypeDescriptor = "F";
+			return array[idx];
+		}
+		else if (arrayComponentType == Integer.TYPE) {
+			int[] array = (int[]) ctx;
+			checkAccess(array.length, idx);
+			this.exitTypeDescriptor = "I";
+			return array[idx];
+		}
+		else if (arrayComponentType == Long.TYPE) {
+			long[] array = (long[]) ctx;
+			checkAccess(array.length, idx);
+			this.exitTypeDescriptor = "J";
+			return array[idx];
+		}
+		else if (arrayComponentType == Short.TYPE) {
+			short[] array = (short[]) ctx;
+			checkAccess(array.length, idx);
+			this.exitTypeDescriptor = "S";
 			return array[idx];
 		}
 		else {
@@ -434,8 +449,13 @@ public class Indexer extends SpelNodeImpl {
 	}
 
 	@SuppressWarnings("unchecked")
-	private <T> T convertValue(TypeConverter converter, Object value, Class<T> targetType) {
-		return (T) converter.convertValue(value, TypeDescriptor.forObject(value), TypeDescriptor.valueOf(targetType));
+	private <T> T convertValue(TypeConverter converter, @Nullable Object value, Class<T> targetType) {
+		T result = (T) converter.convertValue(
+				value, TypeDescriptor.forObject(value), TypeDescriptor.valueOf(targetType));
+		if (result == null) {
+			throw new IllegalStateException("Null conversion result for index [" + value + "]");
+		}
+		return result;
 	}
 
 
@@ -463,9 +483,10 @@ public class Indexer extends SpelNodeImpl {
 		}
 
 		@Override
-		public void setValue(Object newValue) {
-			setArrayElement(this.typeConverter, this.array, this.index, newValue,
-					this.typeDescriptor.getElementTypeDescriptor().getType());
+		public void setValue(@Nullable Object newValue) {
+			TypeDescriptor elementType = this.typeDescriptor.getElementTypeDescriptor();
+			Assert.state(elementType != null, "No element type");
+			setArrayElement(this.typeConverter, this.array, this.index, newValue, elementType.getType());
 		}
 
 		@Override
@@ -482,11 +503,14 @@ public class Indexer extends SpelNodeImpl {
 
 		private final Map map;
 
+		@Nullable
 		private final Object key;
 
 		private final TypeDescriptor mapEntryDescriptor;
 
-		public MapIndexingValueRef(TypeConverter typeConverter, Map map, Object key, TypeDescriptor mapEntryDescriptor) {
+		public MapIndexingValueRef(
+				TypeConverter typeConverter, Map map, @Nullable Object key, TypeDescriptor mapEntryDescriptor) {
+
 			this.typeConverter = typeConverter;
 			this.map = map;
 			this.key = key;
@@ -501,7 +525,7 @@ public class Indexer extends SpelNodeImpl {
 		}
 
 		@Override
-		public void setValue(Object newValue) {
+		public void setValue(@Nullable Object newValue) {
 			if (this.mapEntryDescriptor.getMapValueTypeDescriptor() != null) {
 				newValue = this.typeConverter.convertValue(newValue, TypeDescriptor.forObject(newValue),
 						this.mapEntryDescriptor.getMapValueTypeDescriptor());
@@ -526,8 +550,9 @@ public class Indexer extends SpelNodeImpl {
 
 		private final TypeDescriptor targetObjectTypeDescriptor;
 
-		public PropertyIndexingValueRef(Object targetObject, String value, EvaluationContext evaluationContext,
-				TypeDescriptor targetObjectTypeDescriptor) {
+		public PropertyIndexingValueRef(Object targetObject, String value,
+				EvaluationContext evaluationContext, TypeDescriptor targetObjectTypeDescriptor) {
+
 			this.targetObject = targetObject;
 			this.name = value;
 			this.evaluationContext = evaluationContext;
@@ -542,68 +567,68 @@ public class Indexer extends SpelNodeImpl {
 						Indexer.this.cachedReadTargetType != null &&
 						Indexer.this.cachedReadTargetType.equals(targetObjectRuntimeClass)) {
 					// It is OK to use the cached accessor
-					return Indexer.this.cachedReadAccessor.read(this.evaluationContext, this.targetObject, this.name);
+					PropertyAccessor accessor = Indexer.this.cachedReadAccessor;
+					Assert.state(accessor != null, "No cached read accessor");
+					return accessor.read(this.evaluationContext, this.targetObject, this.name);
 				}
 				List<PropertyAccessor> accessorsToTry = AstUtils.getPropertyAccessorsToTry(
 						targetObjectRuntimeClass, this.evaluationContext.getPropertyAccessors());
-				if (accessorsToTry != null) {
-					for (PropertyAccessor accessor : accessorsToTry) {
-						if (accessor.canRead(this.evaluationContext, this.targetObject, this.name)) {
-							if (accessor instanceof ReflectivePropertyAccessor) {
-								accessor = ((ReflectivePropertyAccessor) accessor).createOptimalAccessor(
-										this.evaluationContext, this.targetObject, this.name);
-							}
-							Indexer.this.cachedReadAccessor = accessor;
-							Indexer.this.cachedReadName = this.name;
-							Indexer.this.cachedReadTargetType = targetObjectRuntimeClass;
-							if (accessor instanceof ReflectivePropertyAccessor.OptimalPropertyAccessor) {
-								ReflectivePropertyAccessor.OptimalPropertyAccessor optimalAccessor =
-										(ReflectivePropertyAccessor.OptimalPropertyAccessor) accessor;
-								Member member = optimalAccessor.member;
-								Indexer.this.exitTypeDescriptor = CodeFlow.toDescriptor(member instanceof Method ?
-										((Method) member).getReturnType() : ((Field) member).getType());
-							}
-							return accessor.read(this.evaluationContext, this.targetObject, this.name);
+				for (PropertyAccessor accessor : accessorsToTry) {
+					if (accessor.canRead(this.evaluationContext, this.targetObject, this.name)) {
+						if (accessor instanceof ReflectivePropertyAccessor) {
+							accessor = ((ReflectivePropertyAccessor) accessor).createOptimalAccessor(
+									this.evaluationContext, this.targetObject, this.name);
 						}
+						Indexer.this.cachedReadAccessor = accessor;
+						Indexer.this.cachedReadName = this.name;
+						Indexer.this.cachedReadTargetType = targetObjectRuntimeClass;
+						if (accessor instanceof ReflectivePropertyAccessor.OptimalPropertyAccessor) {
+							ReflectivePropertyAccessor.OptimalPropertyAccessor optimalAccessor =
+									(ReflectivePropertyAccessor.OptimalPropertyAccessor) accessor;
+							Member member = optimalAccessor.member;
+							Indexer.this.exitTypeDescriptor = CodeFlow.toDescriptor(member instanceof Method ?
+									((Method) member).getReturnType() : ((Field) member).getType());
+						}
+						return accessor.read(this.evaluationContext, this.targetObject, this.name);
 					}
 				}
 			}
 			catch (AccessException ex) {
-				throw new SpelEvaluationException(getStartPosition(), ex, SpelMessage.INDEXING_NOT_SUPPORTED_FOR_TYPE,
-						this.targetObjectTypeDescriptor.toString());
+				throw new SpelEvaluationException(getStartPosition(), ex,
+						SpelMessage.INDEXING_NOT_SUPPORTED_FOR_TYPE, this.targetObjectTypeDescriptor.toString());
 			}
-			throw new SpelEvaluationException(getStartPosition(), SpelMessage.INDEXING_NOT_SUPPORTED_FOR_TYPE,
-					this.targetObjectTypeDescriptor.toString());
+			throw new SpelEvaluationException(getStartPosition(),
+					SpelMessage.INDEXING_NOT_SUPPORTED_FOR_TYPE, this.targetObjectTypeDescriptor.toString());
 		}
 
 		@Override
-		public void setValue(Object newValue) {
+		public void setValue(@Nullable Object newValue) {
 			Class<?> contextObjectClass = getObjectClass(this.targetObject);
 			try {
 				if (Indexer.this.cachedWriteName != null && Indexer.this.cachedWriteName.equals(this.name) &&
 						Indexer.this.cachedWriteTargetType != null &&
 						Indexer.this.cachedWriteTargetType.equals(contextObjectClass)) {
 					// It is OK to use the cached accessor
-					Indexer.this.cachedWriteAccessor.write(this.evaluationContext, this.targetObject, this.name, newValue);
+					PropertyAccessor accessor = Indexer.this.cachedWriteAccessor;
+					Assert.state(accessor != null, "No cached write accessor");
+					accessor.write(this.evaluationContext, this.targetObject, this.name, newValue);
 					return;
 				}
-				List<PropertyAccessor> accessorsToTry =
-						AstUtils.getPropertyAccessorsToTry(contextObjectClass, this.evaluationContext.getPropertyAccessors());
-				if (accessorsToTry != null) {
-					for (PropertyAccessor accessor : accessorsToTry) {
-						if (accessor.canWrite(this.evaluationContext, this.targetObject, this.name)) {
-							Indexer.this.cachedWriteName = this.name;
-							Indexer.this.cachedWriteTargetType = contextObjectClass;
-							Indexer.this.cachedWriteAccessor = accessor;
-							accessor.write(this.evaluationContext, this.targetObject, this.name, newValue);
-							return;
-						}
+				List<PropertyAccessor> accessorsToTry = AstUtils.getPropertyAccessorsToTry(
+						contextObjectClass, this.evaluationContext.getPropertyAccessors());
+				for (PropertyAccessor accessor : accessorsToTry) {
+					if (accessor.canWrite(this.evaluationContext, this.targetObject, this.name)) {
+						Indexer.this.cachedWriteName = this.name;
+						Indexer.this.cachedWriteTargetType = contextObjectClass;
+						Indexer.this.cachedWriteAccessor = accessor;
+						accessor.write(this.evaluationContext, this.targetObject, this.name, newValue);
+						return;
 					}
 				}
 			}
 			catch (AccessException ex) {
-				throw new SpelEvaluationException(getStartPosition(), ex, SpelMessage.EXCEPTION_DURING_PROPERTY_WRITE,
-						this.name, ex.getMessage());
+				throw new SpelEvaluationException(getStartPosition(), ex,
+						SpelMessage.EXCEPTION_DURING_PROPERTY_WRITE, this.name, ex.getMessage());
 			}
 		}
 
@@ -614,7 +639,7 @@ public class Indexer extends SpelNodeImpl {
 	}
 
 
-	@SuppressWarnings({ "rawtypes", "unchecked" })
+	@SuppressWarnings({"rawtypes", "unchecked"})
 	private class CollectionIndexingValueRef implements ValueRef {
 
 		private final Collection collection;
@@ -629,11 +654,12 @@ public class Indexer extends SpelNodeImpl {
 
 		private final int maximumSize;
 
-		public CollectionIndexingValueRef(Collection collection, int index, TypeDescriptor collectionEntryTypeDescriptor,
+		public CollectionIndexingValueRef(Collection collection, int index, TypeDescriptor collectionEntryDescriptor,
 				TypeConverter typeConverter, boolean growCollection, int maximumSize) {
+
 			this.collection = collection;
 			this.index = index;
-			this.collectionEntryDescriptor = collectionEntryTypeDescriptor;
+			this.collectionEntryDescriptor = collectionEntryDescriptor;
 			this.typeConverter = typeConverter;
 			this.growCollection = growCollection;
 			this.maximumSize = maximumSize;
@@ -658,7 +684,7 @@ public class Indexer extends SpelNodeImpl {
 		}
 
 		@Override
-		public void setValue(Object newValue) {
+		public void setValue(@Nullable Object newValue) {
 			growCollectionIfNecessary();
 			if (this.collection instanceof List) {
 				List list = (List) this.collection;
@@ -684,13 +710,15 @@ public class Indexer extends SpelNodeImpl {
 					throw new SpelEvaluationException(getStartPosition(), SpelMessage.UNABLE_TO_GROW_COLLECTION);
 				}
 				if (this.collectionEntryDescriptor.getElementTypeDescriptor() == null) {
-					throw new SpelEvaluationException(getStartPosition(), SpelMessage.UNABLE_TO_GROW_COLLECTION_UNKNOWN_ELEMENT_TYPE);
+					throw new SpelEvaluationException(
+							getStartPosition(), SpelMessage.UNABLE_TO_GROW_COLLECTION_UNKNOWN_ELEMENT_TYPE);
 				}
 				TypeDescriptor elementType = this.collectionEntryDescriptor.getElementTypeDescriptor();
 				try {
+					Constructor<?> ctor = ReflectionUtils.accessibleConstructor(elementType.getType());
 					int newElements = this.index - this.collection.size();
 					while (newElements >= 0) {
-						(this.collection).add(elementType.getType().newInstance());
+						this.collection.add(ctor.newInstance());
 						newElements--;
 					}
 				}
@@ -731,7 +759,7 @@ public class Indexer extends SpelNodeImpl {
 		}
 
 		@Override
-		public void setValue(Object newValue) {
+		public void setValue(@Nullable Object newValue) {
 			throw new SpelEvaluationException(getStartPosition(), SpelMessage.INDEXING_NOT_SUPPORTED_FOR_TYPE,
 					this.typeDescriptor.toString());
 		}
