@@ -1,11 +1,11 @@
 /*
- * Copyright 2002-2016 the original author or authors.
+ * Copyright 2002-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -22,6 +22,7 @@ import javax.resource.cci.Connection;
 import javax.resource.cci.ConnectionFactory;
 
 import org.springframework.dao.DataAccessException;
+import org.springframework.lang.Nullable;
 
 /**
  * Generic callback interface for code that operates on a CCI Connection.
@@ -36,10 +37,12 @@ import org.springframework.dao.DataAccessException;
  * @author Thierry Templier
  * @author Juergen Hoeller
  * @since 1.2
+ * @param <T> the result type
  * @see CciTemplate#execute(ConnectionCallback)
  * @see CciTemplate#execute(javax.resource.cci.InteractionSpec, javax.resource.cci.Record)
  * @see CciTemplate#execute(javax.resource.cci.InteractionSpec, RecordCreator, RecordExtractor)
  */
+@FunctionalInterface
 public interface ConnectionCallback<T> {
 
 	/**
@@ -69,6 +72,7 @@ public interface ConnectionCallback<T> {
 	 * @see javax.resource.cci.ConnectionFactory#getMetaData()
 	 * @see CciTemplate#execute(javax.resource.cci.InteractionSpec, RecordCreator, RecordExtractor)
 	 */
+	@Nullable
 	T doInConnection(Connection connection, ConnectionFactory connectionFactory)
 			throws ResourceException, SQLException, DataAccessException;
 
