@@ -23,6 +23,9 @@ import java.util.LinkedHashMap;
 import java.util.Locale;
 import java.util.Map;
 import java.util.Set;
+import java.util.function.Function;
+
+import org.springframework.lang.Nullable;
 
 /**
  * {@link LinkedHashMap} variant that stores String keys in a case-insensitive
@@ -62,7 +65,7 @@ public class LinkedCaseInsensitiveMap<V> implements Map<String, V>, Serializable
 	 * @param locale the Locale to use for case-insensitive key conversion
 	 * @see #convertKey(String)
 	 */
-	public LinkedCaseInsensitiveMap(Locale locale) {
+	public LinkedCaseInsensitiveMap(@Nullable Locale locale) {
 		this(16, locale);
 	}
 
@@ -85,7 +88,7 @@ public class LinkedCaseInsensitiveMap<V> implements Map<String, V>, Serializable
 	 * @param locale the Locale to use for case-insensitive key conversion
 	 * @see #convertKey(String)
 	 */
-	public LinkedCaseInsensitiveMap(int initialCapacity, Locale locale) {
+	public LinkedCaseInsensitiveMap(int initialCapacity, @Nullable Locale locale) {
 		this.targetMap = new LinkedHashMap<String, V>(initialCapacity) {
 			@Override
 			public boolean containsKey(Object key) {
@@ -100,7 +103,7 @@ public class LinkedCaseInsensitiveMap<V> implements Map<String, V>, Serializable
 				return doRemove;
 			}
 		};
-		this.caseInsensitiveKeys = new HashMap<String, String>(initialCapacity);
+		this.caseInsensitiveKeys = new HashMap<>(initialCapacity);
 		this.locale = (locale != null ? locale : Locale.getDefault());
 	}
 
@@ -138,6 +141,7 @@ public class LinkedCaseInsensitiveMap<V> implements Map<String, V>, Serializable
 	}
 
 	@Override
+	@Nullable
 	public V get(Object key) {
 		if (key instanceof String) {
 			String caseInsensitiveKey = this.caseInsensitiveKeys.get(convertKey((String) key));
@@ -149,6 +153,7 @@ public class LinkedCaseInsensitiveMap<V> implements Map<String, V>, Serializable
 	}
 
 	@Override
+	@Nullable
 	public V getOrDefault(Object key, V defaultValue) {
 		if (key instanceof String) {
 			String caseInsensitiveKey = this.caseInsensitiveKeys.get(convertKey((String) key));
@@ -160,12 +165,15 @@ public class LinkedCaseInsensitiveMap<V> implements Map<String, V>, Serializable
 	}
 
 	@Override
-	public V put(String key, V value) {
+	@Nullable
+	public V put(String key, @Nullable V value) {
 		String oldKey = this.caseInsensitiveKeys.put(convertKey(key), key);
+		V oldKeyValue = null;
 		if (oldKey != null && !oldKey.equals(key)) {
-			this.targetMap.remove(oldKey);
+			oldKeyValue = this.targetMap.remove(oldKey);
 		}
-		return this.targetMap.put(key, value);
+		V oldValue = this.targetMap.put(key, value);
+		return (oldKeyValue != null ? oldKeyValue : oldValue);
 	}
 
 	@Override
@@ -173,12 +181,31 @@ public class LinkedCaseInsensitiveMap<V> implements Map<String, V>, Serializable
 		if (map.isEmpty()) {
 			return;
 		}
-		for (Map.Entry<? extends String, ? extends V> entry : map.entrySet()) {
-			put(entry.getKey(), entry.getValue());
-		}
+		map.forEach(this::put);
 	}
 
 	@Override
+	@Nullable
+	public V putIfAbsent(String key, @Nullable V value) {
+		String oldKey = this.caseInsensitiveKeys.putIfAbsent(convertKey(key), key);
+		if (oldKey != null) {
+			return this.targetMap.get(oldKey);
+		}
+		return this.targetMap.putIfAbsent(key, value);
+	}
+
+	@Override
+	@Nullable
+	public V computeIfAbsent(String key, Function<? super String, ? extends V> mappingFunction) {
+		String oldKey = this.caseInsensitiveKeys.putIfAbsent(convertKey(key), key);
+		if (oldKey != null) {
+			return this.targetMap.get(oldKey);
+		}
+		return this.targetMap.computeIfAbsent(key, mappingFunction);
+	}
+
+	@Override
+	@Nullable
 	public V remove(Object key) {
 		if (key instanceof String) {
 			String caseInsensitiveKey = this.caseInsensitiveKeys.remove(convertKey((String) key));
@@ -212,7 +239,7 @@ public class LinkedCaseInsensitiveMap<V> implements Map<String, V>, Serializable
 
 	@Override
 	public LinkedCaseInsensitiveMap<V> clone() {
-		return new LinkedCaseInsensitiveMap<V>(this);
+		return new LinkedCaseInsensitiveMap<>(this);
 	}
 
 	@Override
