@@ -1,11 +1,11 @@
 /*
- * Copyright 2002-2016 the original author or authors.
+ * Copyright 2002-2019 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -73,7 +73,6 @@ public class SocketUtils {
 	 * &lt;bean id="bean2" ... p:port="#{socketUtils.findAvailableTcpPort(30000)}" /&gt;</code></pre>
 	 */
 	public SocketUtils() {
-		/* no-op */
 	}
 
 
@@ -251,19 +250,20 @@ public class SocketUtils {
 		 */
 		int findAvailablePort(int minPort, int maxPort) {
 			Assert.isTrue(minPort > 0, "'minPort' must be greater than 0");
-			Assert.isTrue(maxPort >= minPort, "'maxPort' must be greater than or equals 'minPort'");
+			Assert.isTrue(maxPort >= minPort, "'maxPort' must be greater than or equal to 'minPort'");
 			Assert.isTrue(maxPort <= PORT_RANGE_MAX, "'maxPort' must be less than or equal to " + PORT_RANGE_MAX);
 
 			int portRange = maxPort - minPort;
 			int candidatePort;
 			int searchCounter = 0;
 			do {
-				if (++searchCounter > portRange) {
+				if (searchCounter > portRange) {
 					throw new IllegalStateException(String.format(
 							"Could not find an available %s port in the range [%d, %d] after %d attempts",
 							name(), minPort, maxPort, searchCounter));
 				}
 				candidatePort = findRandomPort(minPort, maxPort);
+				searchCounter++;
 			}
 			while (!isPortAvailable(candidatePort));
 
@@ -287,7 +287,7 @@ public class SocketUtils {
 			Assert.isTrue((maxPort - minPort) >= numRequested,
 					"'numRequested' must not be greater than 'maxPort' - 'minPort'");
 
-			SortedSet<Integer> availablePorts = new TreeSet<Integer>();
+			SortedSet<Integer> availablePorts = new TreeSet<>();
 			int attemptCount = 0;
 			while ((++attemptCount <= numRequested + 100) && availablePorts.size() < numRequested) {
 				availablePorts.add(findAvailablePort(minPort, maxPort));
